# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import OvfConsumer

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vApp import EntityConfigInfo

class ImportSpec(DynamicData):
   entityConfig: Optional[EntityConfigInfo] = None
   instantiationOst: Optional[OvfConsumer.OstNode] = None
