# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .DatastoreSyncStatus import DatastoreSyncStatus as DatastoreSyncStatus
from .VStorageObjectAssociations import VStorageObjectAssociations as VStorageObjectAssociations
from .VStorageObjectManager import VStorageObjectManager as VStorageObjectManager
from .VStorageObjectQueryResult import VStorageObjectQueryResult as VStorageObjectQueryResult
from .VStorageObjectQuerySpec import VStorageObjectQuerySpec as VStorageObjectQuerySpec
from .VStorageObjectResult import VStorageObjectResult as VStorageObjectResult
from .VStorageObjectSnapshotResult import VStorageObjectSnapshotResult as VStorageObjectSnapshotResult
