# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .HostCommunication import HostCommunication as HostCommunication
from .HostNotConnected import HostNotConnected as HostNotConnected
from .HostNotReachable import HostNotReachable as HostNotReachable
from .InvalidArgument import InvalidArgument as InvalidArgument
from .InvalidRequest import InvalidRequest as InvalidRequest
from .InvalidType import InvalidType as InvalidType
from .ManagedObjectNotFound import ManagedObjectNotFound as ManagedObjectNotFound
from .MethodNotFound import MethodNotFound as MethodNotFound
from .NotEnoughLicenses import NotEnoughLicenses as NotEnoughLicenses
from .NotImplemented import NotImplemented as NotImplemented
from .NotSupported import NotSupported as NotSupported
from .RequestCanceled import RequestCanceled as RequestCanceled
from .SecurityError import SecurityError as SecurityError
from .SystemError import SystemError as SystemError
from .UnexpectedFault import UnexpectedFault as UnexpectedFault
