# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .ApplyRecommendationResult import ApplyRecommendationResult as ApplyRecommendationResult
from .AutomationConfig import AutomationConfig as AutomationConfig
from .ConfigInfo import ConfigInfo as ConfigInfo
from .ConfigSpec import ConfigSpec as ConfigSpec
from .HbrDiskMigrationAction import HbrDiskMigrationAction as HbrDiskMigrationAction
from .IoLoadBalanceConfig import IoLoadBalanceConfig as IoLoadBalanceConfig
from .OptionSpec import OptionSpec as OptionSpec
from .PlacementAffinityRule import PlacementAffinityRule as PlacementAffinityRule
from .PlacementRankResult import PlacementRankResult as PlacementRankResult
from .PlacementRankSpec import PlacementRankSpec as PlacementRankSpec
from .PlacementRankVmSpec import PlacementRankVmSpec as PlacementRankVmSpec
from .PodConfigInfo import PodConfigInfo as PodConfigInfo
from .PodConfigSpec import PodConfigSpec as PodConfigSpec
from .PodSelectionSpec import PodSelectionSpec as PodSelectionSpec
from .SpaceLoadBalanceConfig import SpaceLoadBalanceConfig as SpaceLoadBalanceConfig
from .StorageMigrationAction import StorageMigrationAction as StorageMigrationAction
from .StoragePlacementAction import StoragePlacementAction as StoragePlacementAction
from .StoragePlacementResult import StoragePlacementResult as StoragePlacementResult
from .StoragePlacementSpec import StoragePlacementSpec as StoragePlacementSpec
from .VirtualDiskAntiAffinityRuleSpec import VirtualDiskAntiAffinityRuleSpec as VirtualDiskAntiAffinityRuleSpec
from .VirtualDiskRuleSpec import VirtualDiskRuleSpec as VirtualDiskRuleSpec
from .VmConfigInfo import VmConfigInfo as VmConfigInfo
from .VmConfigSpec import VmConfigSpec as VmConfigSpec
