# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AccountCreatedEvent import AccountCreatedEvent as AccountCreatedEvent
from .AccountRemovedEvent import AccountRemovedEvent as AccountRemovedEvent
from .AccountUpdatedEvent import AccountUpdatedEvent as AccountUpdatedEvent
from .AdminPasswordNotChangedEvent import AdminPasswordNotChangedEvent as AdminPasswordNotChangedEvent
from .AlarmAcknowledgedEvent import AlarmAcknowledgedEvent as AlarmAcknowledgedEvent
from .AlarmActionTriggeredEvent import AlarmActionTriggeredEvent as AlarmActionTriggeredEvent
from .AlarmClearedEvent import AlarmClearedEvent as AlarmClearedEvent
from .AlarmCreatedEvent import AlarmCreatedEvent as AlarmCreatedEvent
from .AlarmEmailCompletedEvent import AlarmEmailCompletedEvent as AlarmEmailCompletedEvent
from .AlarmEmailFailedEvent import AlarmEmailFailedEvent as AlarmEmailFailedEvent
from .AlarmEvent import AlarmEvent as AlarmEvent
from .AlarmEventArgument import AlarmEventArgument as AlarmEventArgument
from .AlarmReconfiguredEvent import AlarmReconfiguredEvent as AlarmReconfiguredEvent
from .AlarmRemovedEvent import AlarmRemovedEvent as AlarmRemovedEvent
from .AlarmScriptCompleteEvent import AlarmScriptCompleteEvent as AlarmScriptCompleteEvent
from .AlarmScriptFailedEvent import AlarmScriptFailedEvent as AlarmScriptFailedEvent
from .AlarmSnmpCompletedEvent import AlarmSnmpCompletedEvent as AlarmSnmpCompletedEvent
from .AlarmSnmpFailedEvent import AlarmSnmpFailedEvent as AlarmSnmpFailedEvent
from .AlarmStatusChangedEvent import AlarmStatusChangedEvent as AlarmStatusChangedEvent
from .AllVirtualMachinesLicensedEvent import AllVirtualMachinesLicensedEvent as AllVirtualMachinesLicensedEvent
from .AlreadyAuthenticatedSessionEvent import AlreadyAuthenticatedSessionEvent as AlreadyAuthenticatedSessionEvent
from .AuthorizationEvent import AuthorizationEvent as AuthorizationEvent
from .BadUsernameSessionEvent import BadUsernameSessionEvent as BadUsernameSessionEvent
from .CanceledHostOperationEvent import CanceledHostOperationEvent as CanceledHostOperationEvent
from .ChangesInfoEventArgument import ChangesInfoEventArgument as ChangesInfoEventArgument
from .ClusterComplianceCheckedEvent import ClusterComplianceCheckedEvent as ClusterComplianceCheckedEvent
from .ClusterCreatedEvent import ClusterCreatedEvent as ClusterCreatedEvent
from .ClusterDestroyedEvent import ClusterDestroyedEvent as ClusterDestroyedEvent
from .ClusterEvent import ClusterEvent as ClusterEvent
from .ClusterOvercommittedEvent import ClusterOvercommittedEvent as ClusterOvercommittedEvent
from .ClusterReconfiguredEvent import ClusterReconfiguredEvent as ClusterReconfiguredEvent
from .ClusterStatusChangedEvent import ClusterStatusChangedEvent as ClusterStatusChangedEvent
from .ComputeResourceEventArgument import ComputeResourceEventArgument as ComputeResourceEventArgument
from .CustomFieldDefAddedEvent import CustomFieldDefAddedEvent as CustomFieldDefAddedEvent
from .CustomFieldDefEvent import CustomFieldDefEvent as CustomFieldDefEvent
from .CustomFieldDefRemovedEvent import CustomFieldDefRemovedEvent as CustomFieldDefRemovedEvent
from .CustomFieldDefRenamedEvent import CustomFieldDefRenamedEvent as CustomFieldDefRenamedEvent
from .CustomFieldEvent import CustomFieldEvent as CustomFieldEvent
from .CustomFieldValueChangedEvent import CustomFieldValueChangedEvent as CustomFieldValueChangedEvent
from .CustomizationEvent import CustomizationEvent as CustomizationEvent
from .CustomizationFailed import CustomizationFailed as CustomizationFailed
from .CustomizationLinuxIdentityFailed import CustomizationLinuxIdentityFailed as CustomizationLinuxIdentityFailed
from .CustomizationNetworkSetupFailed import CustomizationNetworkSetupFailed as CustomizationNetworkSetupFailed
from .CustomizationStartedEvent import CustomizationStartedEvent as CustomizationStartedEvent
from .CustomizationSucceeded import CustomizationSucceeded as CustomizationSucceeded
from .CustomizationSysprepFailed import CustomizationSysprepFailed as CustomizationSysprepFailed
from .CustomizationUnknownFailure import CustomizationUnknownFailure as CustomizationUnknownFailure
from .DVPortgroupCreatedEvent import DVPortgroupCreatedEvent as DVPortgroupCreatedEvent
from .DVPortgroupDestroyedEvent import DVPortgroupDestroyedEvent as DVPortgroupDestroyedEvent
from .DVPortgroupEvent import DVPortgroupEvent as DVPortgroupEvent
from .DVPortgroupReconfiguredEvent import DVPortgroupReconfiguredEvent as DVPortgroupReconfiguredEvent
from .DVPortgroupRenamedEvent import DVPortgroupRenamedEvent as DVPortgroupRenamedEvent
from .DasAdmissionControlDisabledEvent import DasAdmissionControlDisabledEvent as DasAdmissionControlDisabledEvent
from .DasAdmissionControlEnabledEvent import DasAdmissionControlEnabledEvent as DasAdmissionControlEnabledEvent
from .DasAgentFoundEvent import DasAgentFoundEvent as DasAgentFoundEvent
from .DasAgentUnavailableEvent import DasAgentUnavailableEvent as DasAgentUnavailableEvent
from .DasClusterIsolatedEvent import DasClusterIsolatedEvent as DasClusterIsolatedEvent
from .DasDisabledEvent import DasDisabledEvent as DasDisabledEvent
from .DasEnabledEvent import DasEnabledEvent as DasEnabledEvent
from .DasHostFailedEvent import DasHostFailedEvent as DasHostFailedEvent
from .DasHostIsolatedEvent import DasHostIsolatedEvent as DasHostIsolatedEvent
from .DatacenterCreatedEvent import DatacenterCreatedEvent as DatacenterCreatedEvent
from .DatacenterEvent import DatacenterEvent as DatacenterEvent
from .DatacenterEventArgument import DatacenterEventArgument as DatacenterEventArgument
from .DatacenterRenamedEvent import DatacenterRenamedEvent as DatacenterRenamedEvent
from .DatastoreCapacityIncreasedEvent import DatastoreCapacityIncreasedEvent as DatastoreCapacityIncreasedEvent
from .DatastoreDestroyedEvent import DatastoreDestroyedEvent as DatastoreDestroyedEvent
from .DatastoreDiscoveredEvent import DatastoreDiscoveredEvent as DatastoreDiscoveredEvent
from .DatastoreDuplicatedEvent import DatastoreDuplicatedEvent as DatastoreDuplicatedEvent
from .DatastoreEvent import DatastoreEvent as DatastoreEvent
from .DatastoreEventArgument import DatastoreEventArgument as DatastoreEventArgument
from .DatastoreFileCopiedEvent import DatastoreFileCopiedEvent as DatastoreFileCopiedEvent
from .DatastoreFileDeletedEvent import DatastoreFileDeletedEvent as DatastoreFileDeletedEvent
from .DatastoreFileEvent import DatastoreFileEvent as DatastoreFileEvent
from .DatastoreFileMovedEvent import DatastoreFileMovedEvent as DatastoreFileMovedEvent
from .DatastoreIORMReconfiguredEvent import DatastoreIORMReconfiguredEvent as DatastoreIORMReconfiguredEvent
from .DatastorePrincipalConfigured import DatastorePrincipalConfigured as DatastorePrincipalConfigured
from .DatastoreRemovedOnHostEvent import DatastoreRemovedOnHostEvent as DatastoreRemovedOnHostEvent
from .DatastoreRenamedEvent import DatastoreRenamedEvent as DatastoreRenamedEvent
from .DatastoreRenamedOnHostEvent import DatastoreRenamedOnHostEvent as DatastoreRenamedOnHostEvent
from .DrsDisabledEvent import DrsDisabledEvent as DrsDisabledEvent
from .DrsEnabledEvent import DrsEnabledEvent as DrsEnabledEvent
from .DrsEnteredStandbyModeEvent import DrsEnteredStandbyModeEvent as DrsEnteredStandbyModeEvent
from .DrsEnteringStandbyModeEvent import DrsEnteringStandbyModeEvent as DrsEnteringStandbyModeEvent
from .DrsExitStandbyModeFailedEvent import DrsExitStandbyModeFailedEvent as DrsExitStandbyModeFailedEvent
from .DrsExitedStandbyModeEvent import DrsExitedStandbyModeEvent as DrsExitedStandbyModeEvent
from .DrsExitingStandbyModeEvent import DrsExitingStandbyModeEvent as DrsExitingStandbyModeEvent
from .DrsInvocationFailedEvent import DrsInvocationFailedEvent as DrsInvocationFailedEvent
from .DrsRecoveredFromFailureEvent import DrsRecoveredFromFailureEvent as DrsRecoveredFromFailureEvent
from .DrsResourceConfigureFailedEvent import DrsResourceConfigureFailedEvent as DrsResourceConfigureFailedEvent
from .DrsResourceConfigureSyncedEvent import DrsResourceConfigureSyncedEvent as DrsResourceConfigureSyncedEvent
from .DrsRuleComplianceEvent import DrsRuleComplianceEvent as DrsRuleComplianceEvent
from .DrsRuleViolationEvent import DrsRuleViolationEvent as DrsRuleViolationEvent
from .DrsSoftRuleViolationEvent import DrsSoftRuleViolationEvent as DrsSoftRuleViolationEvent
from .DrsVmMigratedEvent import DrsVmMigratedEvent as DrsVmMigratedEvent
from .DrsVmPoweredOnEvent import DrsVmPoweredOnEvent as DrsVmPoweredOnEvent
from .DuplicateIpDetectedEvent import DuplicateIpDetectedEvent as DuplicateIpDetectedEvent
from .DvpgImportEvent import DvpgImportEvent as DvpgImportEvent
from .DvpgRestoreEvent import DvpgRestoreEvent as DvpgRestoreEvent
from .DvsCreatedEvent import DvsCreatedEvent as DvsCreatedEvent
from .DvsDestroyedEvent import DvsDestroyedEvent as DvsDestroyedEvent
from .DvsEvent import DvsEvent as DvsEvent
from .DvsEventArgument import DvsEventArgument as DvsEventArgument
from .DvsHealthStatusChangeEvent import DvsHealthStatusChangeEvent as DvsHealthStatusChangeEvent
from .DvsHostBackInSyncEvent import DvsHostBackInSyncEvent as DvsHostBackInSyncEvent
from .DvsHostJoinedEvent import DvsHostJoinedEvent as DvsHostJoinedEvent
from .DvsHostLeftEvent import DvsHostLeftEvent as DvsHostLeftEvent
from .DvsHostStatusUpdated import DvsHostStatusUpdated as DvsHostStatusUpdated
from .DvsHostWentOutOfSyncEvent import DvsHostWentOutOfSyncEvent as DvsHostWentOutOfSyncEvent
from .DvsImportEvent import DvsImportEvent as DvsImportEvent
from .DvsMergedEvent import DvsMergedEvent as DvsMergedEvent
from .DvsOutOfSyncHostArgument import DvsOutOfSyncHostArgument as DvsOutOfSyncHostArgument
from .DvsPortBlockedEvent import DvsPortBlockedEvent as DvsPortBlockedEvent
from .DvsPortConnectedEvent import DvsPortConnectedEvent as DvsPortConnectedEvent
from .DvsPortCreatedEvent import DvsPortCreatedEvent as DvsPortCreatedEvent
from .DvsPortDeletedEvent import DvsPortDeletedEvent as DvsPortDeletedEvent
from .DvsPortDisconnectedEvent import DvsPortDisconnectedEvent as DvsPortDisconnectedEvent
from .DvsPortEnteredPassthruEvent import DvsPortEnteredPassthruEvent as DvsPortEnteredPassthruEvent
from .DvsPortExitedPassthruEvent import DvsPortExitedPassthruEvent as DvsPortExitedPassthruEvent
from .DvsPortJoinPortgroupEvent import DvsPortJoinPortgroupEvent as DvsPortJoinPortgroupEvent
from .DvsPortLeavePortgroupEvent import DvsPortLeavePortgroupEvent as DvsPortLeavePortgroupEvent
from .DvsPortLinkDownEvent import DvsPortLinkDownEvent as DvsPortLinkDownEvent
from .DvsPortLinkUpEvent import DvsPortLinkUpEvent as DvsPortLinkUpEvent
from .DvsPortReconfiguredEvent import DvsPortReconfiguredEvent as DvsPortReconfiguredEvent
from .DvsPortRuntimeChangeEvent import DvsPortRuntimeChangeEvent as DvsPortRuntimeChangeEvent
from .DvsPortUnblockedEvent import DvsPortUnblockedEvent as DvsPortUnblockedEvent
from .DvsPortVendorSpecificStateChangeEvent import DvsPortVendorSpecificStateChangeEvent as DvsPortVendorSpecificStateChangeEvent
from .DvsReconfiguredEvent import DvsReconfiguredEvent as DvsReconfiguredEvent
from .DvsRenamedEvent import DvsRenamedEvent as DvsRenamedEvent
from .DvsRestoreEvent import DvsRestoreEvent as DvsRestoreEvent
from .DvsUpgradeAvailableEvent import DvsUpgradeAvailableEvent as DvsUpgradeAvailableEvent
from .DvsUpgradeInProgressEvent import DvsUpgradeInProgressEvent as DvsUpgradeInProgressEvent
from .DvsUpgradeRejectedEvent import DvsUpgradeRejectedEvent as DvsUpgradeRejectedEvent
from .DvsUpgradedEvent import DvsUpgradedEvent as DvsUpgradedEvent
from .EnteredMaintenanceModeEvent import EnteredMaintenanceModeEvent as EnteredMaintenanceModeEvent
from .EnteredStandbyModeEvent import EnteredStandbyModeEvent as EnteredStandbyModeEvent
from .EnteringMaintenanceModeEvent import EnteringMaintenanceModeEvent as EnteringMaintenanceModeEvent
from .EnteringStandbyModeEvent import EnteringStandbyModeEvent as EnteringStandbyModeEvent
from .EntityEventArgument import EntityEventArgument as EntityEventArgument
from .ErrorUpgradeEvent import ErrorUpgradeEvent as ErrorUpgradeEvent
from .Event import Event as Event
from .EventArgument import EventArgument as EventArgument
from .EventDescription import EventDescription as EventDescription
from .EventEx import EventEx as EventEx
from .EventFilterSpec import EventFilterSpec as EventFilterSpec
from .EventHistoryCollector import EventHistoryCollector as EventHistoryCollector
from .EventManager import EventManager as EventManager
from .ExitMaintenanceModeEvent import ExitMaintenanceModeEvent as ExitMaintenanceModeEvent
from .ExitStandbyModeFailedEvent import ExitStandbyModeFailedEvent as ExitStandbyModeFailedEvent
from .ExitedStandbyModeEvent import ExitedStandbyModeEvent as ExitedStandbyModeEvent
from .ExitingStandbyModeEvent import ExitingStandbyModeEvent as ExitingStandbyModeEvent
from .ExtendedEvent import ExtendedEvent as ExtendedEvent
from .FailoverLevelRestored import FailoverLevelRestored as FailoverLevelRestored
from .FolderEventArgument import FolderEventArgument as FolderEventArgument
from .GeneralEvent import GeneralEvent as GeneralEvent
from .GeneralHostErrorEvent import GeneralHostErrorEvent as GeneralHostErrorEvent
from .GeneralHostInfoEvent import GeneralHostInfoEvent as GeneralHostInfoEvent
from .GeneralHostWarningEvent import GeneralHostWarningEvent as GeneralHostWarningEvent
from .GeneralUserEvent import GeneralUserEvent as GeneralUserEvent
from .GeneralVmErrorEvent import GeneralVmErrorEvent as GeneralVmErrorEvent
from .GeneralVmInfoEvent import GeneralVmInfoEvent as GeneralVmInfoEvent
from .GeneralVmWarningEvent import GeneralVmWarningEvent as GeneralVmWarningEvent
from .GhostDvsProxySwitchDetectedEvent import GhostDvsProxySwitchDetectedEvent as GhostDvsProxySwitchDetectedEvent
from .GhostDvsProxySwitchRemovedEvent import GhostDvsProxySwitchRemovedEvent as GhostDvsProxySwitchRemovedEvent
from .GlobalMessageChangedEvent import GlobalMessageChangedEvent as GlobalMessageChangedEvent
from .HealthStatusChangedEvent import HealthStatusChangedEvent as HealthStatusChangedEvent
from .HostAddFailedEvent import HostAddFailedEvent as HostAddFailedEvent
from .HostAddedEvent import HostAddedEvent as HostAddedEvent
from .HostAdminDisableEvent import HostAdminDisableEvent as HostAdminDisableEvent
from .HostAdminEnableEvent import HostAdminEnableEvent as HostAdminEnableEvent
from .HostCnxFailedAccountFailedEvent import HostCnxFailedAccountFailedEvent as HostCnxFailedAccountFailedEvent
from .HostCnxFailedAlreadyManagedEvent import HostCnxFailedAlreadyManagedEvent as HostCnxFailedAlreadyManagedEvent
from .HostCnxFailedBadCcagentEvent import HostCnxFailedBadCcagentEvent as HostCnxFailedBadCcagentEvent
from .HostCnxFailedBadUsernameEvent import HostCnxFailedBadUsernameEvent as HostCnxFailedBadUsernameEvent
from .HostCnxFailedBadVersionEvent import HostCnxFailedBadVersionEvent as HostCnxFailedBadVersionEvent
from .HostCnxFailedCcagentUpgradeEvent import HostCnxFailedCcagentUpgradeEvent as HostCnxFailedCcagentUpgradeEvent
from .HostCnxFailedEvent import HostCnxFailedEvent as HostCnxFailedEvent
from .HostCnxFailedNetworkErrorEvent import HostCnxFailedNetworkErrorEvent as HostCnxFailedNetworkErrorEvent
from .HostCnxFailedNoAccessEvent import HostCnxFailedNoAccessEvent as HostCnxFailedNoAccessEvent
from .HostCnxFailedNoConnectionEvent import HostCnxFailedNoConnectionEvent as HostCnxFailedNoConnectionEvent
from .HostCnxFailedNoLicenseEvent import HostCnxFailedNoLicenseEvent as HostCnxFailedNoLicenseEvent
from .HostCnxFailedNotFoundEvent import HostCnxFailedNotFoundEvent as HostCnxFailedNotFoundEvent
from .HostCnxFailedTimeoutEvent import HostCnxFailedTimeoutEvent as HostCnxFailedTimeoutEvent
from .HostComplianceCheckedEvent import HostComplianceCheckedEvent as HostComplianceCheckedEvent
from .HostCompliantEvent import HostCompliantEvent as HostCompliantEvent
from .HostConfigAppliedEvent import HostConfigAppliedEvent as HostConfigAppliedEvent
from .HostConnectedEvent import HostConnectedEvent as HostConnectedEvent
from .HostConnectionLostEvent import HostConnectionLostEvent as HostConnectionLostEvent
from .HostDasDisabledEvent import HostDasDisabledEvent as HostDasDisabledEvent
from .HostDasDisablingEvent import HostDasDisablingEvent as HostDasDisablingEvent
from .HostDasEnabledEvent import HostDasEnabledEvent as HostDasEnabledEvent
from .HostDasEnablingEvent import HostDasEnablingEvent as HostDasEnablingEvent
from .HostDasErrorEvent import HostDasErrorEvent as HostDasErrorEvent
from .HostDasEvent import HostDasEvent as HostDasEvent
from .HostDasOkEvent import HostDasOkEvent as HostDasOkEvent
from .HostDisconnectedEvent import HostDisconnectedEvent as HostDisconnectedEvent
from .HostEnableAdminFailedEvent import HostEnableAdminFailedEvent as HostEnableAdminFailedEvent
from .HostEvent import HostEvent as HostEvent
from .HostEventArgument import HostEventArgument as HostEventArgument
from .HostExtraNetworksEvent import HostExtraNetworksEvent as HostExtraNetworksEvent
from .HostGetShortNameFailedEvent import HostGetShortNameFailedEvent as HostGetShortNameFailedEvent
from .HostInAuditModeEvent import HostInAuditModeEvent as HostInAuditModeEvent
from .HostInventoryFullEvent import HostInventoryFullEvent as HostInventoryFullEvent
from .HostInventoryUnreadableEvent import HostInventoryUnreadableEvent as HostInventoryUnreadableEvent
from .HostIpChangedEvent import HostIpChangedEvent as HostIpChangedEvent
from .HostIpInconsistentEvent import HostIpInconsistentEvent as HostIpInconsistentEvent
from .HostIpToShortNameFailedEvent import HostIpToShortNameFailedEvent as HostIpToShortNameFailedEvent
from .HostIsolationIpPingFailedEvent import HostIsolationIpPingFailedEvent as HostIsolationIpPingFailedEvent
from .HostLicenseExpiredEvent import HostLicenseExpiredEvent as HostLicenseExpiredEvent
from .HostLocalPortCreatedEvent import HostLocalPortCreatedEvent as HostLocalPortCreatedEvent
from .HostMissingNetworksEvent import HostMissingNetworksEvent as HostMissingNetworksEvent
from .HostMonitoringStateChangedEvent import HostMonitoringStateChangedEvent as HostMonitoringStateChangedEvent
from .HostNoAvailableNetworksEvent import HostNoAvailableNetworksEvent as HostNoAvailableNetworksEvent
from .HostNoHAEnabledPortGroupsEvent import HostNoHAEnabledPortGroupsEvent as HostNoHAEnabledPortGroupsEvent
from .HostNoRedundantManagementNetworkEvent import HostNoRedundantManagementNetworkEvent as HostNoRedundantManagementNetworkEvent
from .HostNonCompliantEvent import HostNonCompliantEvent as HostNonCompliantEvent
from .HostNotInClusterEvent import HostNotInClusterEvent as HostNotInClusterEvent
from .HostOvercommittedEvent import HostOvercommittedEvent as HostOvercommittedEvent
from .HostPrimaryAgentNotShortNameEvent import HostPrimaryAgentNotShortNameEvent as HostPrimaryAgentNotShortNameEvent
from .HostProfileAppliedEvent import HostProfileAppliedEvent as HostProfileAppliedEvent
from .HostReconnectionFailedEvent import HostReconnectionFailedEvent as HostReconnectionFailedEvent
from .HostRemovedEvent import HostRemovedEvent as HostRemovedEvent
from .HostShortNameInconsistentEvent import HostShortNameInconsistentEvent as HostShortNameInconsistentEvent
from .HostShortNameToIpFailedEvent import HostShortNameToIpFailedEvent as HostShortNameToIpFailedEvent
from .HostShutdownEvent import HostShutdownEvent as HostShutdownEvent
from .HostSpecificationChangedEvent import HostSpecificationChangedEvent as HostSpecificationChangedEvent
from .HostSpecificationRequireEvent import HostSpecificationRequireEvent as HostSpecificationRequireEvent
from .HostSpecificationUpdateEvent import HostSpecificationUpdateEvent as HostSpecificationUpdateEvent
from .HostStatusChangedEvent import HostStatusChangedEvent as HostStatusChangedEvent
from .HostSubSpecificationDeleteEvent import HostSubSpecificationDeleteEvent as HostSubSpecificationDeleteEvent
from .HostSubSpecificationUpdateEvent import HostSubSpecificationUpdateEvent as HostSubSpecificationUpdateEvent
from .HostSyncFailedEvent import HostSyncFailedEvent as HostSyncFailedEvent
from .HostUpgradeFailedEvent import HostUpgradeFailedEvent as HostUpgradeFailedEvent
from .HostUserWorldSwapNotEnabledEvent import HostUserWorldSwapNotEnabledEvent as HostUserWorldSwapNotEnabledEvent
from .HostVnicConnectedToCustomizedDVPortEvent import HostVnicConnectedToCustomizedDVPortEvent as HostVnicConnectedToCustomizedDVPortEvent
from .HostWwnChangedEvent import HostWwnChangedEvent as HostWwnChangedEvent
from .HostWwnConflictEvent import HostWwnConflictEvent as HostWwnConflictEvent
from .IncorrectHostInformationEvent import IncorrectHostInformationEvent as IncorrectHostInformationEvent
from .InfoUpgradeEvent import InfoUpgradeEvent as InfoUpgradeEvent
from .InsufficientFailoverResourcesEvent import InsufficientFailoverResourcesEvent as InsufficientFailoverResourcesEvent
from .InvalidEditionEvent import InvalidEditionEvent as InvalidEditionEvent
from .LicenseEvent import LicenseEvent as LicenseEvent
from .LicenseExpiredEvent import LicenseExpiredEvent as LicenseExpiredEvent
from .LicenseNonComplianceEvent import LicenseNonComplianceEvent as LicenseNonComplianceEvent
from .LicenseRestrictedEvent import LicenseRestrictedEvent as LicenseRestrictedEvent
from .LicenseServerAvailableEvent import LicenseServerAvailableEvent as LicenseServerAvailableEvent
from .LicenseServerUnavailableEvent import LicenseServerUnavailableEvent as LicenseServerUnavailableEvent
from .LocalDatastoreCreatedEvent import LocalDatastoreCreatedEvent as LocalDatastoreCreatedEvent
from .LocalTSMEnabledEvent import LocalTSMEnabledEvent as LocalTSMEnabledEvent
from .LockerMisconfiguredEvent import LockerMisconfiguredEvent as LockerMisconfiguredEvent
from .LockerReconfiguredEvent import LockerReconfiguredEvent as LockerReconfiguredEvent
from .ManagedEntityEventArgument import ManagedEntityEventArgument as ManagedEntityEventArgument
from .MigrationErrorEvent import MigrationErrorEvent as MigrationErrorEvent
from .MigrationEvent import MigrationEvent as MigrationEvent
from .MigrationHostErrorEvent import MigrationHostErrorEvent as MigrationHostErrorEvent
from .MigrationHostWarningEvent import MigrationHostWarningEvent as MigrationHostWarningEvent
from .MigrationResourceErrorEvent import MigrationResourceErrorEvent as MigrationResourceErrorEvent
from .MigrationResourceWarningEvent import MigrationResourceWarningEvent as MigrationResourceWarningEvent
from .MigrationWarningEvent import MigrationWarningEvent as MigrationWarningEvent
from .MtuMatchEvent import MtuMatchEvent as MtuMatchEvent
from .MtuMismatchEvent import MtuMismatchEvent as MtuMismatchEvent
from .NASDatastoreCreatedEvent import NASDatastoreCreatedEvent as NASDatastoreCreatedEvent
from .NetworkEventArgument import NetworkEventArgument as NetworkEventArgument
from .NetworkRollbackEvent import NetworkRollbackEvent as NetworkRollbackEvent
from .NoAccessUserEvent import NoAccessUserEvent as NoAccessUserEvent
from .NoDatastoresConfiguredEvent import NoDatastoresConfiguredEvent as NoDatastoresConfiguredEvent
from .NoLicenseEvent import NoLicenseEvent as NoLicenseEvent
from .NoMaintenanceModeDrsRecommendationForVM import NoMaintenanceModeDrsRecommendationForVM as NoMaintenanceModeDrsRecommendationForVM
from .NonVIWorkloadDetectedOnDatastoreEvent import NonVIWorkloadDetectedOnDatastoreEvent as NonVIWorkloadDetectedOnDatastoreEvent
from .NotEnoughResourcesToStartVmEvent import NotEnoughResourcesToStartVmEvent as NotEnoughResourcesToStartVmEvent
from .OutOfSyncDvsHost import OutOfSyncDvsHost as OutOfSyncDvsHost
from .PermissionAddedEvent import PermissionAddedEvent as PermissionAddedEvent
from .PermissionEvent import PermissionEvent as PermissionEvent
from .PermissionRemovedEvent import PermissionRemovedEvent as PermissionRemovedEvent
from .PermissionUpdatedEvent import PermissionUpdatedEvent as PermissionUpdatedEvent
from .ProfileAssociatedEvent import ProfileAssociatedEvent as ProfileAssociatedEvent
from .ProfileChangedEvent import ProfileChangedEvent as ProfileChangedEvent
from .ProfileCreatedEvent import ProfileCreatedEvent as ProfileCreatedEvent
from .ProfileDissociatedEvent import ProfileDissociatedEvent as ProfileDissociatedEvent
from .ProfileEvent import ProfileEvent as ProfileEvent
from .ProfileEventArgument import ProfileEventArgument as ProfileEventArgument
from .ProfileReferenceHostChangedEvent import ProfileReferenceHostChangedEvent as ProfileReferenceHostChangedEvent
from .ProfileRemovedEvent import ProfileRemovedEvent as ProfileRemovedEvent
from .RecoveryEvent import RecoveryEvent as RecoveryEvent
from .RemoteTSMEnabledEvent import RemoteTSMEnabledEvent as RemoteTSMEnabledEvent
from .ResourcePoolCreatedEvent import ResourcePoolCreatedEvent as ResourcePoolCreatedEvent
from .ResourcePoolDestroyedEvent import ResourcePoolDestroyedEvent as ResourcePoolDestroyedEvent
from .ResourcePoolEvent import ResourcePoolEvent as ResourcePoolEvent
from .ResourcePoolEventArgument import ResourcePoolEventArgument as ResourcePoolEventArgument
from .ResourcePoolMovedEvent import ResourcePoolMovedEvent as ResourcePoolMovedEvent
from .ResourcePoolReconfiguredEvent import ResourcePoolReconfiguredEvent as ResourcePoolReconfiguredEvent
from .ResourceViolatedEvent import ResourceViolatedEvent as ResourceViolatedEvent
from .RoleAddedEvent import RoleAddedEvent as RoleAddedEvent
from .RoleEvent import RoleEvent as RoleEvent
from .RoleEventArgument import RoleEventArgument as RoleEventArgument
from .RoleRemovedEvent import RoleRemovedEvent as RoleRemovedEvent
from .RoleUpdatedEvent import RoleUpdatedEvent as RoleUpdatedEvent
from .RollbackEvent import RollbackEvent as RollbackEvent
from .ScheduledTaskCompletedEvent import ScheduledTaskCompletedEvent as ScheduledTaskCompletedEvent
from .ScheduledTaskCreatedEvent import ScheduledTaskCreatedEvent as ScheduledTaskCreatedEvent
from .ScheduledTaskEmailCompletedEvent import ScheduledTaskEmailCompletedEvent as ScheduledTaskEmailCompletedEvent
from .ScheduledTaskEmailFailedEvent import ScheduledTaskEmailFailedEvent as ScheduledTaskEmailFailedEvent
from .ScheduledTaskEvent import ScheduledTaskEvent as ScheduledTaskEvent
from .ScheduledTaskEventArgument import ScheduledTaskEventArgument as ScheduledTaskEventArgument
from .ScheduledTaskFailedEvent import ScheduledTaskFailedEvent as ScheduledTaskFailedEvent
from .ScheduledTaskReconfiguredEvent import ScheduledTaskReconfiguredEvent as ScheduledTaskReconfiguredEvent
from .ScheduledTaskRemovedEvent import ScheduledTaskRemovedEvent as ScheduledTaskRemovedEvent
from .ScheduledTaskStartedEvent import ScheduledTaskStartedEvent as ScheduledTaskStartedEvent
from .ServerLicenseExpiredEvent import ServerLicenseExpiredEvent as ServerLicenseExpiredEvent
from .ServerStartedSessionEvent import ServerStartedSessionEvent as ServerStartedSessionEvent
from .SessionEvent import SessionEvent as SessionEvent
from .SessionTerminatedEvent import SessionTerminatedEvent as SessionTerminatedEvent
from .TaskEvent import TaskEvent as TaskEvent
from .TaskTimeoutEvent import TaskTimeoutEvent as TaskTimeoutEvent
from .TeamingMatchEvent import TeamingMatchEvent as TeamingMatchEvent
from .TeamingMisMatchEvent import TeamingMisMatchEvent as TeamingMisMatchEvent
from .TemplateBeingUpgradedEvent import TemplateBeingUpgradedEvent as TemplateBeingUpgradedEvent
from .TemplateUpgradeEvent import TemplateUpgradeEvent as TemplateUpgradeEvent
from .TemplateUpgradeFailedEvent import TemplateUpgradeFailedEvent as TemplateUpgradeFailedEvent
from .TemplateUpgradedEvent import TemplateUpgradedEvent as TemplateUpgradedEvent
from .TimedOutHostOperationEvent import TimedOutHostOperationEvent as TimedOutHostOperationEvent
from .UnlicensedVirtualMachinesEvent import UnlicensedVirtualMachinesEvent as UnlicensedVirtualMachinesEvent
from .UnlicensedVirtualMachinesFoundEvent import UnlicensedVirtualMachinesFoundEvent as UnlicensedVirtualMachinesFoundEvent
from .UpdatedAgentBeingRestartedEvent import UpdatedAgentBeingRestartedEvent as UpdatedAgentBeingRestartedEvent
from .UpgradeEvent import UpgradeEvent as UpgradeEvent
from .UplinkPortMtuNotSupportEvent import UplinkPortMtuNotSupportEvent as UplinkPortMtuNotSupportEvent
from .UplinkPortMtuSupportEvent import UplinkPortMtuSupportEvent as UplinkPortMtuSupportEvent
from .UplinkPortVlanTrunkedEvent import UplinkPortVlanTrunkedEvent as UplinkPortVlanTrunkedEvent
from .UplinkPortVlanUntrunkedEvent import UplinkPortVlanUntrunkedEvent as UplinkPortVlanUntrunkedEvent
from .UserAssignedToGroup import UserAssignedToGroup as UserAssignedToGroup
from .UserLoginSessionEvent import UserLoginSessionEvent as UserLoginSessionEvent
from .UserLogoutSessionEvent import UserLogoutSessionEvent as UserLogoutSessionEvent
from .UserPasswordChanged import UserPasswordChanged as UserPasswordChanged
from .UserUnassignedFromGroup import UserUnassignedFromGroup as UserUnassignedFromGroup
from .UserUpgradeEvent import UserUpgradeEvent as UserUpgradeEvent
from .VMFSDatastoreCreatedEvent import VMFSDatastoreCreatedEvent as VMFSDatastoreCreatedEvent
from .VMFSDatastoreExpandedEvent import VMFSDatastoreExpandedEvent as VMFSDatastoreExpandedEvent
from .VMFSDatastoreExtendedEvent import VMFSDatastoreExtendedEvent as VMFSDatastoreExtendedEvent
from .VMotionLicenseExpiredEvent import VMotionLicenseExpiredEvent as VMotionLicenseExpiredEvent
from .VcAgentUninstallFailedEvent import VcAgentUninstallFailedEvent as VcAgentUninstallFailedEvent
from .VcAgentUninstalledEvent import VcAgentUninstalledEvent as VcAgentUninstalledEvent
from .VcAgentUpgradeFailedEvent import VcAgentUpgradeFailedEvent as VcAgentUpgradeFailedEvent
from .VcAgentUpgradedEvent import VcAgentUpgradedEvent as VcAgentUpgradedEvent
from .VimAccountPasswordChangedEvent import VimAccountPasswordChangedEvent as VimAccountPasswordChangedEvent
from .VmAcquiredMksTicketEvent import VmAcquiredMksTicketEvent as VmAcquiredMksTicketEvent
from .VmAcquiredTicketEvent import VmAcquiredTicketEvent as VmAcquiredTicketEvent
from .VmAutoRenameEvent import VmAutoRenameEvent as VmAutoRenameEvent
from .VmBeingClonedEvent import VmBeingClonedEvent as VmBeingClonedEvent
from .VmBeingClonedNoFolderEvent import VmBeingClonedNoFolderEvent as VmBeingClonedNoFolderEvent
from .VmBeingCreatedEvent import VmBeingCreatedEvent as VmBeingCreatedEvent
from .VmBeingDeployedEvent import VmBeingDeployedEvent as VmBeingDeployedEvent
from .VmBeingHotMigratedEvent import VmBeingHotMigratedEvent as VmBeingHotMigratedEvent
from .VmBeingMigratedEvent import VmBeingMigratedEvent as VmBeingMigratedEvent
from .VmBeingRelocatedEvent import VmBeingRelocatedEvent as VmBeingRelocatedEvent
from .VmCloneEvent import VmCloneEvent as VmCloneEvent
from .VmCloneFailedEvent import VmCloneFailedEvent as VmCloneFailedEvent
from .VmClonedEvent import VmClonedEvent as VmClonedEvent
from .VmConfigMissingEvent import VmConfigMissingEvent as VmConfigMissingEvent
from .VmConnectedEvent import VmConnectedEvent as VmConnectedEvent
from .VmCreatedEvent import VmCreatedEvent as VmCreatedEvent
from .VmDasBeingResetEvent import VmDasBeingResetEvent as VmDasBeingResetEvent
from .VmDasBeingResetWithScreenshotEvent import VmDasBeingResetWithScreenshotEvent as VmDasBeingResetWithScreenshotEvent
from .VmDasResetFailedEvent import VmDasResetFailedEvent as VmDasResetFailedEvent
from .VmDasUpdateErrorEvent import VmDasUpdateErrorEvent as VmDasUpdateErrorEvent
from .VmDasUpdateOkEvent import VmDasUpdateOkEvent as VmDasUpdateOkEvent
from .VmDateRolledBackEvent import VmDateRolledBackEvent as VmDateRolledBackEvent
from .VmDeployFailedEvent import VmDeployFailedEvent as VmDeployFailedEvent
from .VmDeployedEvent import VmDeployedEvent as VmDeployedEvent
from .VmDisconnectedEvent import VmDisconnectedEvent as VmDisconnectedEvent
from .VmDiscoveredEvent import VmDiscoveredEvent as VmDiscoveredEvent
from .VmDiskFailedEvent import VmDiskFailedEvent as VmDiskFailedEvent
from .VmEmigratingEvent import VmEmigratingEvent as VmEmigratingEvent
from .VmEndRecordingEvent import VmEndRecordingEvent as VmEndRecordingEvent
from .VmEndReplayingEvent import VmEndReplayingEvent as VmEndReplayingEvent
from .VmEvent import VmEvent as VmEvent
from .VmEventArgument import VmEventArgument as VmEventArgument
from .VmFailedMigrateEvent import VmFailedMigrateEvent as VmFailedMigrateEvent
from .VmFailedRelayoutEvent import VmFailedRelayoutEvent as VmFailedRelayoutEvent
from .VmFailedRelayoutOnVmfs2DatastoreEvent import VmFailedRelayoutOnVmfs2DatastoreEvent as VmFailedRelayoutOnVmfs2DatastoreEvent
from .VmFailedStartingSecondaryEvent import VmFailedStartingSecondaryEvent as VmFailedStartingSecondaryEvent
from .VmFailedToPowerOffEvent import VmFailedToPowerOffEvent as VmFailedToPowerOffEvent
from .VmFailedToPowerOnEvent import VmFailedToPowerOnEvent as VmFailedToPowerOnEvent
from .VmFailedToRebootGuestEvent import VmFailedToRebootGuestEvent as VmFailedToRebootGuestEvent
from .VmFailedToResetEvent import VmFailedToResetEvent as VmFailedToResetEvent
from .VmFailedToShutdownGuestEvent import VmFailedToShutdownGuestEvent as VmFailedToShutdownGuestEvent
from .VmFailedToStandbyGuestEvent import VmFailedToStandbyGuestEvent as VmFailedToStandbyGuestEvent
from .VmFailedToSuspendEvent import VmFailedToSuspendEvent as VmFailedToSuspendEvent
from .VmFailedUpdatingSecondaryConfig import VmFailedUpdatingSecondaryConfig as VmFailedUpdatingSecondaryConfig
from .VmFailoverFailed import VmFailoverFailed as VmFailoverFailed
from .VmFaultToleranceStateChangedEvent import VmFaultToleranceStateChangedEvent as VmFaultToleranceStateChangedEvent
from .VmFaultToleranceTurnedOffEvent import VmFaultToleranceTurnedOffEvent as VmFaultToleranceTurnedOffEvent
from .VmFaultToleranceVmTerminatedEvent import VmFaultToleranceVmTerminatedEvent as VmFaultToleranceVmTerminatedEvent
from .VmGuestOSCrashedEvent import VmGuestOSCrashedEvent as VmGuestOSCrashedEvent
from .VmGuestRebootEvent import VmGuestRebootEvent as VmGuestRebootEvent
from .VmGuestShutdownEvent import VmGuestShutdownEvent as VmGuestShutdownEvent
from .VmGuestStandbyEvent import VmGuestStandbyEvent as VmGuestStandbyEvent
from .VmHealthMonitoringStateChangedEvent import VmHealthMonitoringStateChangedEvent as VmHealthMonitoringStateChangedEvent
from .VmInstanceUuidAssignedEvent import VmInstanceUuidAssignedEvent as VmInstanceUuidAssignedEvent
from .VmInstanceUuidChangedEvent import VmInstanceUuidChangedEvent as VmInstanceUuidChangedEvent
from .VmInstanceUuidConflictEvent import VmInstanceUuidConflictEvent as VmInstanceUuidConflictEvent
from .VmMacAssignedEvent import VmMacAssignedEvent as VmMacAssignedEvent
from .VmMacChangedEvent import VmMacChangedEvent as VmMacChangedEvent
from .VmMacConflictEvent import VmMacConflictEvent as VmMacConflictEvent
from .VmMaxFTRestartCountReached import VmMaxFTRestartCountReached as VmMaxFTRestartCountReached
from .VmMaxRestartCountReached import VmMaxRestartCountReached as VmMaxRestartCountReached
from .VmMessageErrorEvent import VmMessageErrorEvent as VmMessageErrorEvent
from .VmMessageEvent import VmMessageEvent as VmMessageEvent
from .VmMessageWarningEvent import VmMessageWarningEvent as VmMessageWarningEvent
from .VmMigratedEvent import VmMigratedEvent as VmMigratedEvent
from .VmNoCompatibleHostForSecondaryEvent import VmNoCompatibleHostForSecondaryEvent as VmNoCompatibleHostForSecondaryEvent
from .VmNoNetworkAccessEvent import VmNoNetworkAccessEvent as VmNoNetworkAccessEvent
from .VmOrphanedEvent import VmOrphanedEvent as VmOrphanedEvent
from .VmPowerOffOnIsolationEvent import VmPowerOffOnIsolationEvent as VmPowerOffOnIsolationEvent
from .VmPoweredOffEvent import VmPoweredOffEvent as VmPoweredOffEvent
from .VmPoweredOnEvent import VmPoweredOnEvent as VmPoweredOnEvent
from .VmPoweringOnWithCustomizedDVPortEvent import VmPoweringOnWithCustomizedDVPortEvent as VmPoweringOnWithCustomizedDVPortEvent
from .VmPrimaryFailoverEvent import VmPrimaryFailoverEvent as VmPrimaryFailoverEvent
from .VmReconfiguredEvent import VmReconfiguredEvent as VmReconfiguredEvent
from .VmRegisteredEvent import VmRegisteredEvent as VmRegisteredEvent
from .VmRelayoutSuccessfulEvent import VmRelayoutSuccessfulEvent as VmRelayoutSuccessfulEvent
from .VmRelayoutUpToDateEvent import VmRelayoutUpToDateEvent as VmRelayoutUpToDateEvent
from .VmReloadFromPathEvent import VmReloadFromPathEvent as VmReloadFromPathEvent
from .VmReloadFromPathFailedEvent import VmReloadFromPathFailedEvent as VmReloadFromPathFailedEvent
from .VmRelocateFailedEvent import VmRelocateFailedEvent as VmRelocateFailedEvent
from .VmRelocateSpecEvent import VmRelocateSpecEvent as VmRelocateSpecEvent
from .VmRelocatedEvent import VmRelocatedEvent as VmRelocatedEvent
from .VmRemoteConsoleConnectedEvent import VmRemoteConsoleConnectedEvent as VmRemoteConsoleConnectedEvent
from .VmRemoteConsoleDisconnectedEvent import VmRemoteConsoleDisconnectedEvent as VmRemoteConsoleDisconnectedEvent
from .VmRemovedEvent import VmRemovedEvent as VmRemovedEvent
from .VmRenamedEvent import VmRenamedEvent as VmRenamedEvent
from .VmRequirementsExceedCurrentEVCModeEvent import VmRequirementsExceedCurrentEVCModeEvent as VmRequirementsExceedCurrentEVCModeEvent
from .VmResettingEvent import VmResettingEvent as VmResettingEvent
from .VmResourcePoolMovedEvent import VmResourcePoolMovedEvent as VmResourcePoolMovedEvent
from .VmResourceReallocatedEvent import VmResourceReallocatedEvent as VmResourceReallocatedEvent
from .VmRestartedOnAlternateHostEvent import VmRestartedOnAlternateHostEvent as VmRestartedOnAlternateHostEvent
from .VmResumingEvent import VmResumingEvent as VmResumingEvent
from .VmSecondaryAddedEvent import VmSecondaryAddedEvent as VmSecondaryAddedEvent
from .VmSecondaryDisabledBySystemEvent import VmSecondaryDisabledBySystemEvent as VmSecondaryDisabledBySystemEvent
from .VmSecondaryDisabledEvent import VmSecondaryDisabledEvent as VmSecondaryDisabledEvent
from .VmSecondaryEnabledEvent import VmSecondaryEnabledEvent as VmSecondaryEnabledEvent
from .VmSecondaryStartedEvent import VmSecondaryStartedEvent as VmSecondaryStartedEvent
from .VmShutdownOnIsolationEvent import VmShutdownOnIsolationEvent as VmShutdownOnIsolationEvent
from .VmStartRecordingEvent import VmStartRecordingEvent as VmStartRecordingEvent
from .VmStartReplayingEvent import VmStartReplayingEvent as VmStartReplayingEvent
from .VmStartingEvent import VmStartingEvent as VmStartingEvent
from .VmStartingSecondaryEvent import VmStartingSecondaryEvent as VmStartingSecondaryEvent
from .VmStaticMacConflictEvent import VmStaticMacConflictEvent as VmStaticMacConflictEvent
from .VmStoppingEvent import VmStoppingEvent as VmStoppingEvent
from .VmSuspendedEvent import VmSuspendedEvent as VmSuspendedEvent
from .VmSuspendingEvent import VmSuspendingEvent as VmSuspendingEvent
from .VmTimedoutStartingSecondaryEvent import VmTimedoutStartingSecondaryEvent as VmTimedoutStartingSecondaryEvent
from .VmUnsupportedStartingEvent import VmUnsupportedStartingEvent as VmUnsupportedStartingEvent
from .VmUpgradeCompleteEvent import VmUpgradeCompleteEvent as VmUpgradeCompleteEvent
from .VmUpgradeFailedEvent import VmUpgradeFailedEvent as VmUpgradeFailedEvent
from .VmUpgradingEvent import VmUpgradingEvent as VmUpgradingEvent
from .VmUuidAssignedEvent import VmUuidAssignedEvent as VmUuidAssignedEvent
from .VmUuidChangedEvent import VmUuidChangedEvent as VmUuidChangedEvent
from .VmUuidConflictEvent import VmUuidConflictEvent as VmUuidConflictEvent
from .VmVnicPoolReservationViolationClearEvent import VmVnicPoolReservationViolationClearEvent as VmVnicPoolReservationViolationClearEvent
from .VmVnicPoolReservationViolationRaiseEvent import VmVnicPoolReservationViolationRaiseEvent as VmVnicPoolReservationViolationRaiseEvent
from .VmWwnAssignedEvent import VmWwnAssignedEvent as VmWwnAssignedEvent
from .VmWwnChangedEvent import VmWwnChangedEvent as VmWwnChangedEvent
from .VmWwnConflictEvent import VmWwnConflictEvent as VmWwnConflictEvent
from .VnicPortArgument import VnicPortArgument as VnicPortArgument
from .WarningUpgradeEvent import WarningUpgradeEvent as WarningUpgradeEvent
from .iScsiBootFailureEvent import iScsiBootFailureEvent as iScsiBootFailureEvent
