# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .ActiveDirectoryAuthentication import ActiveDirectoryAuthentication as ActiveDirectoryAuthentication
from .ActiveDirectoryInfo import ActiveDirectoryInfo as ActiveDirectoryInfo
from .ActiveDirectorySpec import ActiveDirectorySpec as ActiveDirectorySpec
from .AssignableHardwareBinding import AssignableHardwareBinding as AssignableHardwareBinding
from .AssignableHardwareConfig import AssignableHardwareConfig as AssignableHardwareConfig
from .AssignableHardwareManager import AssignableHardwareManager as AssignableHardwareManager
from .AuthenticationInfo import AuthenticationInfo as AuthenticationInfo
from .AuthenticationManager import AuthenticationManager as AuthenticationManager
from .AuthenticationManagerInfo import AuthenticationManagerInfo as AuthenticationManagerInfo
from .AuthenticationStore import AuthenticationStore as AuthenticationStore
from .AuthenticationStoreInfo import AuthenticationStoreInfo as AuthenticationStoreInfo
from .AutoStartManager import AutoStartManager as AutoStartManager
from .BIOSInfo import BIOSInfo as BIOSInfo
from .BlockAdapterTargetTransport import BlockAdapterTargetTransport as BlockAdapterTargetTransport
from .BlockHba import BlockHba as BlockHba
from .BootDeviceInfo import BootDeviceInfo as BootDeviceInfo
from .BootDeviceSystem import BootDeviceSystem as BootDeviceSystem
from .CacheConfigurationManager import CacheConfigurationManager as CacheConfigurationManager
from .Capability import Capability as Capability
from .CertificateManager import CertificateManager as CertificateManager
from .ConfigChange import ConfigChange as ConfigChange
from .ConfigInfo import ConfigInfo as ConfigInfo
from .ConfigManager import ConfigManager as ConfigManager
from .ConfigSpec import ConfigSpec as ConfigSpec
from .ConnectInfo import ConnectInfo as ConnectInfo
from .ConnectSpec import ConnectSpec as ConnectSpec
from .CpuIdInfo import CpuIdInfo as CpuIdInfo
from .CpuInfo import CpuInfo as CpuInfo
from .CpuPackage import CpuPackage as CpuPackage
from .CpuPowerManagementInfo import CpuPowerManagementInfo as CpuPowerManagementInfo
from .CpuSchedulerSystem import CpuSchedulerSystem as CpuSchedulerSystem
from .DataTransportConnectionInfo import DataTransportConnectionInfo as DataTransportConnectionInfo
from .DatastoreBrowser import DatastoreBrowser as DatastoreBrowser
from .DatastoreSystem import DatastoreSystem as DatastoreSystem
from .DateTimeConfig import DateTimeConfig as DateTimeConfig
from .DateTimeInfo import DateTimeInfo as DateTimeInfo
from .DateTimeSystem import DateTimeSystem as DateTimeSystem
from .DeploymentInfo import DeploymentInfo as DeploymentInfo
from .Device import Device as Device
from .DevicePciId import DevicePciId as DevicePciId
from .DhcpService import DhcpService as DhcpService
from .DiagnosticPartition import DiagnosticPartition as DiagnosticPartition
from .DiagnosticSystem import DiagnosticSystem as DiagnosticSystem
from .DigestInfo import DigestInfo as DigestInfo
from .DigestVerificationSetting import DigestVerificationSetting as DigestVerificationSetting
from .DirectoryStore import DirectoryStore as DirectoryStore
from .DirectoryStoreInfo import DirectoryStoreInfo as DirectoryStoreInfo
from .DiskConfigurationResult import DiskConfigurationResult as DiskConfigurationResult
from .DiskDimensions import DiskDimensions as DiskDimensions
from .DiskPartitionInfo import DiskPartitionInfo as DiskPartitionInfo
from .DnsConfig import DnsConfig as DnsConfig
from .DnsConfigSpec import DnsConfigSpec as DnsConfigSpec
from .DvxClass import DvxClass as DvxClass
from .EnterMaintenanceResult import EnterMaintenanceResult as EnterMaintenanceResult
from .EsxAgentHostManager import EsxAgentHostManager as EsxAgentHostManager
from .FcoeConfig import FcoeConfig as FcoeConfig
from .FeatureCapability import FeatureCapability as FeatureCapability
from .FeatureMask import FeatureMask as FeatureMask
from .FeatureVersionInfo import FeatureVersionInfo as FeatureVersionInfo
from .FibreChannelHba import FibreChannelHba as FibreChannelHba
from .FibreChannelOverEthernetHba import FibreChannelOverEthernetHba as FibreChannelOverEthernetHba
from .FibreChannelOverEthernetTargetTransport import FibreChannelOverEthernetTargetTransport as FibreChannelOverEthernetTargetTransport
from .FibreChannelTargetTransport import FibreChannelTargetTransport as FibreChannelTargetTransport
from .FileAccess import FileAccess as FileAccess
from .FileSystemMountInfo import FileSystemMountInfo as FileSystemMountInfo
from .FileSystemVolume import FileSystemVolume as FileSystemVolume
from .FileSystemVolumeInfo import FileSystemVolumeInfo as FileSystemVolumeInfo
from .FirewallConfig import FirewallConfig as FirewallConfig
from .FirewallInfo import FirewallInfo as FirewallInfo
from .FirewallSystem import FirewallSystem as FirewallSystem
from .FirmwareSystem import FirmwareSystem as FirmwareSystem
from .FlagInfo import FlagInfo as FlagInfo
from .ForceMountedInfo import ForceMountedInfo as ForceMountedInfo
from .Fru import Fru as Fru
from .GatewaySpec import GatewaySpec as GatewaySpec
from .GraphicsConfig import GraphicsConfig as GraphicsConfig
from .GraphicsInfo import GraphicsInfo as GraphicsInfo
from .GraphicsManager import GraphicsManager as GraphicsManager
from .HardwareInfo import HardwareInfo as HardwareInfo
from .HardwareStatusInfo import HardwareStatusInfo as HardwareStatusInfo
from .HbaCreateSpec import HbaCreateSpec as HbaCreateSpec
from .HealthStatusSystem import HealthStatusSystem as HealthStatusSystem
from .HostAccessManager import HostAccessManager as HostAccessManager
from .HostBusAdapter import HostBusAdapter as HostBusAdapter
from .HostProxySwitch import HostProxySwitch as HostProxySwitch
from .HostSpbm import HostSpbm as HostSpbm
from .HostSpbmDatastoreInfo import HostSpbmDatastoreInfo as HostSpbmDatastoreInfo
from .HostSpbmHashInfo import HostSpbmHashInfo as HostSpbmHashInfo
from .HostSpbmPolicyBlobInfo import HostSpbmPolicyBlobInfo as HostSpbmPolicyBlobInfo
from .HostSpbmPolicyInfo import HostSpbmPolicyInfo as HostSpbmPolicyInfo
from .ImageConfigManager import ImageConfigManager as ImageConfigManager
from .InternetScsiHba import InternetScsiHba as InternetScsiHba
from .InternetScsiTargetTransport import InternetScsiTargetTransport as InternetScsiTargetTransport
from .IpConfig import IpConfig as IpConfig
from .IpRouteConfig import IpRouteConfig as IpRouteConfig
from .IpRouteConfigSpec import IpRouteConfigSpec as IpRouteConfigSpec
from .IpRouteEntry import IpRouteEntry as IpRouteEntry
from .IpRouteOp import IpRouteOp as IpRouteOp
from .IpRouteTableConfig import IpRouteTableConfig as IpRouteTableConfig
from .IpRouteTableInfo import IpRouteTableInfo as IpRouteTableInfo
from .IpmiInfo import IpmiInfo as IpmiInfo
from .IscsiManager import IscsiManager as IscsiManager
from .KernelModuleSystem import KernelModuleSystem as KernelModuleSystem
from .LACPInfo import LACPInfo as LACPInfo
from .LAGInfo import LAGInfo as LAGInfo
from .LAGUplinkInfo import LAGUplinkInfo as LAGUplinkInfo
from .LicenseSpec import LicenseSpec as LicenseSpec
from .LinkDiscoveryProtocolConfig import LinkDiscoveryProtocolConfig as LinkDiscoveryProtocolConfig
from .LocalAccountManager import LocalAccountManager as LocalAccountManager
from .LocalAuthentication import LocalAuthentication as LocalAuthentication
from .LocalAuthenticationInfo import LocalAuthenticationInfo as LocalAuthenticationInfo
from .LocalDatastoreInfo import LocalDatastoreInfo as LocalDatastoreInfo
from .LocalFileSystemVolume import LocalFileSystemVolume as LocalFileSystemVolume
from .MaintenanceSpec import MaintenanceSpec as MaintenanceSpec
from .MemoryManagerSystem import MemoryManagerSystem as MemoryManagerSystem
from .MemorySpec import MemorySpec as MemorySpec
from .MemoryTierFlags import MemoryTierFlags as MemoryTierFlags
from .MemoryTierInfo import MemoryTierInfo as MemoryTierInfo
from .MemoryTierType import MemoryTierType as MemoryTierType
from .MemoryTieringType import MemoryTieringType as MemoryTieringType
from .MessageBusProxy import MessageBusProxy as MessageBusProxy
from .MountInfo import MountInfo as MountInfo
from .MultipathInfo import MultipathInfo as MultipathInfo
from .MultipathStateInfo import MultipathStateInfo as MultipathStateInfo
from .NasDatastoreInfo import NasDatastoreInfo as NasDatastoreInfo
from .NasVolume import NasVolume as NasVolume
from .NatService import NatService as NatService
from .NetCapabilities import NetCapabilities as NetCapabilities
from .NetOffloadCapabilities import NetOffloadCapabilities as NetOffloadCapabilities
from .NetStackInstance import NetStackInstance as NetStackInstance
from .NetworkConfig import NetworkConfig as NetworkConfig
from .NetworkInfo import NetworkInfo as NetworkInfo
from .NetworkPolicy import NetworkPolicy as NetworkPolicy
from .NetworkSystem import NetworkSystem as NetworkSystem
from .NfcConnectionInfo import NfcConnectionInfo as NfcConnectionInfo
from .NtpConfig import NtpConfig as NtpConfig
from .NumaInfo import NumaInfo as NumaInfo
from .NumaNode import NumaNode as NumaNode
from .NumericSensorInfo import NumericSensorInfo as NumericSensorInfo
from .NvdimmSystem import NvdimmSystem as NvdimmSystem
from .NvmeConnectSpec import NvmeConnectSpec as NvmeConnectSpec
from .NvmeController import NvmeController as NvmeController
from .NvmeDisconnectSpec import NvmeDisconnectSpec as NvmeDisconnectSpec
from .NvmeDiscoverSpec import NvmeDiscoverSpec as NvmeDiscoverSpec
from .NvmeDiscoveryLog import NvmeDiscoveryLog as NvmeDiscoveryLog
from .NvmeNamespace import NvmeNamespace as NvmeNamespace
from .NvmeOpaqueTransportParameters import NvmeOpaqueTransportParameters as NvmeOpaqueTransportParameters
from .NvmeOverFibreChannelParameters import NvmeOverFibreChannelParameters as NvmeOverFibreChannelParameters
from .NvmeOverRdmaParameters import NvmeOverRdmaParameters as NvmeOverRdmaParameters
from .NvmeOverTcpParameters import NvmeOverTcpParameters as NvmeOverTcpParameters
from .NvmeSpec import NvmeSpec as NvmeSpec
from .NvmeTopology import NvmeTopology as NvmeTopology
from .NvmeTransportParameters import NvmeTransportParameters as NvmeTransportParameters
from .NvmeTransportType import NvmeTransportType as NvmeTransportType
from .OpaqueNetworkInfo import OpaqueNetworkInfo as OpaqueNetworkInfo
from .OpaqueSwitch import OpaqueSwitch as OpaqueSwitch
from .PMemDatastoreInfo import PMemDatastoreInfo as PMemDatastoreInfo
from .PMemVolume import PMemVolume as PMemVolume
from .ParallelScsiHba import ParallelScsiHba as ParallelScsiHba
from .ParallelScsiTargetTransport import ParallelScsiTargetTransport as ParallelScsiTargetTransport
from .PartialMaintenanceModeId import PartialMaintenanceModeId as PartialMaintenanceModeId
from .PartialMaintenanceModeRuntimeInfo import PartialMaintenanceModeRuntimeInfo as PartialMaintenanceModeRuntimeInfo
from .PartialMaintenanceModeStatus import PartialMaintenanceModeStatus as PartialMaintenanceModeStatus
from .PatchManager import PatchManager as PatchManager
from .PathSelectionPolicyOption import PathSelectionPolicyOption as PathSelectionPolicyOption
from .PciDevice import PciDevice as PciDevice
from .PciPassthruConfig import PciPassthruConfig as PciPassthruConfig
from .PciPassthruInfo import PciPassthruInfo as PciPassthruInfo
from .PciPassthruSystem import PciPassthruSystem as PciPassthruSystem
from .PcieHba import PcieHba as PcieHba
from .PcieTargetTransport import PcieTargetTransport as PcieTargetTransport
from .PersistentMemoryInfo import PersistentMemoryInfo as PersistentMemoryInfo
from .PhysicalNic import PhysicalNic as PhysicalNic
from .PlugStoreTopology import PlugStoreTopology as PlugStoreTopology
from .PnicTSOInfo import PnicTSOInfo as PnicTSOInfo
from .PortGroup import PortGroup as PortGroup
from .PowerSystem import PowerSystem as PowerSystem
from .ProtocolEndpoint import ProtocolEndpoint as ProtocolEndpoint
from .PtpConfig import PtpConfig as PtpConfig
from .QualifiedName import QualifiedName as QualifiedName
from .RdmaDevice import RdmaDevice as RdmaDevice
from .RdmaHba import RdmaHba as RdmaHba
from .RdmaProtocol import RdmaProtocol as RdmaProtocol
from .RdmaTargetTransport import RdmaTargetTransport as RdmaTargetTransport
from .ReliableMemoryInfo import ReliableMemoryInfo as ReliableMemoryInfo
from .ResignatureRescanResult import ResignatureRescanResult as ResignatureRescanResult
from .Ruleset import Ruleset as Ruleset
from .RuntimeInfo import RuntimeInfo as RuntimeInfo
from .ScsiDisk import ScsiDisk as ScsiDisk
from .ScsiLun import ScsiLun as ScsiLun
from .ScsiTopology import ScsiTopology as ScsiTopology
from .SecuritySpec import SecuritySpec as SecuritySpec
from .SerialAttachedHba import SerialAttachedHba as SerialAttachedHba
from .SerialAttachedTargetTransport import SerialAttachedTargetTransport as SerialAttachedTargetTransport
from .Service import Service as Service
from .ServiceConfig import ServiceConfig as ServiceConfig
from .ServiceInfo import ServiceInfo as ServiceInfo
from .ServiceSystem import ServiceSystem as ServiceSystem
from .SevInfo import SevInfo as SevInfo
from .SgxInfo import SgxInfo as SgxInfo
from .SgxRegistrationInfo import SgxRegistrationInfo as SgxRegistrationInfo
from .SharedGpuCapabilities import SharedGpuCapabilities as SharedGpuCapabilities
from .SnmpSystem import SnmpSystem as SnmpSystem
from .SoftwarePackage import SoftwarePackage as SoftwarePackage
from .SriovConfig import SriovConfig as SriovConfig
from .SriovDevicePoolInfo import SriovDevicePoolInfo as SriovDevicePoolInfo
from .SriovInfo import SriovInfo as SriovInfo
from .SriovNetworkDevicePoolInfo import SriovNetworkDevicePoolInfo as SriovNetworkDevicePoolInfo
from .SslThumbprintInfo import SslThumbprintInfo as SslThumbprintInfo
from .StorageArrayTypePolicyOption import StorageArrayTypePolicyOption as StorageArrayTypePolicyOption
from .StorageDeviceInfo import StorageDeviceInfo as StorageDeviceInfo
from .StorageProtocol import StorageProtocol as StorageProtocol
from .StorageSystem import StorageSystem as StorageSystem
from .Summary import Summary as Summary
from .SystemEventInfo import SystemEventInfo as SystemEventInfo
from .SystemHealthInfo import SystemHealthInfo as SystemHealthInfo
from .SystemIdentificationInfo import SystemIdentificationInfo as SystemIdentificationInfo
from .SystemInfo import SystemInfo as SystemInfo
from .SystemResourceInfo import SystemResourceInfo as SystemResourceInfo
from .SystemSwapConfiguration import SystemSwapConfiguration as SystemSwapConfiguration
from .TargetTransport import TargetTransport as TargetTransport
from .TcpHba import TcpHba as TcpHba
from .TcpHbaCreateSpec import TcpHbaCreateSpec as TcpHbaCreateSpec
from .TcpTargetTransport import TcpTargetTransport as TcpTargetTransport
from .TdxInfo import TdxInfo as TdxInfo
from .TpmAttestationInfo import TpmAttestationInfo as TpmAttestationInfo
from .TpmAttestationReport import TpmAttestationReport as TpmAttestationReport
from .TpmBootCompleteEventDetails import TpmBootCompleteEventDetails as TpmBootCompleteEventDetails
from .TpmBootSecurityOptionEventDetails import TpmBootSecurityOptionEventDetails as TpmBootSecurityOptionEventDetails
from .TpmCommandEventDetails import TpmCommandEventDetails as TpmCommandEventDetails
from .TpmDigestInfo import TpmDigestInfo as TpmDigestInfo
from .TpmEventDetails import TpmEventDetails as TpmEventDetails
from .TpmEventLogEntry import TpmEventLogEntry as TpmEventLogEntry
from .TpmNvTagEventDetails import TpmNvTagEventDetails as TpmNvTagEventDetails
from .TpmOptionEventDetails import TpmOptionEventDetails as TpmOptionEventDetails
from .TpmSignerEventDetails import TpmSignerEventDetails as TpmSignerEventDetails
from .TpmSoftwareComponentEventDetails import TpmSoftwareComponentEventDetails as TpmSoftwareComponentEventDetails
from .TpmVersionEventDetails import TpmVersionEventDetails as TpmVersionEventDetails
from .TrustAuthorityAttestationInfo import TrustAuthorityAttestationInfo as TrustAuthorityAttestationInfo
from .UnresolvedVmfsExtent import UnresolvedVmfsExtent as UnresolvedVmfsExtent
from .UnresolvedVmfsResignatureSpec import UnresolvedVmfsResignatureSpec as UnresolvedVmfsResignatureSpec
from .UnresolvedVmfsResolutionResult import UnresolvedVmfsResolutionResult as UnresolvedVmfsResolutionResult
from .UnresolvedVmfsResolutionSpec import UnresolvedVmfsResolutionSpec as UnresolvedVmfsResolutionSpec
from .UnresolvedVmfsVolume import UnresolvedVmfsVolume as UnresolvedVmfsVolume
from .VFlashManager import VFlashManager as VFlashManager
from .VFlashResourceConfigurationResult import VFlashResourceConfigurationResult as VFlashResourceConfigurationResult
from .VMotionConfig import VMotionConfig as VMotionConfig
from .VMotionInfo import VMotionInfo as VMotionInfo
from .VMotionSystem import VMotionSystem as VMotionSystem
from .VSANStretchedClusterHostCapability import VSANStretchedClusterHostCapability as VSANStretchedClusterHostCapability
from .VfatVolume import VfatVolume as VfatVolume
from .VffsVolume import VffsVolume as VffsVolume
from .VirtualNic import VirtualNic as VirtualNic
from .VirtualNicConnection import VirtualNicConnection as VirtualNicConnection
from .VirtualNicManager import VirtualNicManager as VirtualNicManager
from .VirtualNicManagerInfo import VirtualNicManagerInfo as VirtualNicManagerInfo
from .VirtualSwitch import VirtualSwitch as VirtualSwitch
from .VmfsDatastoreCreateSpec import VmfsDatastoreCreateSpec as VmfsDatastoreCreateSpec
from .VmfsDatastoreExpandSpec import VmfsDatastoreExpandSpec as VmfsDatastoreExpandSpec
from .VmfsDatastoreExtendSpec import VmfsDatastoreExtendSpec as VmfsDatastoreExtendSpec
from .VmfsDatastoreInfo import VmfsDatastoreInfo as VmfsDatastoreInfo
from .VmfsDatastoreOption import VmfsDatastoreOption as VmfsDatastoreOption
from .VmfsDatastoreSpec import VmfsDatastoreSpec as VmfsDatastoreSpec
from .VmfsRescanResult import VmfsRescanResult as VmfsRescanResult
from .VmfsVolume import VmfsVolume as VmfsVolume
from .VsanBasicDeviceInfo import VsanBasicDeviceInfo as VsanBasicDeviceInfo
from .VsanClusterMembershipInfo import VsanClusterMembershipInfo as VsanClusterMembershipInfo
from .VsanControllerType import VsanControllerType as VsanControllerType
from .VsanDaemonHealth import VsanDaemonHealth as VsanDaemonHealth
from .VsanDatastoreInfo import VsanDatastoreInfo as VsanDatastoreInfo
from .VsanDiskBalanceState import VsanDiskBalanceState as VsanDiskBalanceState
from .VsanDiskEncryptionHealth import VsanDiskEncryptionHealth as VsanDiskEncryptionHealth
from .VsanDiskRebalanceResult import VsanDiskRebalanceResult as VsanDiskRebalanceResult
from .VsanDitEncryptionHealthSummary import VsanDitEncryptionHealthSummary as VsanDitEncryptionHealthSummary
from .VsanEncryptionHealthSummary import VsanEncryptionHealthSummary as VsanEncryptionHealthSummary
from .VsanEncryptionIssue import VsanEncryptionIssue as VsanEncryptionIssue
from .VsanFailedRepairObjectResult import VsanFailedRepairObjectResult as VsanFailedRepairObjectResult
from .VsanFileServerHealthSummary import VsanFileServerHealthSummary as VsanFileServerHealthSummary
from .VsanFileServiceBalanceHealth import VsanFileServiceBalanceHealth as VsanFileServiceBalanceHealth
from .VsanFileServiceHealthSummary import VsanFileServiceHealthSummary as VsanFileServiceHealthSummary
from .VsanFileServiceRootFsHealth import VsanFileServiceRootFsHealth as VsanFileServiceRootFsHealth
from .VsanFileServiceShareHealthSummary import VsanFileServiceShareHealthSummary as VsanFileServiceShareHealthSummary
from .VsanHclCommonDeviceInfo import VsanHclCommonDeviceInfo as VsanHclCommonDeviceInfo
from .VsanHclComputeResource import VsanHclComputeResource as VsanHclComputeResource
from .VsanHclControllerInfo import VsanHclControllerInfo as VsanHclControllerInfo
from .VsanHclDiskInfo import VsanHclDiskInfo as VsanHclDiskInfo
from .VsanHclFirmwareFile import VsanHclFirmwareFile as VsanHclFirmwareFile
from .VsanHclFirmwareUpdateSpec import VsanHclFirmwareUpdateSpec as VsanHclFirmwareUpdateSpec
from .VsanHclMemInfo import VsanHclMemInfo as VsanHclMemInfo
from .VsanHclNicInfo import VsanHclNicInfo as VsanHclNicInfo
from .VsanHealthQuerySpec import VsanHealthQuerySpec as VsanHealthQuerySpec
from .VsanHealthSystem import VsanHealthSystem as VsanHealthSystem
from .VsanHostCimProviderInfo import VsanHostCimProviderInfo as VsanHostCimProviderInfo
from .VsanHostEMMSummary import VsanHostEMMSummary as VsanHostEMMSummary
from .VsanHostFwComponent import VsanHostFwComponent as VsanHostFwComponent
from .VsanHostGlobalDedupConfigHealthSummary import VsanHostGlobalDedupConfigHealthSummary as VsanHostGlobalDedupConfigHealthSummary
from .VsanHostHclInfo import VsanHostHclInfo as VsanHostHclInfo
from .VsanHostHealthSystemStatusResult import VsanHostHealthSystemStatusResult as VsanHostHealthSystemStatusResult
from .VsanHostHwDeviceId import VsanHostHwDeviceId as VsanHostHwDeviceId
from .VsanHostIoInsightInfo import VsanHostIoInsightInfo as VsanHostIoInsightInfo
from .VsanHostQueryCheckLimitsOptionType import VsanHostQueryCheckLimitsOptionType as VsanHostQueryCheckLimitsOptionType
from .VsanHostQueryCheckLimitsSpec import VsanHostQueryCheckLimitsSpec as VsanHostQueryCheckLimitsSpec
from .VsanHostReference import VsanHostReference as VsanHostReference
from .VsanHostVirtualApplianceInfo import VsanHostVirtualApplianceInfo as VsanHostVirtualApplianceInfo
from .VsanHostVmdkLoadTestResult import VsanHostVmdkLoadTestResult as VsanHostVmdkLoadTestResult
from .VsanHwToVcgInfoMapping import VsanHwToVcgInfoMapping as VsanHwToVcgInfoMapping
from .VsanInternalSystem import VsanInternalSystem as VsanInternalSystem
from .VsanIoInsightInfo import VsanIoInsightInfo as VsanIoInsightInfo
from .VsanIoInsightState import VsanIoInsightState as VsanIoInsightState
from .VsanIperfClientSpec import VsanIperfClientSpec as VsanIperfClientSpec
from .VsanKmsHealth import VsanKmsHealth as VsanKmsHealth
from .VsanLimitHealthResult import VsanLimitHealthResult as VsanLimitHealthResult
from .VsanNetworkDiagnosticsHealthInfo import VsanNetworkDiagnosticsHealthInfo as VsanNetworkDiagnosticsHealthInfo
from .VsanNetworkHealthResult import VsanNetworkHealthResult as VsanNetworkHealthResult
from .VsanNetworkLoadTestResult import VsanNetworkLoadTestResult as VsanNetworkLoadTestResult
from .VsanNetworkPeerHealthResult import VsanNetworkPeerHealthResult as VsanNetworkPeerHealthResult
from .VsanNicRdmaInfo import VsanNicRdmaInfo as VsanNicRdmaInfo
from .VsanObjectHealth import VsanObjectHealth as VsanObjectHealth
from .VsanObjectOverallHealth import VsanObjectOverallHealth as VsanObjectOverallHealth
from .VsanPeerHostConnectivityHealthState import VsanPeerHostConnectivityHealthState as VsanPeerHostConnectivityHealthState
from .VsanPhysicalDiskHealth import VsanPhysicalDiskHealth as VsanPhysicalDiskHealth
from .VsanPhysicalDiskHealthSummary import VsanPhysicalDiskHealthSummary as VsanPhysicalDiskHealthSummary
from .VsanProactiveRebalanceInfoEx import VsanProactiveRebalanceInfoEx as VsanProactiveRebalanceInfoEx
from .VsanQueryResultHostInfo import VsanQueryResultHostInfo as VsanQueryResultHostInfo
from .VsanRepairObjectsResult import VsanRepairObjectsResult as VsanRepairObjectsResult
from .VsanResourceHealth import VsanResourceHealth as VsanResourceHealth
from .VsanServerClusterInfo import VsanServerClusterInfo as VsanServerClusterInfo
from .VsanSmartDiskStats import VsanSmartDiskStats as VsanSmartDiskStats
from .VsanSmartParameter import VsanSmartParameter as VsanSmartParameter
from .VsanSmartParameterType import VsanSmartParameterType as VsanSmartParameterType
from .VsanSmartStatsHostSummary import VsanSmartStatsHostSummary as VsanSmartStatsHostSummary
from .VsanSystem import VsanSystem as VsanSystem
from .VsanSystemEx import VsanSystemEx as VsanSystemEx
from .VsanUpdateManager import VsanUpdateManager as VsanUpdateManager
from .VsanVcgDeviceInfo import VsanVcgDeviceInfo as VsanVcgDeviceInfo
from .VsanVcsaDeployerSystem import VsanVcsaDeployerSystem as VsanVcsaDeployerSystem
from .VsanVmdkIOLoadSpec import VsanVmdkIOLoadSpec as VsanVmdkIOLoadSpec
from .VsanVmdkLoadTestResult import VsanVmdkLoadTestResult as VsanVmdkLoadTestResult
from .VsanVmdkLoadTestSpec import VsanVmdkLoadTestSpec as VsanVmdkLoadTestSpec
from .VsanVsanPcapResult import VsanVsanPcapResult as VsanVsanPcapResult
from .VvolDatastoreInfo import VvolDatastoreInfo as VvolDatastoreInfo
from .VvolNQN import VvolNQN as VvolNQN
from .VvolVolume import VvolVolume as VvolVolume
