# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.fault import VmConfigFault

class QuarantineModeFault(VmConfigFault):
   class FaultType(Enum):
      NoCompatibleNonQuarantinedHost: ClassVar['FaultType'] = 'NoCompatibleNonQuarantinedHost'
      CorrectionDisallowed: ClassVar['FaultType'] = 'CorrectionDisallowed'
      CorrectionImpact: ClassVar['FaultType'] = 'CorrectionImpact'

   vmName: str
   faultType: str
