# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.profile.host import HostSubSpecification

class HostSpecification(DynamicData):
   createdTime: datetime
   lastModified: Optional[datetime] = None
   host: HostSystem
   subSpecs: list[HostSubSpecification] = []
   changeID: Optional[str] = None
