# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import replication as replication

from .AuthConnectionFailed import AuthConnectionFailed as AuthConnectionFailed
from .CertificateAuthorityFault import CertificateAuthorityFault as CertificateAuthorityFault
from .CertificateNotImported import CertificateNotImported as CertificateNotImported
from .CertificateNotTrusted import CertificateNotTrusted as CertificateNotTrusted
from .CertificateRefreshFailed import CertificateRefreshFailed as CertificateRefreshFailed
from .CertificateRevocationFailed import CertificateRevocationFailed as CertificateRevocationFailed
from .DuplicateEntry import DuplicateEntry as DuplicateEntry
from .InactiveProvider import InactiveProvider as InactiveProvider
from .IncorrectUsernamePassword import IncorrectUsernamePassword as IncorrectUsernamePassword
from .InvalidCertificate import InvalidCertificate as InvalidCertificate
from .InvalidLogin import InvalidLogin as InvalidLogin
from .InvalidProfile import InvalidProfile as InvalidProfile
from .InvalidSession import InvalidSession as InvalidSession
from .InvalidUrl import InvalidUrl as InvalidUrl
from .MultipleSortSpecsNotSupported import MultipleSortSpecsNotSupported as MultipleSortSpecsNotSupported
from .NoCommonProviderForAllBackings import NoCommonProviderForAllBackings as NoCommonProviderForAllBackings
from .NotSupportedByProvider import NotSupportedByProvider as NotSupportedByProvider
from .ProviderBusy import ProviderBusy as ProviderBusy
from .ProviderConnectionFailed import ProviderConnectionFailed as ProviderConnectionFailed
from .ProviderNotFound import ProviderNotFound as ProviderNotFound
from .ProviderOutOfProvisioningResource import ProviderOutOfProvisioningResource as ProviderOutOfProvisioningResource
from .ProviderOutOfResource import ProviderOutOfResource as ProviderOutOfResource
from .ProviderRegistrationFault import ProviderRegistrationFault as ProviderRegistrationFault
from .ProviderSyncFailed import ProviderSyncFailed as ProviderSyncFailed
from .ProviderUnavailable import ProviderUnavailable as ProviderUnavailable
from .ProviderUnregistrationFault import ProviderUnregistrationFault as ProviderUnregistrationFault
from .ProxyRegistrationFailed import ProxyRegistrationFailed as ProxyRegistrationFailed
from .QueryExecutionFault import QueryExecutionFault as QueryExecutionFault
from .QueryNotSupported import QueryNotSupported as QueryNotSupported
from .ResourceInUse import ResourceInUse as ResourceInUse
from .ServiceNotInitialized import ServiceNotInitialized as ServiceNotInitialized
from .SmsFault import SmsFault as SmsFault
from .SyncInProgress import SyncInProgress as SyncInProgress
from .TooMany import TooMany as TooMany
