# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AgentIssue import AgentIssue as AgentIssue
from .CertificateNotTrusted import CertificateNotTrusted as CertificateNotTrusted
from .HostInMaintenanceMode import HostInMaintenanceMode as HostInMaintenanceMode
from .HostInPartialMaintenanceMode import HostInPartialMaintenanceMode as HostInPartialMaintenanceMode
from .InsufficientClusterResources import InsufficientClusterResources as InsufficientClusterResources
from .InsufficientClusterSpace import InsufficientClusterSpace as InsufficientClusterSpace
from .InvalidConfig import InvalidConfig as InvalidConfig
from .MissingClusterVmDatastore import MissingClusterVmDatastore as MissingClusterVmDatastore
from .MissingClusterVmNetwork import MissingClusterVmNetwork as MissingClusterVmNetwork
from .OvfInvalidProperty import OvfInvalidProperty as OvfInvalidProperty
from .TransitionFailed import TransitionFailed as TransitionFailed
from .VmHookFailed import VmHookFailed as VmHookFailed
from .VmHookTimedout import VmHookTimedout as VmHookTimedout
from .VmInaccessible import VmInaccessible as VmInaccessible
from .VmIssue import VmIssue as VmIssue
from .VmNotDeployed import VmNotDeployed as VmNotDeployed
from .VmNotRemoved import VmNotRemoved as VmNotRemoved
from .VmPoweredOff import VmPoweredOff as VmPoweredOff
from .VmPoweredOn import VmPoweredOn as VmPoweredOn
from .VmProtected import VmProtected as VmProtected
from .VmSuspended import VmSuspended as VmSuspended
