# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

class ClusterPowerContext(DynamicData):
   currentClusterPowerStatus: str
   orderedClusterPowerStatus: list[str] = []
   trackingTask: Optional[Task] = None
   lastErrorMessage: Optional[LocalizableMessage] = None
   lastErrorMOs: list[ManagedObject] = []
