# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import FibreChannelHba

class FibreChannelOverEthernetHba(FibreChannelHba):
   class LinkInfo(DynamicData):
      vnportMac: str
      fcfMac: str
      vlanId: int

   underlyingNic: str
   linkInfo: LinkInfo
   isSoftwareFcoe: bool
   markedForRemoval: Optional[bool] = None
