# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import capability as capability
from . import dr as dr

from .InvalidProtectionReason import InvalidProtectionReason as InvalidProtectionReason
from .MigrationType import MigrationType as MigrationType
from .ProtectionStatusType import ProtectionStatusType as ProtectionStatusType
from .ProtectionSupportType import ProtectionSupportType as ProtectionSupportType
from .SnapshotType import SnapshotType as SnapshotType
from .SyncType import SyncType as SyncType
from .VSphereDataProtectionCapabilities import VSphereDataProtectionCapabilities as VSphereDataProtectionCapabilities
from .VssBackupContext import VssBackupContext as VssBackupContext
from .VssBackupType import VssBackupType as VssBackupType
