# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .CapabilityConstraintsRequirement import CapabilityConstraintsRequirement as CapabilityConstraintsRequirement
from .CapabilityProfileRequirement import CapabilityProfileRequirement as CapabilityProfileRequirement
from .CompatibilityResult import CompatibilityResult as CompatibilityResult
from .MatchingReplicationResources import MatchingReplicationResources as MatchingReplicationResources
from .MatchingResources import MatchingResources as MatchingResources
from .PlacementHub import PlacementHub as PlacementHub
from .PlacementSolver import PlacementSolver as PlacementSolver
from .Requirement import Requirement as Requirement
from .ResourceUtilization import ResourceUtilization as ResourceUtilization
