# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .CloneSpec import CloneSpec as CloneSpec
from .EntityConfigInfo import EntityConfigInfo as EntityConfigInfo
from .IPAssignmentInfo import IPAssignmentInfo as IPAssignmentInfo
from .IpPool import IpPool as IpPool
from .OvfSectionInfo import OvfSectionInfo as OvfSectionInfo
from .OvfSectionSpec import OvfSectionSpec as OvfSectionSpec
from .ProductInfo import ProductInfo as ProductInfo
from .ProductSpec import ProductSpec as ProductSpec
from .PropertyInfo import PropertyInfo as PropertyInfo
from .PropertySpec import PropertySpec as PropertySpec
from .VAppConfigInfo import VAppConfigInfo as VAppConfigInfo
from .VAppConfigSpec import VAppConfigSpec as VAppConfigSpec
from .VAppImportSpec import VAppImportSpec as VAppImportSpec
from .VmConfigInfo import VmConfigInfo as VmConfigInfo
from .VmConfigSpec import VmConfigSpec as VmConfigSpec
