# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanClusterWhatifHostFailuresResult

from pyVmomi.vim.host import VsanLimitHealthResult

class VsanClusterLimitHealthResult(DynamicData):
   issueFound: bool
   componentLimitHealth: str
   diskFreeSpaceHealth: str
   rcFreeReservationHealth: str
   hostResults: list[VsanLimitHealthResult] = []
   whatifHostFailures: list[VsanClusterWhatifHostFailuresResult] = []
   hostsCommFailure: list[str] = []
