# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.ext import ManagedByInfo

from pyVmomi.vim.vApp import EntityConfigInfo
from pyVmomi.vim.vApp import VmConfigSpec

class VAppConfigSpec(VmConfigSpec):
   entityConfig: list[EntityConfigInfo] = []
   annotation: Optional[str] = None
   instanceUuid: Optional[str] = None
   managedBy: Optional[ManagedByInfo] = None
