# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AgencyDisabled import AgencyDisabled as AgencyDisabled
from .AgencyIssue import AgencyIssue as AgencyIssue
from .AgentIssue import AgentIssue as AgentIssue
from .CannotAccessAgentOVF import CannotAccessAgentOVF as CannotAccessAgentOVF
from .CannotAccessAgentVib import CannotAccessAgentVib as CannotAccessAgentVib
from .CertificateNotTrusted import CertificateNotTrusted as CertificateNotTrusted
from .ExtensibleIssue import ExtensibleIssue as ExtensibleIssue
from .HostInMaintenanceMode import HostInMaintenanceMode as HostInMaintenanceMode
from .HostInPartialMaintenanceMode import HostInPartialMaintenanceMode as HostInPartialMaintenanceMode
from .HostInStandbyMode import HostInStandbyMode as HostInStandbyMode
from .HostIssue import HostIssue as HostIssue
from .HostNotReachable import HostNotReachable as HostNotReachable
from .HostPoweredOff import HostPoweredOff as HostPoweredOff
from .ImmediateHostRebootRequired import ImmediateHostRebootRequired as ImmediateHostRebootRequired
from .IncompatibleHostVersion import IncompatibleHostVersion as IncompatibleHostVersion
from .InsufficientIpAddresses import InsufficientIpAddresses as InsufficientIpAddresses
from .InsufficientResources import InsufficientResources as InsufficientResources
from .InsufficientSpace import InsufficientSpace as InsufficientSpace
from .InvalidConfig import InvalidConfig as InvalidConfig
from .Issue import Issue as Issue
from .MissingAgentIpPool import MissingAgentIpPool as MissingAgentIpPool
from .MissingDvFilterSwitch import MissingDvFilterSwitch as MissingDvFilterSwitch
from .NoAgentVmDatastore import NoAgentVmDatastore as NoAgentVmDatastore
from .NoAgentVmNetwork import NoAgentVmNetwork as NoAgentVmNetwork
from .NoCustomAgentVmDatastore import NoCustomAgentVmDatastore as NoCustomAgentVmDatastore
from .NoCustomAgentVmNetwork import NoCustomAgentVmNetwork as NoCustomAgentVmNetwork
from .NoDiscoverableAgentVmDatastore import NoDiscoverableAgentVmDatastore as NoDiscoverableAgentVmDatastore
from .NoDiscoverableAgentVmNetwork import NoDiscoverableAgentVmNetwork as NoDiscoverableAgentVmNetwork
from .OrphanedAgency import OrphanedAgency as OrphanedAgency
from .OrphanedDvFilterSwitch import OrphanedDvFilterSwitch as OrphanedDvFilterSwitch
from .OvfInvalidFormat import OvfInvalidFormat as OvfInvalidFormat
from .OvfInvalidProperty import OvfInvalidProperty as OvfInvalidProperty
from .TransitionFailed import TransitionFailed as TransitionFailed
from .UnknownAgentVm import UnknownAgentVm as UnknownAgentVm
from .VibCannotPutHostInMaintenanceMode import VibCannotPutHostInMaintenanceMode as VibCannotPutHostInMaintenanceMode
from .VibCannotPutHostOutOfMaintenanceMode import VibCannotPutHostOutOfMaintenanceMode as VibCannotPutHostOutOfMaintenanceMode
from .VibDependenciesNotMetByHost import VibDependenciesNotMetByHost as VibDependenciesNotMetByHost
from .VibInvalidFormat import VibInvalidFormat as VibInvalidFormat
from .VibIssue import VibIssue as VibIssue
from .VibNotInstalled import VibNotInstalled as VibNotInstalled
from .VibRequirementsNotMetByHost import VibRequirementsNotMetByHost as VibRequirementsNotMetByHost
from .VibRequiresHostInMaintenanceMode import VibRequiresHostInMaintenanceMode as VibRequiresHostInMaintenanceMode
from .VibRequiresHostReboot import VibRequiresHostReboot as VibRequiresHostReboot
from .VibRequiresManualInstallation import VibRequiresManualInstallation as VibRequiresManualInstallation
from .VibRequiresManualUninstallation import VibRequiresManualUninstallation as VibRequiresManualUninstallation
from .VmCorrupted import VmCorrupted as VmCorrupted
from .VmDeployed import VmDeployed as VmDeployed
from .VmHookFailed import VmHookFailed as VmHookFailed
from .VmHookTimedout import VmHookTimedout as VmHookTimedout
from .VmInaccessible import VmInaccessible as VmInaccessible
from .VmIssue import VmIssue as VmIssue
from .VmMarkedAsTemplate import VmMarkedAsTemplate as VmMarkedAsTemplate
from .VmNotDeployed import VmNotDeployed as VmNotDeployed
from .VmOrphaned import VmOrphaned as VmOrphaned
from .VmPoweredOff import VmPoweredOff as VmPoweredOff
from .VmPoweredOn import VmPoweredOn as VmPoweredOn
from .VmProtected import VmProtected as VmProtected
from .VmRequiresHostOutOfMaintenanceMode import VmRequiresHostOutOfMaintenanceMode as VmRequiresHostOutOfMaintenanceMode
from .VmSuspended import VmSuspended as VmSuspended
from .VmWrongFolder import VmWrongFolder as VmWrongFolder
from .VmWrongResourcePool import VmWrongResourcePool as VmWrongResourcePool
