# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AlreadyDone import AlreadyDone as AlreadyDone
from .InvalidFunctionTarget import InvalidFunctionTarget as InvalidFunctionTarget
from .InvalidReplicationState import InvalidReplicationState as InvalidReplicationState
from .NoReplicationTarget import NoReplicationTarget as NoReplicationTarget
from .NoValidReplica import NoValidReplica as NoValidReplica
from .PeerNotReachable import PeerNotReachable as PeerNotReachable
from .ReplicationFault import ReplicationFault as ReplicationFault
from .SyncOngoing import SyncOngoing as SyncOngoing
