# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .DistributedVirtualPort import DistributedVirtualPort as DistributedVirtualPort
from .DistributedVirtualPortgroup import DistributedVirtualPortgroup as DistributedVirtualPortgroup
from .DistributedVirtualPortgroupInfo import DistributedVirtualPortgroupInfo as DistributedVirtualPortgroupInfo
from .DistributedVirtualPortgroupSelection import DistributedVirtualPortgroupSelection as DistributedVirtualPortgroupSelection
from .DistributedVirtualSwitchInfo import DistributedVirtualSwitchInfo as DistributedVirtualSwitchInfo
from .DistributedVirtualSwitchManager import DistributedVirtualSwitchManager as DistributedVirtualSwitchManager
from .DistributedVirtualSwitchSelection import DistributedVirtualSwitchSelection as DistributedVirtualSwitchSelection
from .EntityBackup import EntityBackup as EntityBackup
from .HostMember import HostMember as HostMember
from .HostProductSpec import HostProductSpec as HostProductSpec
from .KeyedOpaqueBlob import KeyedOpaqueBlob as KeyedOpaqueBlob
from .NetworkOffloadSpec import NetworkOffloadSpec as NetworkOffloadSpec
from .NetworkResourcePool import NetworkResourcePool as NetworkResourcePool
from .PortConnectee import PortConnectee as PortConnectee
from .PortConnection import PortConnection as PortConnection
from .PortCriteria import PortCriteria as PortCriteria
from .PortStatistics import PortStatistics as PortStatistics
from .ProductSpec import ProductSpec as ProductSpec
from .TrafficRule import TrafficRule as TrafficRule
from .TrafficRuleset import TrafficRuleset as TrafficRuleset
from .VmVnicNetworkResourcePool import VmVnicNetworkResourcePool as VmVnicNetworkResourcePool
from .VmwareDistributedVirtualSwitch import VmwareDistributedVirtualSwitch as VmwareDistributedVirtualSwitch
