# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .Action import Action as Action
from .ActionHistory import ActionHistory as ActionHistory
from .AffinityRuleSpec import AffinityRuleSpec as AffinityRuleSpec
from .AntiAffinityRuleSpec import AntiAffinityRuleSpec as AntiAffinityRuleSpec
from .AttemptedVmInfo import AttemptedVmInfo as AttemptedVmInfo
from .ClusterInitialPlacementAction import ClusterInitialPlacementAction as ClusterInitialPlacementAction
from .ClusterPowerContext import ClusterPowerContext as ClusterPowerContext
from .ClusterPowerStatus import ClusterPowerStatus as ClusterPowerStatus
from .ConfigInfo import ConfigInfo as ConfigInfo
from .ConfigInfoEx import ConfigInfoEx as ConfigInfoEx
from .ConfigSpec import ConfigSpec as ConfigSpec
from .ConfigSpecEx import ConfigSpecEx as ConfigSpecEx
from .CryptoConfigInfo import CryptoConfigInfo as CryptoConfigInfo
from .DasAamHostInfo import DasAamHostInfo as DasAamHostInfo
from .DasAamNodeState import DasAamNodeState as DasAamNodeState
from .DasAdmissionControlInfo import DasAdmissionControlInfo as DasAdmissionControlInfo
from .DasAdmissionControlPolicy import DasAdmissionControlPolicy as DasAdmissionControlPolicy
from .DasAdvancedRuntimeInfo import DasAdvancedRuntimeInfo as DasAdvancedRuntimeInfo
from .DasConfigInfo import DasConfigInfo as DasConfigInfo
from .DasData import DasData as DasData
from .DasDataSummary import DasDataSummary as DasDataSummary
from .DasFailoverLevelAdvancedRuntimeInfo import DasFailoverLevelAdvancedRuntimeInfo as DasFailoverLevelAdvancedRuntimeInfo
from .DasFdmAvailabilityState import DasFdmAvailabilityState as DasFdmAvailabilityState
from .DasFdmHostState import DasFdmHostState as DasFdmHostState
from .DasHostInfo import DasHostInfo as DasHostInfo
from .DasHostRecommendation import DasHostRecommendation as DasHostRecommendation
from .DasVmConfigInfo import DasVmConfigInfo as DasVmConfigInfo
from .DasVmConfigSpec import DasVmConfigSpec as DasVmConfigSpec
from .DasVmSettings import DasVmSettings as DasVmSettings
from .DatastoreUpdateSpec import DatastoreUpdateSpec as DatastoreUpdateSpec
from .DependencyRuleInfo import DependencyRuleInfo as DependencyRuleInfo
from .DpmConfigInfo import DpmConfigInfo as DpmConfigInfo
from .DpmHostConfigInfo import DpmHostConfigInfo as DpmHostConfigInfo
from .DpmHostConfigSpec import DpmHostConfigSpec as DpmHostConfigSpec
from .DrsConfigInfo import DrsConfigInfo as DrsConfigInfo
from .DrsFaults import DrsFaults as DrsFaults
from .DrsMigration import DrsMigration as DrsMigration
from .DrsRecommendation import DrsRecommendation as DrsRecommendation
from .DrsVmConfigInfo import DrsVmConfigInfo as DrsVmConfigInfo
from .DrsVmConfigSpec import DrsVmConfigSpec as DrsVmConfigSpec
from .EVCManager import EVCManager as EVCManager
from .EnterMaintenanceResult import EnterMaintenanceResult as EnterMaintenanceResult
from .FailoverHostAdmissionControlInfo import FailoverHostAdmissionControlInfo as FailoverHostAdmissionControlInfo
from .FailoverHostAdmissionControlPolicy import FailoverHostAdmissionControlPolicy as FailoverHostAdmissionControlPolicy
from .FailoverLevelAdmissionControlInfo import FailoverLevelAdmissionControlInfo as FailoverLevelAdmissionControlInfo
from .FailoverLevelAdmissionControlPolicy import FailoverLevelAdmissionControlPolicy as FailoverLevelAdmissionControlPolicy
from .FailoverResourcesAdmissionControlInfo import FailoverResourcesAdmissionControlInfo as FailoverResourcesAdmissionControlInfo
from .FailoverResourcesAdmissionControlPolicy import FailoverResourcesAdmissionControlPolicy as FailoverResourcesAdmissionControlPolicy
from .FaultDomainDestroySpec import FaultDomainDestroySpec as FaultDomainDestroySpec
from .FaultDomainUpdateSpec import FaultDomainUpdateSpec as FaultDomainUpdateSpec
from .FixedSizeSlotPolicy import FixedSizeSlotPolicy as FixedSizeSlotPolicy
from .FtVmHostRuleInfo import FtVmHostRuleInfo as FtVmHostRuleInfo
from .GroupInfo import GroupInfo as GroupInfo
from .GroupSpec import GroupSpec as GroupSpec
from .HostGroup import HostGroup as HostGroup
from .HostInfraUpdateHaModeAction import HostInfraUpdateHaModeAction as HostInfraUpdateHaModeAction
from .HostPowerAction import HostPowerAction as HostPowerAction
from .HostRecommendation import HostRecommendation as HostRecommendation
from .InfraUpdateHaConfigInfo import InfraUpdateHaConfigInfo as InfraUpdateHaConfigInfo
from .InitialPlacementAction import InitialPlacementAction as InitialPlacementAction
from .MigrationAction import MigrationAction as MigrationAction
from .NotAttemptedVmInfo import NotAttemptedVmInfo as NotAttemptedVmInfo
from .OrchestrationInfo import OrchestrationInfo as OrchestrationInfo
from .PerformClusterPowerActionSpec import PerformClusterPowerActionSpec as PerformClusterPowerActionSpec
from .PlacementAction import PlacementAction as PlacementAction
from .PlacementResult import PlacementResult as PlacementResult
from .PlacementSpec import PlacementSpec as PlacementSpec
from .PowerOnVmOption import PowerOnVmOption as PowerOnVmOption
from .PowerOnVmResult import PowerOnVmResult as PowerOnVmResult
from .PreemptibleVmPairInfo import PreemptibleVmPairInfo as PreemptibleVmPairInfo
from .PreemptibleVmPairSpec import PreemptibleVmPairSpec as PreemptibleVmPairSpec
from .ProactiveDrsConfigInfo import ProactiveDrsConfigInfo as ProactiveDrsConfigInfo
from .QueryVsanManagedStorageSpaceUsageSpec import QueryVsanManagedStorageSpaceUsageSpec as QueryVsanManagedStorageSpaceUsageSpec
from .Recommendation import Recommendation as Recommendation
from .ResourceUsageSummary import ResourceUsageSummary as ResourceUsageSummary
from .RuleInfo import RuleInfo as RuleInfo
from .RuleSpec import RuleSpec as RuleSpec
from .SiteFaultDomain import SiteFaultDomain as SiteFaultDomain
from .SiteFaultDomainConfig import SiteFaultDomainConfig as SiteFaultDomainConfig
from .SlotPolicy import SlotPolicy as SlotPolicy
from .StorageComplianceResult import StorageComplianceResult as StorageComplianceResult
from .StorageOperationalStatus import StorageOperationalStatus as StorageOperationalStatus
from .StoragePolicyStatus import StoragePolicyStatus as StoragePolicyStatus
from .SystemVMsConfigInfo import SystemVMsConfigInfo as SystemVMsConfigInfo
from .SystemVMsConfigSpec import SystemVMsConfigSpec as SystemVMsConfigSpec
from .TagCategoryUpdateSpec import TagCategoryUpdateSpec as TagCategoryUpdateSpec
from .UsageSummary import UsageSummary as UsageSummary
from .VSANPreferredFaultDomainInfo import VSANPreferredFaultDomainInfo as VSANPreferredFaultDomainInfo
from .VSANStretchedClusterCapability import VSANStretchedClusterCapability as VSANStretchedClusterCapability
from .VSANStretchedClusterFaultDomainConfig import VSANStretchedClusterFaultDomainConfig as VSANStretchedClusterFaultDomainConfig
from .VSANStretchedClusterHostVirtualApplianceStatus import VSANStretchedClusterHostVirtualApplianceStatus as VSANStretchedClusterHostVirtualApplianceStatus
from .VSANWitnessHostInfo import VSANWitnessHostInfo as VSANWitnessHostInfo
from .VmComponentProtectionSettings import VmComponentProtectionSettings as VmComponentProtectionSettings
from .VmGroup import VmGroup as VmGroup
from .VmHostRuleInfo import VmHostRuleInfo as VmHostRuleInfo
from .VmOrchestrationInfo import VmOrchestrationInfo as VmOrchestrationInfo
from .VmOrchestrationSpec import VmOrchestrationSpec as VmOrchestrationSpec
from .VmReadiness import VmReadiness as VmReadiness
from .VmToolsMonitoringSettings import VmToolsMonitoringSettings as VmToolsMonitoringSettings
from .VsanAttachToSrOperation import VsanAttachToSrOperation as VsanAttachToSrOperation
from .VsanBaselinePreferenceType import VsanBaselinePreferenceType as VsanBaselinePreferenceType
from .VsanCapability import VsanCapability as VsanCapability
from .VsanCapabilityStatus import VsanCapabilityStatus as VsanCapabilityStatus
from .VsanCapabilitySystem import VsanCapabilitySystem as VsanCapabilitySystem
from .VsanCapabilityType import VsanCapabilityType as VsanCapabilityType
from .VsanCapabilityType90 import VsanCapabilityType90 as VsanCapabilityType90
from .VsanClusterAdvCfgSyncHostResult import VsanClusterAdvCfgSyncHostResult as VsanClusterAdvCfgSyncHostResult
from .VsanClusterAdvCfgSyncResult import VsanClusterAdvCfgSyncResult as VsanClusterAdvCfgSyncResult
from .VsanClusterBalancePerDiskInfo import VsanClusterBalancePerDiskInfo as VsanClusterBalancePerDiskInfo
from .VsanClusterBalanceSummary import VsanClusterBalanceSummary as VsanClusterBalanceSummary
from .VsanClusterClomdLivenessResult import VsanClusterClomdLivenessResult as VsanClusterClomdLivenessResult
from .VsanClusterConfig import VsanClusterConfig as VsanClusterConfig
from .VsanClusterCreateVmHealthTestResult import VsanClusterCreateVmHealthTestResult as VsanClusterCreateVmHealthTestResult
from .VsanClusterDitEncryptionHealthSummary import VsanClusterDitEncryptionHealthSummary as VsanClusterDitEncryptionHealthSummary
from .VsanClusterEncryptionHealthSummary import VsanClusterEncryptionHealthSummary as VsanClusterEncryptionHealthSummary
from .VsanClusterFileServiceHealthSummary import VsanClusterFileServiceHealthSummary as VsanClusterFileServiceHealthSummary
from .VsanClusterGlobalDedupHealthSummary import VsanClusterGlobalDedupHealthSummary as VsanClusterGlobalDedupHealthSummary
from .VsanClusterHclInfo import VsanClusterHclInfo as VsanClusterHclInfo
from .VsanClusterHealthAction import VsanClusterHealthAction as VsanClusterHealthAction
from .VsanClusterHealthCategoryEnum import VsanClusterHealthCategoryEnum as VsanClusterHealthCategoryEnum
from .VsanClusterHealthCheckInfo import VsanClusterHealthCheckInfo as VsanClusterHealthCheckInfo
from .VsanClusterHealthConfigs import VsanClusterHealthConfigs as VsanClusterHealthConfigs
from .VsanClusterHealthExternalLink import VsanClusterHealthExternalLink as VsanClusterHealthExternalLink
from .VsanClusterHealthGroup import VsanClusterHealthGroup as VsanClusterHealthGroup
from .VsanClusterHealthLinkBase import VsanClusterHealthLinkBase as VsanClusterHealthLinkBase
from .VsanClusterHealthQuerySpec import VsanClusterHealthQuerySpec as VsanClusterHealthQuerySpec
from .VsanClusterHealthResultBase import VsanClusterHealthResultBase as VsanClusterHealthResultBase
from .VsanClusterHealthResultColumnInfo import VsanClusterHealthResultColumnInfo as VsanClusterHealthResultColumnInfo
from .VsanClusterHealthResultKeyValuePair import VsanClusterHealthResultKeyValuePair as VsanClusterHealthResultKeyValuePair
from .VsanClusterHealthResultRow import VsanClusterHealthResultRow as VsanClusterHealthResultRow
from .VsanClusterHealthResultTable import VsanClusterHealthResultTable as VsanClusterHealthResultTable
from .VsanClusterHealthResultWithRemediation import VsanClusterHealthResultWithRemediation as VsanClusterHealthResultWithRemediation
from .VsanClusterHealthSummary import VsanClusterHealthSummary as VsanClusterHealthSummary
from .VsanClusterHealthSystem import VsanClusterHealthSystem as VsanClusterHealthSystem
from .VsanClusterHealthSystemObjectsRepairResult import VsanClusterHealthSystemObjectsRepairResult as VsanClusterHealthSystemObjectsRepairResult
from .VsanClusterHealthSystemStatusResult import VsanClusterHealthSystemStatusResult as VsanClusterHealthSystemStatusResult
from .VsanClusterHealthSystemVersionResult import VsanClusterHealthSystemVersionResult as VsanClusterHealthSystemVersionResult
from .VsanClusterHealthTest import VsanClusterHealthTest as VsanClusterHealthTest
from .VsanClusterHostVmknicMapping import VsanClusterHostVmknicMapping as VsanClusterHostVmknicMapping
from .VsanClusterLimitHealthResult import VsanClusterLimitHealthResult as VsanClusterLimitHealthResult
from .VsanClusterMgmtInternalSystem import VsanClusterMgmtInternalSystem as VsanClusterMgmtInternalSystem
from .VsanClusterNetworkHealthResult import VsanClusterNetworkHealthResult as VsanClusterNetworkHealthResult
from .VsanClusterNetworkLoadTestResult import VsanClusterNetworkLoadTestResult as VsanClusterNetworkLoadTestResult
from .VsanClusterNetworkPartitionInfo import VsanClusterNetworkPartitionInfo as VsanClusterNetworkPartitionInfo
from .VsanClusterNetworkPerfTaskSpec import VsanClusterNetworkPerfTaskSpec as VsanClusterNetworkPerfTaskSpec
from .VsanClusterPowerSystem import VsanClusterPowerSystem as VsanClusterPowerSystem
from .VsanClusterProactiveTestResult import VsanClusterProactiveTestResult as VsanClusterProactiveTestResult
from .VsanClusterTelemetryProxyConfig import VsanClusterTelemetryProxyConfig as VsanClusterTelemetryProxyConfig
from .VsanClusterVMsHealthOverallResult import VsanClusterVMsHealthOverallResult as VsanClusterVMsHealthOverallResult
from .VsanClusterVMsHealthSummaryResult import VsanClusterVMsHealthSummaryResult as VsanClusterVMsHealthSummaryResult
from .VsanClusterVmdkLoadTestResult import VsanClusterVmdkLoadTestResult as VsanClusterVmdkLoadTestResult
from .VsanClusterWhatifHostFailuresResult import VsanClusterWhatifHostFailuresResult as VsanClusterWhatifHostFailuresResult
from .VsanConfigGeneration import VsanConfigGeneration as VsanConfigGeneration
from .VsanDataDrivenAPIAction import VsanDataDrivenAPIAction as VsanDataDrivenAPIAction
from .VsanDatastoreType import VsanDatastoreType as VsanDatastoreType
from .VsanDiagnosticsSystem import VsanDiagnosticsSystem as VsanDiagnosticsSystem
from .VsanDiagnosticsThreshold import VsanDiagnosticsThreshold as VsanDiagnosticsThreshold
from .VsanDiskFormatConversionCheckResult import VsanDiskFormatConversionCheckResult as VsanDiskFormatConversionCheckResult
from .VsanDiskFormatConversionSpec import VsanDiskFormatConversionSpec as VsanDiskFormatConversionSpec
from .VsanDiskMappingsConfigSpec import VsanDiskMappingsConfigSpec as VsanDiskMappingsConfigSpec
from .VsanEntitySpaceUsage import VsanEntitySpaceUsage as VsanEntitySpaceUsage
from .VsanFaultDomainSpec import VsanFaultDomainSpec as VsanFaultDomainSpec
from .VsanFaultDomainsConfigSpec import VsanFaultDomainsConfigSpec as VsanFaultDomainsConfigSpec
from .VsanHealthActionBase import VsanHealthActionBase as VsanHealthActionBase
from .VsanHealthActionSteps import VsanHealthActionSteps as VsanHealthActionSteps
from .VsanHealthApiBasedAction import VsanHealthApiBasedAction as VsanHealthApiBasedAction
from .VsanHealthCmdBasedAction import VsanHealthCmdBasedAction as VsanHealthCmdBasedAction
from .VsanHealthConfirmationDialog import VsanHealthConfirmationDialog as VsanHealthConfirmationDialog
from .VsanHealthCorrelation import VsanHealthCorrelation as VsanHealthCorrelation
from .VsanHealthDataDrivenAction import VsanHealthDataDrivenAction as VsanHealthDataDrivenAction
from .VsanHealthExtMgmtPreCheckResult import VsanHealthExtMgmtPreCheckResult as VsanHealthExtMgmtPreCheckResult
from .VsanHealthTroubleshooting import VsanHealthTroubleshooting as VsanHealthTroubleshooting
from .VsanHealthTxtBasedAction import VsanHealthTxtBasedAction as VsanHealthTxtBasedAction
from .VsanHistoricalHealthQuerySpec import VsanHistoricalHealthQuerySpec as VsanHistoricalHealthQuerySpec
from .VsanHistoricalHealthTest import VsanHistoricalHealthTest as VsanHistoricalHealthTest
from .VsanHostClomdLivenessResult import VsanHostClomdLivenessResult as VsanHostClomdLivenessResult
from .VsanHostCreateVmHealthTestResult import VsanHostCreateVmHealthTestResult as VsanHostCreateVmHealthTestResult
from .VsanHostDiskMapping import VsanHostDiskMapping as VsanHostDiskMapping
from .VsanHostHealthSystemVersionResult import VsanHostHealthSystemVersionResult as VsanHostHealthSystemVersionResult
from .VsanIoInsightInstance import VsanIoInsightInstance as VsanIoInsightInstance
from .VsanIoInsightInstanceQuerySpec import VsanIoInsightInstanceQuerySpec as VsanIoInsightInstanceQuerySpec
from .VsanIoInsightInstanceState import VsanIoInsightInstanceState as VsanIoInsightInstanceState
from .VsanIoInsightManager import VsanIoInsightManager as VsanIoInsightManager
from .VsanIscsiHomeObjectSpec import VsanIscsiHomeObjectSpec as VsanIscsiHomeObjectSpec
from .VsanIscsiInitiatorGroup import VsanIscsiInitiatorGroup as VsanIscsiInitiatorGroup
from .VsanIscsiLUN import VsanIscsiLUN as VsanIscsiLUN
from .VsanIscsiLUNCommonInfo import VsanIscsiLUNCommonInfo as VsanIscsiLUNCommonInfo
from .VsanIscsiLUNRuntimeStatusType import VsanIscsiLUNRuntimeStatusType as VsanIscsiLUNRuntimeStatusType
from .VsanIscsiLUNSpec import VsanIscsiLUNSpec as VsanIscsiLUNSpec
from .VsanIscsiTarget import VsanIscsiTarget as VsanIscsiTarget
from .VsanIscsiTargetAuthSpec import VsanIscsiTargetAuthSpec as VsanIscsiTargetAuthSpec
from .VsanIscsiTargetBasicInfo import VsanIscsiTargetBasicInfo as VsanIscsiTargetBasicInfo
from .VsanIscsiTargetCommonInfo import VsanIscsiTargetCommonInfo as VsanIscsiTargetCommonInfo
from .VsanIscsiTargetServiceConfig import VsanIscsiTargetServiceConfig as VsanIscsiTargetServiceConfig
from .VsanIscsiTargetServiceDefaultConfigSpec import VsanIscsiTargetServiceDefaultConfigSpec as VsanIscsiTargetServiceDefaultConfigSpec
from .VsanIscsiTargetServiceProcessStatus import VsanIscsiTargetServiceProcessStatus as VsanIscsiTargetServiceProcessStatus
from .VsanIscsiTargetServiceSpec import VsanIscsiTargetServiceSpec as VsanIscsiTargetServiceSpec
from .VsanIscsiTargetSpec import VsanIscsiTargetSpec as VsanIscsiTargetSpec
from .VsanIscsiTargetSystem import VsanIscsiTargetSystem as VsanIscsiTargetSystem
from .VsanNetworkDiagnostics import VsanNetworkDiagnostics as VsanNetworkDiagnostics
from .VsanObjIdentityQuerySpec import VsanObjIdentityQuerySpec as VsanObjIdentityQuerySpec
from .VsanObjectExtAttrs import VsanObjectExtAttrs as VsanObjectExtAttrs
from .VsanObjectExtraAttributes import VsanObjectExtraAttributes as VsanObjectExtraAttributes
from .VsanObjectIdentity import VsanObjectIdentity as VsanObjectIdentity
from .VsanObjectIdentityAndHealth import VsanObjectIdentityAndHealth as VsanObjectIdentityAndHealth
from .VsanObjectInformation import VsanObjectInformation as VsanObjectInformation
from .VsanObjectQuerySpec import VsanObjectQuerySpec as VsanObjectQuerySpec
from .VsanObjectSpaceSummary import VsanObjectSpaceSummary as VsanObjectSpaceSummary
from .VsanObjectSystem import VsanObjectSystem as VsanObjectSystem
from .VsanPerfDiagnoseQuerySpec import VsanPerfDiagnoseQuerySpec as VsanPerfDiagnoseQuerySpec
from .VsanPerfDiagnosticException import VsanPerfDiagnosticException as VsanPerfDiagnosticException
from .VsanPerfDiagnosticQueryType import VsanPerfDiagnosticQueryType as VsanPerfDiagnosticQueryType
from .VsanPerfDiagnosticResult import VsanPerfDiagnosticResult as VsanPerfDiagnosticResult
from .VsanPerfEntityMetricCSV import VsanPerfEntityMetricCSV as VsanPerfEntityMetricCSV
from .VsanPerfEntityType import VsanPerfEntityType as VsanPerfEntityType
from .VsanPerfGraph import VsanPerfGraph as VsanPerfGraph
from .VsanPerfHotspotEntitiesMetrics import VsanPerfHotspotEntitiesMetrics as VsanPerfHotspotEntitiesMetrics
from .VsanPerfHotspotQuerySpec import VsanPerfHotspotQuerySpec as VsanPerfHotspotQuerySpec
from .VsanPerfMasterInformation import VsanPerfMasterInformation as VsanPerfMasterInformation
from .VsanPerfMemberInfo import VsanPerfMemberInfo as VsanPerfMemberInfo
from .VsanPerfMetricId import VsanPerfMetricId as VsanPerfMetricId
from .VsanPerfMetricSeriesCSV import VsanPerfMetricSeriesCSV as VsanPerfMetricSeriesCSV
from .VsanPerfNodeInformation import VsanPerfNodeInformation as VsanPerfNodeInformation
from .VsanPerfQuerySpec import VsanPerfQuerySpec as VsanPerfQuerySpec
from .VsanPerfThreshold import VsanPerfThreshold as VsanPerfThreshold
from .VsanPerfTimeRange import VsanPerfTimeRange as VsanPerfTimeRange
from .VsanPerfTimeRangeQuerySpec import VsanPerfTimeRangeQuerySpec as VsanPerfTimeRangeQuerySpec
from .VsanPerfTopEntities import VsanPerfTopEntities as VsanPerfTopEntities
from .VsanPerfTopEntity import VsanPerfTopEntity as VsanPerfTopEntity
from .VsanPerfTopQuerySpec import VsanPerfTopQuerySpec as VsanPerfTopQuerySpec
from .VsanPerformanceManager import VsanPerformanceManager as VsanPerformanceManager
from .VsanPerfsvcConfig import VsanPerfsvcConfig as VsanPerfsvcConfig
from .VsanRelayoutObjectsErrorCode import VsanRelayoutObjectsErrorCode as VsanRelayoutObjectsErrorCode
from .VsanRemoteClusterQuerySpec import VsanRemoteClusterQuerySpec as VsanRemoteClusterQuerySpec
from .VsanRemoteDatastoreSystem import VsanRemoteDatastoreSystem as VsanRemoteDatastoreSystem
from .VsanSpaceQuerySpec import VsanSpaceQuerySpec as VsanSpaceQuerySpec
from .VsanSpaceReportSystem import VsanSpaceReportSystem as VsanSpaceReportSystem
from .VsanSpaceReportingEntityType import VsanSpaceReportingEntityType as VsanSpaceReportingEntityType
from .VsanSpaceUsage import VsanSpaceUsage as VsanSpaceUsage
from .VsanSpaceUsageDetailResult import VsanSpaceUsageDetailResult as VsanSpaceUsageDetailResult
from .VsanSpaceUsageWithDatastoreType import VsanSpaceUsageWithDatastoreType as VsanSpaceUsageWithDatastoreType
from .VsanStorageWorkloadType import VsanStorageWorkloadType as VsanStorageWorkloadType
from .VsanStretchedClusterConfig import VsanStretchedClusterConfig as VsanStretchedClusterConfig
from .VsanSyncingObjectFilter import VsanSyncingObjectFilter as VsanSyncingObjectFilter
from .VsanUnicastAddressInfo import VsanUnicastAddressInfo as VsanUnicastAddressInfo
from .VsanUpgradeStatusEx import VsanUpgradeStatusEx as VsanUpgradeStatusEx
from .VsanUpgradeSystemUpgradeHistoryStoragePoolOp import VsanUpgradeSystemUpgradeHistoryStoragePoolOp as VsanUpgradeSystemUpgradeHistoryStoragePoolOp
from .VsanVcClusterConfigSystem import VsanVcClusterConfigSystem as VsanVcClusterConfigSystem
from .VsanVcClusterHealthSystem import VsanVcClusterHealthSystem as VsanVcClusterHealthSystem
from .VsanVcDiskManagementSystem import VsanVcDiskManagementSystem as VsanVcDiskManagementSystem
from .VsanVcKmipServersHealth import VsanVcKmipServersHealth as VsanVcKmipServersHealth
from .VsanVcLifecycleCheckResult import VsanVcLifecycleCheckResult as VsanVcLifecycleCheckResult
from .VsanVcLifecycleCheckSpec import VsanVcLifecycleCheckSpec as VsanVcLifecycleCheckSpec
from .VsanVcStretchedClusterSystem import VsanVcStretchedClusterSystem as VsanVcStretchedClusterSystem
from .VsanVsanClusterPcapGroup import VsanVsanClusterPcapGroup as VsanVsanClusterPcapGroup
from .VsanVsanClusterPcapResult import VsanVsanClusterPcapResult as VsanVsanClusterPcapResult
from .VsanVumSystem import VsanVumSystem as VsanVumSystem
from .VsanVumSystemConfig import VsanVumSystemConfig as VsanVumSystemConfig
from .VsanWhatifCapacity import VsanWhatifCapacity as VsanWhatifCapacity
from .VsanWitnessSpec import VsanWitnessSpec as VsanWitnessSpec
