# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanStretchedClusterConfig

from pyVmomi.vim.vsan.host import AddStoragePoolDiskSpec
from pyVmomi.vim.vsan.host import DiskMapping

class VsanVcStretchedClusterConfigSpec(DynamicData):
   witnessHost: HostSystem
   clusters: list[VsanStretchedClusterConfig] = []
   witnessDiskMappings: list[DiskMapping] = []
   witnessStoragePoolSpecs: list[AddStoragePoolDiskSpec] = []
