# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .CertificateNotTrustedFault import CertificateNotTrustedFault as CertificateNotTrustedFault
from .DisabledClusterFault import DisabledClusterFault as DisabledClusterFault
from .EamAppFault import EamAppFault as EamAppFault
from .EamFault import EamFault as EamFault
from .EamIOFault import EamIOFault as EamIOFault
from .EamRuntimeFault import EamRuntimeFault as EamRuntimeFault
from .EamServiceNotInitialized import EamServiceNotInitialized as EamServiceNotInitialized
from .EamSystemFault import EamSystemFault as EamSystemFault
from .InvalidAgencyScope import InvalidAgencyScope as InvalidAgencyScope
from .InvalidAgentConfiguration import InvalidAgentConfiguration as InvalidAgentConfiguration
from .InvalidLogin import InvalidLogin as InvalidLogin
from .InvalidState import InvalidState as InvalidState
from .InvalidUrl import InvalidUrl as InvalidUrl
from .InvalidVibPackage import InvalidVibPackage as InvalidVibPackage
from .NoConnectionToVCenter import NoConnectionToVCenter as NoConnectionToVCenter
from .NotAuthorized import NotAuthorized as NotAuthorized
