# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import byte

from pyVmomi.vim import CustomizationSpecInfo
from pyVmomi.vim import CustomizationSpecItem

class CustomizationSpecManager(ManagedObject):
   @property
   def info(self) -> list[CustomizationSpecInfo]: ...
   @property
   def encryptionKey(self) -> list[byte]: ...

   def Exists(self, name: str) -> bool: ...
   def Get(self, name: str) -> CustomizationSpecItem: ...
   def Create(self, item: CustomizationSpecItem) -> NoReturn: ...
   def Overwrite(self, item: CustomizationSpecItem) -> NoReturn: ...
   def Delete(self, name: str) -> NoReturn: ...
   def Duplicate(self, name: str, newName: str) -> NoReturn: ...
   def Rename(self, name: str, newName: str) -> NoReturn: ...
   def SpecItemToXml(self, item: CustomizationSpecItem) -> str: ...
   def XmlToSpecItem(self, specItemXml: str) -> CustomizationSpecItem: ...
   def CheckResources(self, guestOs: str) -> NoReturn: ...
   def IsGuestOsCustomizable(self, guestId: str) -> bool: ...
