# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class AssignableHardwareConfig(DynamicData):
   class AttributeOverride(DynamicData):
      instanceId: str
      name: str
      value: Optional[object] = None

   attributeOverride: list[AttributeOverride] = []
