# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import action as action
from . import alarm as alarm
from . import cluster as cluster
from . import cns as cns
from . import dvs as dvs
from . import encryption as encryption
from . import event as event
from . import ext as ext
from . import fault as fault
from . import host as host
from . import net as net
from . import option as option
from . import profile as profile
from . import scheduler as scheduler
from . import storageDrs as storageDrs
from . import tenant as tenant
from . import vApp as vApp
from . import vcha as vcha
from . import view as view
from . import vm as vm
from . import vsan as vsan
from . import vslm as vslm

from .AboutInfo import AboutInfo as AboutInfo
from .AuthorizationDescription import AuthorizationDescription as AuthorizationDescription
from .AuthorizationManager import AuthorizationManager as AuthorizationManager
from .BatchResult import BatchResult as BatchResult
from .BoolPolicy import BoolPolicy as BoolPolicy
from .Capability import Capability as Capability
from .CertificateManager import CertificateManager as CertificateManager
from .ClusterComputeResource import ClusterComputeResource as ClusterComputeResource
from .ComputeResource import ComputeResource as ComputeResource
from .ConfigSpecOperation import ConfigSpecOperation as ConfigSpecOperation
from .CustomFieldsManager import CustomFieldsManager as CustomFieldsManager
from .CustomizationSpecInfo import CustomizationSpecInfo as CustomizationSpecInfo
from .CustomizationSpecItem import CustomizationSpecItem as CustomizationSpecItem
from .CustomizationSpecManager import CustomizationSpecManager as CustomizationSpecManager
from .Datacenter import Datacenter as Datacenter
from .Datastore import Datastore as Datastore
from .DatastoreNamespaceManager import DatastoreNamespaceManager as DatastoreNamespaceManager
from .Description import Description as Description
from .DesiredSoftwareSpec import DesiredSoftwareSpec as DesiredSoftwareSpec
from .DiagnosticManager import DiagnosticManager as DiagnosticManager
from .DirectPathProfileManager import DirectPathProfileManager as DirectPathProfileManager
from .DistributedVirtualSwitch import DistributedVirtualSwitch as DistributedVirtualSwitch
from .EVCMode import EVCMode as EVCMode
from .ElementDescription import ElementDescription as ElementDescription
from .EnumDescription import EnumDescription as EnumDescription
from .EnvironmentBrowser import EnvironmentBrowser as EnvironmentBrowser
from .ExtendedDescription import ExtendedDescription as ExtendedDescription
from .ExtendedElementDescription import ExtendedElementDescription as ExtendedElementDescription
from .ExtensibleManagedObject import ExtensibleManagedObject as ExtensibleManagedObject
from .Extension import Extension as Extension
from .ExtensionManager import ExtensionManager as ExtensionManager
from .FaultsByHost import FaultsByHost as FaultsByHost
from .FaultsByVM import FaultsByVM as FaultsByVM
from .FeatureEVCMode import FeatureEVCMode as FeatureEVCMode
from .FileManager import FileManager as FileManager
from .Folder import Folder as Folder
from .HbrReplicationTargetSpec import HbrReplicationTargetSpec as HbrReplicationTargetSpec
from .HbrTargetSpec import HbrTargetSpec as HbrTargetSpec
from .HbrTargetSpecReplacement import HbrTargetSpecReplacement as HbrTargetSpecReplacement
from .HealthUpdate import HealthUpdate as HealthUpdate
from .HealthUpdateInfo import HealthUpdateInfo as HealthUpdateInfo
from .HealthUpdateManager import HealthUpdateManager as HealthUpdateManager
from .HistoricalInterval import HistoricalInterval as HistoricalInterval
from .HistoryCollector import HistoryCollector as HistoryCollector
from .HostServiceTicket import HostServiceTicket as HostServiceTicket
from .HostSystem import HostSystem as HostSystem
from .HttpNfcLease import HttpNfcLease as HttpNfcLease
from .ImportSpec import ImportSpec as ImportSpec
from .InheritablePolicy import InheritablePolicy as InheritablePolicy
from .IntExpression import IntExpression as IntExpression
from .IntPolicy import IntPolicy as IntPolicy
from .IoFilterManager import IoFilterManager as IoFilterManager
from .IpAddress import IpAddress as IpAddress
from .IpPoolManager import IpPoolManager as IpPoolManager
from .IpRange import IpRange as IpRange
from .KeyValue import KeyValue as KeyValue
from .LatencySensitivity import LatencySensitivity as LatencySensitivity
from .LicenseAssignmentManager import LicenseAssignmentManager as LicenseAssignmentManager
from .LicenseManager import LicenseManager as LicenseManager
from .LocalizationManager import LocalizationManager as LocalizationManager
from .LongPolicy import LongPolicy as LongPolicy
from .MacAddress import MacAddress as MacAddress
from .MacRange import MacRange as MacRange
from .ManagedEntity import ManagedEntity as ManagedEntity
from .MethodDescription import MethodDescription as MethodDescription
from .NegatableExpression import NegatableExpression as NegatableExpression
from .Network import Network as Network
from .NumericRange import NumericRange as NumericRange
from .OpaqueNetwork import OpaqueNetwork as OpaqueNetwork
from .OverheadMemoryManager import OverheadMemoryManager as OverheadMemoryManager
from .OvfManager import OvfManager as OvfManager
from .PasswordField import PasswordField as PasswordField
from .PerformanceDescription import PerformanceDescription as PerformanceDescription
from .PerformanceManager import PerformanceManager as PerformanceManager
from .PosixUserSearchResult import PosixUserSearchResult as PosixUserSearchResult
from .PrivilegePolicyDef import PrivilegePolicyDef as PrivilegePolicyDef
from .ResourceAllocationInfo import ResourceAllocationInfo as ResourceAllocationInfo
from .ResourceAllocationOption import ResourceAllocationOption as ResourceAllocationOption
from .ResourceConfigOption import ResourceConfigOption as ResourceConfigOption
from .ResourceConfigSpec import ResourceConfigSpec as ResourceConfigSpec
from .ResourcePlanningManager import ResourcePlanningManager as ResourcePlanningManager
from .ResourcePool import ResourcePool as ResourcePool
from .SDDCBase import SDDCBase as SDDCBase
from .SearchIndex import SearchIndex as SearchIndex
from .SelectionSet import SelectionSet as SelectionSet
from .ServiceInstance import ServiceInstance as ServiceInstance
from .ServiceInstanceContent import ServiceInstanceContent as ServiceInstanceContent
from .ServiceLocator import ServiceLocator as ServiceLocator
from .ServiceManager import ServiceManager as ServiceManager
from .SessionManager import SessionManager as SessionManager
from .SharesInfo import SharesInfo as SharesInfo
from .SharesOption import SharesOption as SharesOption
from .SimpleCommand import SimpleCommand as SimpleCommand
from .SingleIp import SingleIp as SingleIp
from .SingleMac import SingleMac as SingleMac
from .SiteInfo import SiteInfo as SiteInfo
from .SiteInfoManager import SiteInfoManager as SiteInfoManager
from .StoragePod import StoragePod as StoragePod
from .StorageQueryManager import StorageQueryManager as StorageQueryManager
from .StorageResourceManager import StorageResourceManager as StorageResourceManager
from .StringExpression import StringExpression as StringExpression
from .StringPolicy import StringPolicy as StringPolicy
from .Tag import Tag as Tag
from .Task import Task as Task
from .TaskDescription import TaskDescription as TaskDescription
from .TaskFilterSpec import TaskFilterSpec as TaskFilterSpec
from .TaskHistoryCollector import TaskHistoryCollector as TaskHistoryCollector
from .TaskInfo import TaskInfo as TaskInfo
from .TaskInfoFilterSpec import TaskInfoFilterSpec as TaskInfoFilterSpec
from .TaskManager import TaskManager as TaskManager
from .TaskReason import TaskReason as TaskReason
from .TaskReasonAlarm import TaskReasonAlarm as TaskReasonAlarm
from .TaskReasonSchedule import TaskReasonSchedule as TaskReasonSchedule
from .TaskReasonSystem import TaskReasonSystem as TaskReasonSystem
from .TaskReasonUser import TaskReasonUser as TaskReasonUser
from .TypeDescription import TypeDescription as TypeDescription
from .UpdateVirtualMachineFilesResult import UpdateVirtualMachineFilesResult as UpdateVirtualMachineFilesResult
from .UserDirectory import UserDirectory as UserDirectory
from .UserSearchResult import UserSearchResult as UserSearchResult
from .UserSession import UserSession as UserSession
from .VVolVmConfigFileUpdateResult import VVolVmConfigFileUpdateResult as VVolVmConfigFileUpdateResult
from .VasaStorageArray import VasaStorageArray as VasaStorageArray
from .VimVasaProvider import VimVasaProvider as VimVasaProvider
from .VimVasaProviderInfo import VimVasaProviderInfo as VimVasaProviderInfo
from .VirtualApp import VirtualApp as VirtualApp
from .VirtualDiskManager import VirtualDiskManager as VirtualDiskManager
from .VirtualMachine import VirtualMachine as VirtualMachine
from .VirtualizationManager import VirtualizationManager as VirtualizationManager
from .VsanComparator import VsanComparator as VsanComparator
from .VsanCompositeConstraint import VsanCompositeConstraint as VsanCompositeConstraint
from .VsanCompositeConstraintConjoinerEnum import VsanCompositeConstraintConjoinerEnum as VsanCompositeConstraintConjoinerEnum
from .VsanDataObfuscationRule import VsanDataObfuscationRule as VsanDataObfuscationRule
from .VsanJsonComparator import VsanJsonComparator as VsanJsonComparator
from .VsanJsonFilterRule import VsanJsonFilterRule as VsanJsonFilterRule
from .VsanMassCollector import VsanMassCollector as VsanMassCollector
from .VsanMassCollectorObjectCollectionEnum import VsanMassCollectorObjectCollectionEnum as VsanMassCollectorObjectCollectionEnum
from .VsanMassCollectorPropertyParams import VsanMassCollectorPropertyParams as VsanMassCollectorPropertyParams
from .VsanMassCollectorSpec import VsanMassCollectorSpec as VsanMassCollectorSpec
from .VsanNestJsonComparator import VsanNestJsonComparator as VsanNestJsonComparator
from .VsanObjectTypeRule import VsanObjectTypeRule as VsanObjectTypeRule
from .VsanPhoneHomeSystem import VsanPhoneHomeSystem as VsanPhoneHomeSystem
from .VsanPropertyConstraint import VsanPropertyConstraint as VsanPropertyConstraint
from .VsanPropertyConstraintComparatorEnum import VsanPropertyConstraintComparatorEnum as VsanPropertyConstraintComparatorEnum
from .VsanRegexBasedRule import VsanRegexBasedRule as VsanRegexBasedRule
from .VsanResourceConstraint import VsanResourceConstraint as VsanResourceConstraint
from .VsanUpgradeSystem import VsanUpgradeSystem as VsanUpgradeSystem
from .VsanUpgradeSystemEx import VsanUpgradeSystemEx as VsanUpgradeSystemEx
