# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .ActiveDirectoryFault import ActiveDirectoryFault as ActiveDirectoryFault
from .ActiveVMsBlockingEVC import ActiveVMsBlockingEVC as ActiveVMsBlockingEVC
from .AdminDisabled import AdminDisabled as AdminDisabled
from .AdminNotDisabled import AdminNotDisabled as AdminNotDisabled
from .AffinityConfigured import AffinityConfigured as AffinityConfigured
from .AgentInstallFailed import AgentInstallFailed as AgentInstallFailed
from .AlreadyBeingManaged import AlreadyBeingManaged as AlreadyBeingManaged
from .AlreadyConnected import AlreadyConnected as AlreadyConnected
from .AlreadyExists import AlreadyExists as AlreadyExists
from .AlreadyUpgraded import AlreadyUpgraded as AlreadyUpgraded
from .AnswerFileUpdateFailed import AnswerFileUpdateFailed as AnswerFileUpdateFailed
from .ApplicationQuiesceFault import ApplicationQuiesceFault as ApplicationQuiesceFault
from .AuthMinimumAdminPermission import AuthMinimumAdminPermission as AuthMinimumAdminPermission
from .BackupBlobReadFailure import BackupBlobReadFailure as BackupBlobReadFailure
from .BackupBlobWriteFailure import BackupBlobWriteFailure as BackupBlobWriteFailure
from .BlockedByFirewall import BlockedByFirewall as BlockedByFirewall
from .CAMServerRefusedConnection import CAMServerRefusedConnection as CAMServerRefusedConnection
from .CannotAccessFile import CannotAccessFile as CannotAccessFile
from .CannotAccessLocalSource import CannotAccessLocalSource as CannotAccessLocalSource
from .CannotAccessNetwork import CannotAccessNetwork as CannotAccessNetwork
from .CannotAccessVmComponent import CannotAccessVmComponent as CannotAccessVmComponent
from .CannotAccessVmConfig import CannotAccessVmConfig as CannotAccessVmConfig
from .CannotAccessVmDevice import CannotAccessVmDevice as CannotAccessVmDevice
from .CannotAccessVmDisk import CannotAccessVmDisk as CannotAccessVmDisk
from .CannotAddHostWithFTVmAsStandalone import CannotAddHostWithFTVmAsStandalone as CannotAddHostWithFTVmAsStandalone
from .CannotAddHostWithFTVmToDifferentCluster import CannotAddHostWithFTVmToDifferentCluster as CannotAddHostWithFTVmToDifferentCluster
from .CannotAddHostWithFTVmToNonHACluster import CannotAddHostWithFTVmToNonHACluster as CannotAddHostWithFTVmToNonHACluster
from .CannotChangeDrsBehaviorForFtSecondary import CannotChangeDrsBehaviorForFtSecondary as CannotChangeDrsBehaviorForFtSecondary
from .CannotChangeHaSettingsForFtSecondary import CannotChangeHaSettingsForFtSecondary as CannotChangeHaSettingsForFtSecondary
from .CannotChangeVsanClusterUuid import CannotChangeVsanClusterUuid as CannotChangeVsanClusterUuid
from .CannotChangeVsanNodeUuid import CannotChangeVsanNodeUuid as CannotChangeVsanNodeUuid
from .CannotComputeFTCompatibleHosts import CannotComputeFTCompatibleHosts as CannotComputeFTCompatibleHosts
from .CannotCreateFile import CannotCreateFile as CannotCreateFile
from .CannotDecryptPasswords import CannotDecryptPasswords as CannotDecryptPasswords
from .CannotDeleteFile import CannotDeleteFile as CannotDeleteFile
from .CannotDisableDrsOnClustersWithVApps import CannotDisableDrsOnClustersWithVApps as CannotDisableDrsOnClustersWithVApps
from .CannotDisableSnapshot import CannotDisableSnapshot as CannotDisableSnapshot
from .CannotDisconnectHostWithFaultToleranceVm import CannotDisconnectHostWithFaultToleranceVm as CannotDisconnectHostWithFaultToleranceVm
from .CannotEnableVmcpForCluster import CannotEnableVmcpForCluster as CannotEnableVmcpForCluster
from .CannotModifyConfigCpuRequirements import CannotModifyConfigCpuRequirements as CannotModifyConfigCpuRequirements
from .CannotMoveFaultToleranceVm import CannotMoveFaultToleranceVm as CannotMoveFaultToleranceVm
from .CannotMoveHostWithFaultToleranceVm import CannotMoveHostWithFaultToleranceVm as CannotMoveHostWithFaultToleranceVm
from .CannotMoveVmWithDeltaDisk import CannotMoveVmWithDeltaDisk as CannotMoveVmWithDeltaDisk
from .CannotMoveVmWithNativeDeltaDisk import CannotMoveVmWithNativeDeltaDisk as CannotMoveVmWithNativeDeltaDisk
from .CannotMoveVsanEnabledHost import CannotMoveVsanEnabledHost as CannotMoveVsanEnabledHost
from .CannotPlaceWithoutPrerequisiteMoves import CannotPlaceWithoutPrerequisiteMoves as CannotPlaceWithoutPrerequisiteMoves
from .CannotPowerOffVmInCluster import CannotPowerOffVmInCluster as CannotPowerOffVmInCluster
from .CannotReconfigureVsanWhenHaEnabled import CannotReconfigureVsanWhenHaEnabled as CannotReconfigureVsanWhenHaEnabled
from .CannotUseNetwork import CannotUseNetwork as CannotUseNetwork
from .ClockSkew import ClockSkew as ClockSkew
from .CloneFromSnapshotNotSupported import CloneFromSnapshotNotSupported as CloneFromSnapshotNotSupported
from .CnsAlreadyRegisteredFault import CnsAlreadyRegisteredFault as CnsAlreadyRegisteredFault
from .CnsFault import CnsFault as CnsFault
from .CnsInCompatibleFault import CnsInCompatibleFault as CnsInCompatibleFault
from .CnsMissingControllerFault import CnsMissingControllerFault as CnsMissingControllerFault
from .CnsMissingPrivilegeFault import CnsMissingPrivilegeFault as CnsMissingPrivilegeFault
from .CnsNotRegisteredFault import CnsNotRegisteredFault as CnsNotRegisteredFault
from .CnsPlacementFault import CnsPlacementFault as CnsPlacementFault
from .CnsRankedLowerFault import CnsRankedLowerFault as CnsRankedLowerFault
from .CnsSnapshotNotFoundFault import CnsSnapshotNotFoundFault as CnsSnapshotNotFoundFault
from .CnsVolumeNotFoundFault import CnsVolumeNotFoundFault as CnsVolumeNotFoundFault
from .CollectorAddressUnset import CollectorAddressUnset as CollectorAddressUnset
from .ConcurrentAccess import ConcurrentAccess as ConcurrentAccess
from .ConflictingConfiguration import ConflictingConfiguration as ConflictingConfiguration
from .ConflictingDatastoreFound import ConflictingDatastoreFound as ConflictingDatastoreFound
from .ConnectedIso import ConnectedIso as ConnectedIso
from .CpuCompatibilityUnknown import CpuCompatibilityUnknown as CpuCompatibilityUnknown
from .CpuHotPlugNotSupported import CpuHotPlugNotSupported as CpuHotPlugNotSupported
from .CpuIncompatible import CpuIncompatible as CpuIncompatible
from .CpuIncompatible1ECX import CpuIncompatible1ECX as CpuIncompatible1ECX
from .CpuIncompatible81EDX import CpuIncompatible81EDX as CpuIncompatible81EDX
from .CustomizationFault import CustomizationFault as CustomizationFault
from .CustomizationPending import CustomizationPending as CustomizationPending
from .DVPortNotSupported import DVPortNotSupported as DVPortNotSupported
from .DasConfigFault import DasConfigFault as DasConfigFault
from .DatabaseError import DatabaseError as DatabaseError
from .DatacenterMismatch import DatacenterMismatch as DatacenterMismatch
from .DatastoreNotWritableOnHost import DatastoreNotWritableOnHost as DatastoreNotWritableOnHost
from .DeltaDiskFormatNotSupported import DeltaDiskFormatNotSupported as DeltaDiskFormatNotSupported
from .DestinationSwitchFull import DestinationSwitchFull as DestinationSwitchFull
from .DestinationVsanDisabled import DestinationVsanDisabled as DestinationVsanDisabled
from .DeviceBackingNotSupported import DeviceBackingNotSupported as DeviceBackingNotSupported
from .DeviceControllerNotSupported import DeviceControllerNotSupported as DeviceControllerNotSupported
from .DeviceHotPlugNotSupported import DeviceHotPlugNotSupported as DeviceHotPlugNotSupported
from .DeviceNotFound import DeviceNotFound as DeviceNotFound
from .DeviceNotSupported import DeviceNotSupported as DeviceNotSupported
from .DeviceUnsupportedForVmPlatform import DeviceUnsupportedForVmPlatform as DeviceUnsupportedForVmPlatform
from .DeviceUnsupportedForVmVersion import DeviceUnsupportedForVmVersion as DeviceUnsupportedForVmVersion
from .DigestNotSupported import DigestNotSupported as DigestNotSupported
from .DirectoryNotEmpty import DirectoryNotEmpty as DirectoryNotEmpty
from .DisableAdminNotSupported import DisableAdminNotSupported as DisableAdminNotSupported
from .DisallowedChangeByService import DisallowedChangeByService as DisallowedChangeByService
from .DisallowedDiskModeChange import DisallowedDiskModeChange as DisallowedDiskModeChange
from .DisallowedMigrationDeviceAttached import DisallowedMigrationDeviceAttached as DisallowedMigrationDeviceAttached
from .DisallowedOperationOnFailoverHost import DisallowedOperationOnFailoverHost as DisallowedOperationOnFailoverHost
from .DisconnectedHostsBlockingEVC import DisconnectedHostsBlockingEVC as DisconnectedHostsBlockingEVC
from .DiskHasPartitions import DiskHasPartitions as DiskHasPartitions
from .DiskIsLastRemainingNonSSD import DiskIsLastRemainingNonSSD as DiskIsLastRemainingNonSSD
from .DiskIsNonLocal import DiskIsNonLocal as DiskIsNonLocal
from .DiskIsUSB import DiskIsUSB as DiskIsUSB
from .DiskMoveTypeNotSupported import DiskMoveTypeNotSupported as DiskMoveTypeNotSupported
from .DiskNotSupported import DiskNotSupported as DiskNotSupported
from .DiskTooSmall import DiskTooSmall as DiskTooSmall
from .DomainNotFound import DomainNotFound as DomainNotFound
from .DrsDisabledOnVm import DrsDisabledOnVm as DrsDisabledOnVm
from .DrsVmotionIncompatibleFault import DrsVmotionIncompatibleFault as DrsVmotionIncompatibleFault
from .DuplicateDisks import DuplicateDisks as DuplicateDisks
from .DuplicateName import DuplicateName as DuplicateName
from .DuplicateVsanNetworkInterface import DuplicateVsanNetworkInterface as DuplicateVsanNetworkInterface
from .DvsApplyOperationFault import DvsApplyOperationFault as DvsApplyOperationFault
from .DvsFault import DvsFault as DvsFault
from .DvsNotAuthorized import DvsNotAuthorized as DvsNotAuthorized
from .DvsOperationBulkFault import DvsOperationBulkFault as DvsOperationBulkFault
from .DvsScopeViolated import DvsScopeViolated as DvsScopeViolated
from .EVCAdmissionFailed import EVCAdmissionFailed as EVCAdmissionFailed
from .EVCAdmissionFailedCPUFeaturesForMode import EVCAdmissionFailedCPUFeaturesForMode as EVCAdmissionFailedCPUFeaturesForMode
from .EVCAdmissionFailedCPUModel import EVCAdmissionFailedCPUModel as EVCAdmissionFailedCPUModel
from .EVCAdmissionFailedCPUModelForMode import EVCAdmissionFailedCPUModelForMode as EVCAdmissionFailedCPUModelForMode
from .EVCAdmissionFailedCPUVendor import EVCAdmissionFailedCPUVendor as EVCAdmissionFailedCPUVendor
from .EVCAdmissionFailedCPUVendorUnknown import EVCAdmissionFailedCPUVendorUnknown as EVCAdmissionFailedCPUVendorUnknown
from .EVCAdmissionFailedHostDisconnected import EVCAdmissionFailedHostDisconnected as EVCAdmissionFailedHostDisconnected
from .EVCAdmissionFailedHostSoftware import EVCAdmissionFailedHostSoftware as EVCAdmissionFailedHostSoftware
from .EVCAdmissionFailedHostSoftwareForMode import EVCAdmissionFailedHostSoftwareForMode as EVCAdmissionFailedHostSoftwareForMode
from .EVCAdmissionFailedVmActive import EVCAdmissionFailedVmActive as EVCAdmissionFailedVmActive
from .EVCConfigFault import EVCConfigFault as EVCConfigFault
from .EVCModeIllegalByVendor import EVCModeIllegalByVendor as EVCModeIllegalByVendor
from .EVCModeUnsupportedByHosts import EVCModeUnsupportedByHosts as EVCModeUnsupportedByHosts
from .EVCUnsupportedByHostHardware import EVCUnsupportedByHostHardware as EVCUnsupportedByHostHardware
from .EVCUnsupportedByHostSoftware import EVCUnsupportedByHostSoftware as EVCUnsupportedByHostSoftware
from .EightHostLimitViolated import EightHostLimitViolated as EightHostLimitViolated
from .EncryptionKeyRequired import EncryptionKeyRequired as EncryptionKeyRequired
from .ExpiredAddonLicense import ExpiredAddonLicense as ExpiredAddonLicense
from .ExpiredEditionLicense import ExpiredEditionLicense as ExpiredEditionLicense
from .ExpiredFeatureLicense import ExpiredFeatureLicense as ExpiredFeatureLicense
from .ExtendedFault import ExtendedFault as ExtendedFault
from .FailToEnableSPBM import FailToEnableSPBM as FailToEnableSPBM
from .FailToLockFaultToleranceVMs import FailToLockFaultToleranceVMs as FailToLockFaultToleranceVMs
from .FaultToleranceAntiAffinityViolated import FaultToleranceAntiAffinityViolated as FaultToleranceAntiAffinityViolated
from .FaultToleranceCannotEditMem import FaultToleranceCannotEditMem as FaultToleranceCannotEditMem
from .FaultToleranceCpuIncompatible import FaultToleranceCpuIncompatible as FaultToleranceCpuIncompatible
from .FaultToleranceNeedsThickDisk import FaultToleranceNeedsThickDisk as FaultToleranceNeedsThickDisk
from .FaultToleranceNotLicensed import FaultToleranceNotLicensed as FaultToleranceNotLicensed
from .FaultToleranceNotSameBuild import FaultToleranceNotSameBuild as FaultToleranceNotSameBuild
from .FaultTolerancePrimaryPowerOnNotAttempted import FaultTolerancePrimaryPowerOnNotAttempted as FaultTolerancePrimaryPowerOnNotAttempted
from .FaultToleranceVmNotDasProtected import FaultToleranceVmNotDasProtected as FaultToleranceVmNotDasProtected
from .FcoeFault import FcoeFault as FcoeFault
from .FcoeFaultPnicHasNoPortSet import FcoeFaultPnicHasNoPortSet as FcoeFaultPnicHasNoPortSet
from .FeatureRequirementsNotMet import FeatureRequirementsNotMet as FeatureRequirementsNotMet
from .FileAlreadyExists import FileAlreadyExists as FileAlreadyExists
from .FileBackedPortNotSupported import FileBackedPortNotSupported as FileBackedPortNotSupported
from .FileFault import FileFault as FileFault
from .FileLocked import FileLocked as FileLocked
from .FileNameTooLong import FileNameTooLong as FileNameTooLong
from .FileNotFound import FileNotFound as FileNotFound
from .FileNotWritable import FileNotWritable as FileNotWritable
from .FileTooLarge import FileTooLarge as FileTooLarge
from .FilesystemQuiesceFault import FilesystemQuiesceFault as FilesystemQuiesceFault
from .FilterInUse import FilterInUse as FilterInUse
from .FtIssuesOnHost import FtIssuesOnHost as FtIssuesOnHost
from .FtVmHostRuleViolation import FtVmHostRuleViolation as FtVmHostRuleViolation
from .FullStorageVMotionNotSupported import FullStorageVMotionNotSupported as FullStorageVMotionNotSupported
from .GatewayConnectFault import GatewayConnectFault as GatewayConnectFault
from .GatewayHostNotReachable import GatewayHostNotReachable as GatewayHostNotReachable
from .GatewayNotFound import GatewayNotFound as GatewayNotFound
from .GatewayNotReachable import GatewayNotReachable as GatewayNotReachable
from .GatewayOperationRefused import GatewayOperationRefused as GatewayOperationRefused
from .GatewayToHostAuthFault import GatewayToHostAuthFault as GatewayToHostAuthFault
from .GatewayToHostConnectFault import GatewayToHostConnectFault as GatewayToHostConnectFault
from .GatewayToHostTrustVerifyFault import GatewayToHostTrustVerifyFault as GatewayToHostTrustVerifyFault
from .GenericDrsFault import GenericDrsFault as GenericDrsFault
from .GenericVmConfigFault import GenericVmConfigFault as GenericVmConfigFault
from .GuestAuthenticationChallenge import GuestAuthenticationChallenge as GuestAuthenticationChallenge
from .GuestComponentsOutOfDate import GuestComponentsOutOfDate as GuestComponentsOutOfDate
from .GuestMultipleMappings import GuestMultipleMappings as GuestMultipleMappings
from .GuestOperationsFault import GuestOperationsFault as GuestOperationsFault
from .GuestOperationsUnavailable import GuestOperationsUnavailable as GuestOperationsUnavailable
from .GuestPermissionDenied import GuestPermissionDenied as GuestPermissionDenied
from .GuestProcessNotFound import GuestProcessNotFound as GuestProcessNotFound
from .GuestRegistryFault import GuestRegistryFault as GuestRegistryFault
from .GuestRegistryKeyAlreadyExists import GuestRegistryKeyAlreadyExists as GuestRegistryKeyAlreadyExists
from .GuestRegistryKeyFault import GuestRegistryKeyFault as GuestRegistryKeyFault
from .GuestRegistryKeyHasSubkeys import GuestRegistryKeyHasSubkeys as GuestRegistryKeyHasSubkeys
from .GuestRegistryKeyInvalid import GuestRegistryKeyInvalid as GuestRegistryKeyInvalid
from .GuestRegistryKeyParentVolatile import GuestRegistryKeyParentVolatile as GuestRegistryKeyParentVolatile
from .GuestRegistryValueFault import GuestRegistryValueFault as GuestRegistryValueFault
from .GuestRegistryValueNotFound import GuestRegistryValueNotFound as GuestRegistryValueNotFound
from .HAErrorsAtDest import HAErrorsAtDest as HAErrorsAtDest
from .HeterogenousHostsBlockingEVC import HeterogenousHostsBlockingEVC as HeterogenousHostsBlockingEVC
from .HostAccessRestrictedToManagementServer import HostAccessRestrictedToManagementServer as HostAccessRestrictedToManagementServer
from .HostConfigFailed import HostConfigFailed as HostConfigFailed
from .HostConfigFault import HostConfigFault as HostConfigFault
from .HostConnectFault import HostConnectFault as HostConnectFault
from .HostHasComponentFailure import HostHasComponentFailure as HostHasComponentFailure
from .HostInDomain import HostInDomain as HostInDomain
from .HostIncompatibleForFaultTolerance import HostIncompatibleForFaultTolerance as HostIncompatibleForFaultTolerance
from .HostIncompatibleForRecordReplay import HostIncompatibleForRecordReplay as HostIncompatibleForRecordReplay
from .HostInventoryFull import HostInventoryFull as HostInventoryFull
from .HostPowerOpFailed import HostPowerOpFailed as HostPowerOpFailed
from .HostSpecificationOperationFailed import HostSpecificationOperationFailed as HostSpecificationOperationFailed
from .HotSnapshotMoveNotSupported import HotSnapshotMoveNotSupported as HotSnapshotMoveNotSupported
from .HttpFault import HttpFault as HttpFault
from .IDEDiskNotSupported import IDEDiskNotSupported as IDEDiskNotSupported
from .IORMNotSupportedHostOnDatastore import IORMNotSupportedHostOnDatastore as IORMNotSupportedHostOnDatastore
from .ImportHostAddFailure import ImportHostAddFailure as ImportHostAddFailure
from .ImportOperationBulkFault import ImportOperationBulkFault as ImportOperationBulkFault
from .InUseFeatureManipulationDisallowed import InUseFeatureManipulationDisallowed as InUseFeatureManipulationDisallowed
from .InaccessibleDatastore import InaccessibleDatastore as InaccessibleDatastore
from .InaccessibleFTMetadataDatastore import InaccessibleFTMetadataDatastore as InaccessibleFTMetadataDatastore
from .InaccessibleVFlashSource import InaccessibleVFlashSource as InaccessibleVFlashSource
from .IncompatibleDefaultDevice import IncompatibleDefaultDevice as IncompatibleDefaultDevice
from .IncompatibleHostForFtSecondary import IncompatibleHostForFtSecondary as IncompatibleHostForFtSecondary
from .IncompatibleHostForVmReplication import IncompatibleHostForVmReplication as IncompatibleHostForVmReplication
from .IncompatibleSetting import IncompatibleSetting as IncompatibleSetting
from .IncorrectFileType import IncorrectFileType as IncorrectFileType
from .IncorrectHostInformation import IncorrectHostInformation as IncorrectHostInformation
from .IndependentDiskVMotionNotSupported import IndependentDiskVMotionNotSupported as IndependentDiskVMotionNotSupported
from .InsufficientAgentVmsDeployed import InsufficientAgentVmsDeployed as InsufficientAgentVmsDeployed
from .InsufficientCpuResourcesFault import InsufficientCpuResourcesFault as InsufficientCpuResourcesFault
from .InsufficientDisks import InsufficientDisks as InsufficientDisks
from .InsufficientFailoverResourcesFault import InsufficientFailoverResourcesFault as InsufficientFailoverResourcesFault
from .InsufficientGraphicsResourcesFault import InsufficientGraphicsResourcesFault as InsufficientGraphicsResourcesFault
from .InsufficientHostCapacityFault import InsufficientHostCapacityFault as InsufficientHostCapacityFault
from .InsufficientHostCpuCapacityFault import InsufficientHostCpuCapacityFault as InsufficientHostCpuCapacityFault
from .InsufficientHostMemoryCapacityFault import InsufficientHostMemoryCapacityFault as InsufficientHostMemoryCapacityFault
from .InsufficientMemoryResourcesFault import InsufficientMemoryResourcesFault as InsufficientMemoryResourcesFault
from .InsufficientNetworkCapacity import InsufficientNetworkCapacity as InsufficientNetworkCapacity
from .InsufficientNetworkResourcePoolCapacity import InsufficientNetworkResourcePoolCapacity as InsufficientNetworkResourcePoolCapacity
from .InsufficientPerCpuCapacity import InsufficientPerCpuCapacity as InsufficientPerCpuCapacity
from .InsufficientResourcesFault import InsufficientResourcesFault as InsufficientResourcesFault
from .InsufficientStandbyCpuResource import InsufficientStandbyCpuResource as InsufficientStandbyCpuResource
from .InsufficientStandbyMemoryResource import InsufficientStandbyMemoryResource as InsufficientStandbyMemoryResource
from .InsufficientStandbyResource import InsufficientStandbyResource as InsufficientStandbyResource
from .InsufficientStorageIops import InsufficientStorageIops as InsufficientStorageIops
from .InsufficientStorageSpace import InsufficientStorageSpace as InsufficientStorageSpace
from .InsufficientVFlashResourcesFault import InsufficientVFlashResourcesFault as InsufficientVFlashResourcesFault
from .InvalidAffinitySettingFault import InvalidAffinitySettingFault as InvalidAffinitySettingFault
from .InvalidBmcRole import InvalidBmcRole as InvalidBmcRole
from .InvalidBundle import InvalidBundle as InvalidBundle
from .InvalidCAMCertificate import InvalidCAMCertificate as InvalidCAMCertificate
from .InvalidCAMServer import InvalidCAMServer as InvalidCAMServer
from .InvalidClientCertificate import InvalidClientCertificate as InvalidClientCertificate
from .InvalidController import InvalidController as InvalidController
from .InvalidDasConfigArgument import InvalidDasConfigArgument as InvalidDasConfigArgument
from .InvalidDasRestartPriorityForFtVm import InvalidDasRestartPriorityForFtVm as InvalidDasRestartPriorityForFtVm
from .InvalidDatastore import InvalidDatastore as InvalidDatastore
from .InvalidDatastorePath import InvalidDatastorePath as InvalidDatastorePath
from .InvalidDatastoreState import InvalidDatastoreState as InvalidDatastoreState
from .InvalidDeviceBacking import InvalidDeviceBacking as InvalidDeviceBacking
from .InvalidDeviceOperation import InvalidDeviceOperation as InvalidDeviceOperation
from .InvalidDeviceSpec import InvalidDeviceSpec as InvalidDeviceSpec
from .InvalidDiskFormat import InvalidDiskFormat as InvalidDiskFormat
from .InvalidDrsBehaviorForFtVm import InvalidDrsBehaviorForFtVm as InvalidDrsBehaviorForFtVm
from .InvalidEditionLicense import InvalidEditionLicense as InvalidEditionLicense
from .InvalidEvent import InvalidEvent as InvalidEvent
from .InvalidFolder import InvalidFolder as InvalidFolder
from .InvalidFormat import InvalidFormat as InvalidFormat
from .InvalidGuestLogin import InvalidGuestLogin as InvalidGuestLogin
from .InvalidHostConnectionState import InvalidHostConnectionState as InvalidHostConnectionState
from .InvalidHostName import InvalidHostName as InvalidHostName
from .InvalidHostState import InvalidHostState as InvalidHostState
from .InvalidIndexArgument import InvalidIndexArgument as InvalidIndexArgument
from .InvalidIpfixConfig import InvalidIpfixConfig as InvalidIpfixConfig
from .InvalidIpmiLoginInfo import InvalidIpmiLoginInfo as InvalidIpmiLoginInfo
from .InvalidIpmiMacAddress import InvalidIpmiMacAddress as InvalidIpmiMacAddress
from .InvalidLicense import InvalidLicense as InvalidLicense
from .InvalidLocale import InvalidLocale as InvalidLocale
from .InvalidLogin import InvalidLogin as InvalidLogin
from .InvalidName import InvalidName as InvalidName
from .InvalidNasCredentials import InvalidNasCredentials as InvalidNasCredentials
from .InvalidNetworkInType import InvalidNetworkInType as InvalidNetworkInType
from .InvalidNetworkResource import InvalidNetworkResource as InvalidNetworkResource
from .InvalidOperationOnSecondaryVm import InvalidOperationOnSecondaryVm as InvalidOperationOnSecondaryVm
from .InvalidPowerState import InvalidPowerState as InvalidPowerState
from .InvalidPrivilege import InvalidPrivilege as InvalidPrivilege
from .InvalidProfileReferenceHost import InvalidProfileReferenceHost as InvalidProfileReferenceHost
from .InvalidPropertyType import InvalidPropertyType as InvalidPropertyType
from .InvalidPropertyValue import InvalidPropertyValue as InvalidPropertyValue
from .InvalidResourcePoolStructureFault import InvalidResourcePoolStructureFault as InvalidResourcePoolStructureFault
from .InvalidScheduledTask import InvalidScheduledTask as InvalidScheduledTask
from .InvalidSnapshotFormat import InvalidSnapshotFormat as InvalidSnapshotFormat
from .InvalidState import InvalidState as InvalidState
from .InvalidVmConfig import InvalidVmConfig as InvalidVmConfig
from .InvalidVmState import InvalidVmState as InvalidVmState
from .InventoryHasStandardAloneHosts import InventoryHasStandardAloneHosts as InventoryHasStandardAloneHosts
from .IpHostnameGeneratorError import IpHostnameGeneratorError as IpHostnameGeneratorError
from .IscsiFault import IscsiFault as IscsiFault
from .IscsiFaultInvalidVnic import IscsiFaultInvalidVnic as IscsiFaultInvalidVnic
from .IscsiFaultPnicInUse import IscsiFaultPnicInUse as IscsiFaultPnicInUse
from .IscsiFaultVnicAlreadyBound import IscsiFaultVnicAlreadyBound as IscsiFaultVnicAlreadyBound
from .IscsiFaultVnicHasActivePaths import IscsiFaultVnicHasActivePaths as IscsiFaultVnicHasActivePaths
from .IscsiFaultVnicHasMultipleUplinks import IscsiFaultVnicHasMultipleUplinks as IscsiFaultVnicHasMultipleUplinks
from .IscsiFaultVnicHasNoUplinks import IscsiFaultVnicHasNoUplinks as IscsiFaultVnicHasNoUplinks
from .IscsiFaultVnicHasWrongUplink import IscsiFaultVnicHasWrongUplink as IscsiFaultVnicHasWrongUplink
from .IscsiFaultVnicInUse import IscsiFaultVnicInUse as IscsiFaultVnicInUse
from .IscsiFaultVnicIsLastPath import IscsiFaultVnicIsLastPath as IscsiFaultVnicIsLastPath
from .IscsiFaultVnicNotBound import IscsiFaultVnicNotBound as IscsiFaultVnicNotBound
from .IscsiFaultVnicNotFound import IscsiFaultVnicNotFound as IscsiFaultVnicNotFound
from .KeyNotFound import KeyNotFound as KeyNotFound
from .LargeRDMConversionNotSupported import LargeRDMConversionNotSupported as LargeRDMConversionNotSupported
from .LargeRDMNotSupportedOnDatastore import LargeRDMNotSupportedOnDatastore as LargeRDMNotSupportedOnDatastore
from .LegacyNetworkInterfaceInUse import LegacyNetworkInterfaceInUse as LegacyNetworkInterfaceInUse
from .LicenseAssignmentFailed import LicenseAssignmentFailed as LicenseAssignmentFailed
from .LicenseDowngradeDisallowed import LicenseDowngradeDisallowed as LicenseDowngradeDisallowed
from .LicenseEntityNotFound import LicenseEntityNotFound as LicenseEntityNotFound
from .LicenseExpired import LicenseExpired as LicenseExpired
from .LicenseKeyEntityMismatch import LicenseKeyEntityMismatch as LicenseKeyEntityMismatch
from .LicenseRestricted import LicenseRestricted as LicenseRestricted
from .LicenseServerUnavailable import LicenseServerUnavailable as LicenseServerUnavailable
from .LicenseSourceUnavailable import LicenseSourceUnavailable as LicenseSourceUnavailable
from .LimitExceeded import LimitExceeded as LimitExceeded
from .LinuxVolumeNotClean import LinuxVolumeNotClean as LinuxVolumeNotClean
from .LogBundlingFailed import LogBundlingFailed as LogBundlingFailed
from .MaintenanceModeFileMove import MaintenanceModeFileMove as MaintenanceModeFileMove
from .MemoryFileFormatNotSupportedByDatastore import MemoryFileFormatNotSupportedByDatastore as MemoryFileFormatNotSupportedByDatastore
from .MemoryHotPlugNotSupported import MemoryHotPlugNotSupported as MemoryHotPlugNotSupported
from .MemorySizeNotRecommended import MemorySizeNotRecommended as MemorySizeNotRecommended
from .MemorySizeNotSupported import MemorySizeNotSupported as MemorySizeNotSupported
from .MemorySizeNotSupportedByDatastore import MemorySizeNotSupportedByDatastore as MemorySizeNotSupportedByDatastore
from .MemorySnapshotOnIndependentDisk import MemorySnapshotOnIndependentDisk as MemorySnapshotOnIndependentDisk
from .MethodAlreadyDisabledFault import MethodAlreadyDisabledFault as MethodAlreadyDisabledFault
from .MethodDisabled import MethodDisabled as MethodDisabled
from .MigrationDisabled import MigrationDisabled as MigrationDisabled
from .MigrationFault import MigrationFault as MigrationFault
from .MigrationFeatureNotSupported import MigrationFeatureNotSupported as MigrationFeatureNotSupported
from .MigrationNotReady import MigrationNotReady as MigrationNotReady
from .MismatchedBundle import MismatchedBundle as MismatchedBundle
from .MismatchedNetworkPolicies import MismatchedNetworkPolicies as MismatchedNetworkPolicies
from .MismatchedVMotionNetworkNames import MismatchedVMotionNetworkNames as MismatchedVMotionNetworkNames
from .MissingBmcSupport import MissingBmcSupport as MissingBmcSupport
from .MissingController import MissingController as MissingController
from .MissingIpPool import MissingIpPool as MissingIpPool
from .MissingLinuxCustResources import MissingLinuxCustResources as MissingLinuxCustResources
from .MissingNetworkIpConfig import MissingNetworkIpConfig as MissingNetworkIpConfig
from .MissingPowerOffConfiguration import MissingPowerOffConfiguration as MissingPowerOffConfiguration
from .MissingPowerOnConfiguration import MissingPowerOnConfiguration as MissingPowerOnConfiguration
from .MissingWindowsCustResources import MissingWindowsCustResources as MissingWindowsCustResources
from .MksConnectionLimitReached import MksConnectionLimitReached as MksConnectionLimitReached
from .MountError import MountError as MountError
from .MultiWriterNotSupported import MultiWriterNotSupported as MultiWriterNotSupported
from .MultipleCertificatesVerifyFault import MultipleCertificatesVerifyFault as MultipleCertificatesVerifyFault
from .MultipleSnapshotsNotSupported import MultipleSnapshotsNotSupported as MultipleSnapshotsNotSupported
from .NamespaceFull import NamespaceFull as NamespaceFull
from .NamespaceLimitReached import NamespaceLimitReached as NamespaceLimitReached
from .NamespaceWriteProtected import NamespaceWriteProtected as NamespaceWriteProtected
from .NasConfigFault import NasConfigFault as NasConfigFault
from .NasConnectionLimitReached import NasConnectionLimitReached as NasConnectionLimitReached
from .NasSessionCredentialConflict import NasSessionCredentialConflict as NasSessionCredentialConflict
from .NasVolumeNotMounted import NasVolumeNotMounted as NasVolumeNotMounted
from .NetworkCopyFault import NetworkCopyFault as NetworkCopyFault
from .NetworkDisruptedAndConfigRolledBack import NetworkDisruptedAndConfigRolledBack as NetworkDisruptedAndConfigRolledBack
from .NetworkInaccessible import NetworkInaccessible as NetworkInaccessible
from .NetworksMayNotBeTheSame import NetworksMayNotBeTheSame as NetworksMayNotBeTheSame
from .NicSettingMismatch import NicSettingMismatch as NicSettingMismatch
from .NoActiveHostInCluster import NoActiveHostInCluster as NoActiveHostInCluster
from .NoAvailableIp import NoAvailableIp as NoAvailableIp
from .NoClientCertificate import NoClientCertificate as NoClientCertificate
from .NoCompatibleDatastore import NoCompatibleDatastore as NoCompatibleDatastore
from .NoCompatibleHardAffinityHost import NoCompatibleHardAffinityHost as NoCompatibleHardAffinityHost
from .NoCompatibleHost import NoCompatibleHost as NoCompatibleHost
from .NoCompatibleHostWithAccessToDevice import NoCompatibleHostWithAccessToDevice as NoCompatibleHostWithAccessToDevice
from .NoCompatibleSoftAffinityHost import NoCompatibleSoftAffinityHost as NoCompatibleSoftAffinityHost
from .NoConnectedDatastore import NoConnectedDatastore as NoConnectedDatastore
from .NoDiskFound import NoDiskFound as NoDiskFound
from .NoDiskSpace import NoDiskSpace as NoDiskSpace
from .NoDisksToCustomize import NoDisksToCustomize as NoDisksToCustomize
from .NoGateway import NoGateway as NoGateway
from .NoGuestHeartbeat import NoGuestHeartbeat as NoGuestHeartbeat
from .NoHost import NoHost as NoHost
from .NoHostSuitableForFtSecondary import NoHostSuitableForFtSecondary as NoHostSuitableForFtSecondary
from .NoLicenseServerConfigured import NoLicenseServerConfigured as NoLicenseServerConfigured
from .NoPeerHostFound import NoPeerHostFound as NoPeerHostFound
from .NoPermission import NoPermission as NoPermission
from .NoPermissionOnAD import NoPermissionOnAD as NoPermissionOnAD
from .NoPermissionOnHost import NoPermissionOnHost as NoPermissionOnHost
from .NoPermissionOnNasVolume import NoPermissionOnNasVolume as NoPermissionOnNasVolume
from .NoSubjectName import NoSubjectName as NoSubjectName
from .NoVcManagedIpConfigured import NoVcManagedIpConfigured as NoVcManagedIpConfigured
from .NoVirtualNic import NoVirtualNic as NoVirtualNic
from .NoVmInVApp import NoVmInVApp as NoVmInVApp
from .NonADUserRequired import NonADUserRequired as NonADUserRequired
from .NonHomeRDMVMotionNotSupported import NonHomeRDMVMotionNotSupported as NonHomeRDMVMotionNotSupported
from .NonPersistentDisksNotSupported import NonPersistentDisksNotSupported as NonPersistentDisksNotSupported
from .NonVmwareOuiMacNotSupportedHost import NonVmwareOuiMacNotSupportedHost as NonVmwareOuiMacNotSupportedHost
from .NotADirectory import NotADirectory as NotADirectory
from .NotAFile import NotAFile as NotAFile
from .NotAuthenticated import NotAuthenticated as NotAuthenticated
from .NotEnoughCpus import NotEnoughCpus as NotEnoughCpus
from .NotEnoughLogicalCpus import NotEnoughLogicalCpus as NotEnoughLogicalCpus
from .NotFound import NotFound as NotFound
from .NotSupportedDeviceForFT import NotSupportedDeviceForFT as NotSupportedDeviceForFT
from .NotSupportedHost import NotSupportedHost as NotSupportedHost
from .NotSupportedHostForChecksum import NotSupportedHostForChecksum as NotSupportedHostForChecksum
from .NotSupportedHostForVFlash import NotSupportedHostForVFlash as NotSupportedHostForVFlash
from .NotSupportedHostForVmcp import NotSupportedHostForVmcp as NotSupportedHostForVmcp
from .NotSupportedHostForVmemFile import NotSupportedHostForVmemFile as NotSupportedHostForVmemFile
from .NotSupportedHostForVsan import NotSupportedHostForVsan as NotSupportedHostForVsan
from .NotSupportedHostInCluster import NotSupportedHostInCluster as NotSupportedHostInCluster
from .NotSupportedHostInDvs import NotSupportedHostInDvs as NotSupportedHostInDvs
from .NotSupportedHostInHACluster import NotSupportedHostInHACluster as NotSupportedHostInHACluster
from .NotUserConfigurableProperty import NotUserConfigurableProperty as NotUserConfigurableProperty
from .NumVirtualCoresPerSocketNotSupported import NumVirtualCoresPerSocketNotSupported as NumVirtualCoresPerSocketNotSupported
from .NumVirtualCpusExceedsLimit import NumVirtualCpusExceedsLimit as NumVirtualCpusExceedsLimit
from .NumVirtualCpusIncompatible import NumVirtualCpusIncompatible as NumVirtualCpusIncompatible
from .NumVirtualCpusNotSupported import NumVirtualCpusNotSupported as NumVirtualCpusNotSupported
from .OperationDisabledByGuest import OperationDisabledByGuest as OperationDisabledByGuest
from .OperationDisallowedOnHost import OperationDisallowedOnHost as OperationDisallowedOnHost
from .OperationNotSupportedByGuest import OperationNotSupportedByGuest as OperationNotSupportedByGuest
from .OutOfBounds import OutOfBounds as OutOfBounds
from .OvfAttribute import OvfAttribute as OvfAttribute
from .OvfConnectedDevice import OvfConnectedDevice as OvfConnectedDevice
from .OvfConnectedDeviceFloppy import OvfConnectedDeviceFloppy as OvfConnectedDeviceFloppy
from .OvfConnectedDeviceIso import OvfConnectedDeviceIso as OvfConnectedDeviceIso
from .OvfConstraint import OvfConstraint as OvfConstraint
from .OvfConsumerCallbackFault import OvfConsumerCallbackFault as OvfConsumerCallbackFault
from .OvfConsumerCommunicationError import OvfConsumerCommunicationError as OvfConsumerCommunicationError
from .OvfConsumerFault import OvfConsumerFault as OvfConsumerFault
from .OvfConsumerInvalidSection import OvfConsumerInvalidSection as OvfConsumerInvalidSection
from .OvfConsumerPowerOnFault import OvfConsumerPowerOnFault as OvfConsumerPowerOnFault
from .OvfConsumerUndeclaredSection import OvfConsumerUndeclaredSection as OvfConsumerUndeclaredSection
from .OvfConsumerUndefinedPrefix import OvfConsumerUndefinedPrefix as OvfConsumerUndefinedPrefix
from .OvfConsumerValidationFault import OvfConsumerValidationFault as OvfConsumerValidationFault
from .OvfCpuCompatibility import OvfCpuCompatibility as OvfCpuCompatibility
from .OvfCpuCompatibilityCheckNotSupported import OvfCpuCompatibilityCheckNotSupported as OvfCpuCompatibilityCheckNotSupported
from .OvfDiskMappingNotFound import OvfDiskMappingNotFound as OvfDiskMappingNotFound
from .OvfDiskOrderConstraint import OvfDiskOrderConstraint as OvfDiskOrderConstraint
from .OvfDuplicateElement import OvfDuplicateElement as OvfDuplicateElement
from .OvfDuplicatedElementBoundary import OvfDuplicatedElementBoundary as OvfDuplicatedElementBoundary
from .OvfDuplicatedPropertyIdExport import OvfDuplicatedPropertyIdExport as OvfDuplicatedPropertyIdExport
from .OvfDuplicatedPropertyIdImport import OvfDuplicatedPropertyIdImport as OvfDuplicatedPropertyIdImport
from .OvfElement import OvfElement as OvfElement
from .OvfElementInvalidValue import OvfElementInvalidValue as OvfElementInvalidValue
from .OvfExport import OvfExport as OvfExport
from .OvfExportFailed import OvfExportFailed as OvfExportFailed
from .OvfFault import OvfFault as OvfFault
from .OvfHardwareCheck import OvfHardwareCheck as OvfHardwareCheck
from .OvfHardwareExport import OvfHardwareExport as OvfHardwareExport
from .OvfHostResourceConstraint import OvfHostResourceConstraint as OvfHostResourceConstraint
from .OvfHostValueNotParsed import OvfHostValueNotParsed as OvfHostValueNotParsed
from .OvfImport import OvfImport as OvfImport
from .OvfImportFailed import OvfImportFailed as OvfImportFailed
from .OvfInternalError import OvfInternalError as OvfInternalError
from .OvfInvalidPackage import OvfInvalidPackage as OvfInvalidPackage
from .OvfInvalidValue import OvfInvalidValue as OvfInvalidValue
from .OvfInvalidValueConfiguration import OvfInvalidValueConfiguration as OvfInvalidValueConfiguration
from .OvfInvalidValueEmpty import OvfInvalidValueEmpty as OvfInvalidValueEmpty
from .OvfInvalidValueFormatMalformed import OvfInvalidValueFormatMalformed as OvfInvalidValueFormatMalformed
from .OvfInvalidValueReference import OvfInvalidValueReference as OvfInvalidValueReference
from .OvfInvalidVmName import OvfInvalidVmName as OvfInvalidVmName
from .OvfMappedOsId import OvfMappedOsId as OvfMappedOsId
from .OvfMissingAttribute import OvfMissingAttribute as OvfMissingAttribute
from .OvfMissingElement import OvfMissingElement as OvfMissingElement
from .OvfMissingElementNormalBoundary import OvfMissingElementNormalBoundary as OvfMissingElementNormalBoundary
from .OvfMissingHardware import OvfMissingHardware as OvfMissingHardware
from .OvfNetworkMappingNotSupported import OvfNetworkMappingNotSupported as OvfNetworkMappingNotSupported
from .OvfNoHostNic import OvfNoHostNic as OvfNoHostNic
from .OvfNoSpaceOnController import OvfNoSpaceOnController as OvfNoSpaceOnController
from .OvfNoSupportedHardwareFamily import OvfNoSupportedHardwareFamily as OvfNoSupportedHardwareFamily
from .OvfProperty import OvfProperty as OvfProperty
from .OvfPropertyExport import OvfPropertyExport as OvfPropertyExport
from .OvfPropertyNetwork import OvfPropertyNetwork as OvfPropertyNetwork
from .OvfPropertyNetworkExport import OvfPropertyNetworkExport as OvfPropertyNetworkExport
from .OvfPropertyQualifier import OvfPropertyQualifier as OvfPropertyQualifier
from .OvfPropertyQualifierDuplicate import OvfPropertyQualifierDuplicate as OvfPropertyQualifierDuplicate
from .OvfPropertyQualifierIgnored import OvfPropertyQualifierIgnored as OvfPropertyQualifierIgnored
from .OvfPropertyType import OvfPropertyType as OvfPropertyType
from .OvfPropertyValue import OvfPropertyValue as OvfPropertyValue
from .OvfSystemFault import OvfSystemFault as OvfSystemFault
from .OvfToXmlUnsupportedElement import OvfToXmlUnsupportedElement as OvfToXmlUnsupportedElement
from .OvfUnableToExportDisk import OvfUnableToExportDisk as OvfUnableToExportDisk
from .OvfUnexpectedElement import OvfUnexpectedElement as OvfUnexpectedElement
from .OvfUnknownDevice import OvfUnknownDevice as OvfUnknownDevice
from .OvfUnknownDeviceBacking import OvfUnknownDeviceBacking as OvfUnknownDeviceBacking
from .OvfUnknownEntity import OvfUnknownEntity as OvfUnknownEntity
from .OvfUnsupportedAttribute import OvfUnsupportedAttribute as OvfUnsupportedAttribute
from .OvfUnsupportedAttributeValue import OvfUnsupportedAttributeValue as OvfUnsupportedAttributeValue
from .OvfUnsupportedDeviceBackingInfo import OvfUnsupportedDeviceBackingInfo as OvfUnsupportedDeviceBackingInfo
from .OvfUnsupportedDeviceBackingOption import OvfUnsupportedDeviceBackingOption as OvfUnsupportedDeviceBackingOption
from .OvfUnsupportedDeviceExport import OvfUnsupportedDeviceExport as OvfUnsupportedDeviceExport
from .OvfUnsupportedDiskProvisioning import OvfUnsupportedDiskProvisioning as OvfUnsupportedDiskProvisioning
from .OvfUnsupportedElement import OvfUnsupportedElement as OvfUnsupportedElement
from .OvfUnsupportedElementValue import OvfUnsupportedElementValue as OvfUnsupportedElementValue
from .OvfUnsupportedPackage import OvfUnsupportedPackage as OvfUnsupportedPackage
from .OvfUnsupportedSection import OvfUnsupportedSection as OvfUnsupportedSection
from .OvfUnsupportedSubType import OvfUnsupportedSubType as OvfUnsupportedSubType
from .OvfUnsupportedType import OvfUnsupportedType as OvfUnsupportedType
from .OvfWrongElement import OvfWrongElement as OvfWrongElement
from .OvfWrongNamespace import OvfWrongNamespace as OvfWrongNamespace
from .OvfXmlFormat import OvfXmlFormat as OvfXmlFormat
from .PasswordExpired import PasswordExpired as PasswordExpired
from .PatchAlreadyInstalled import PatchAlreadyInstalled as PatchAlreadyInstalled
from .PatchBinariesNotFound import PatchBinariesNotFound as PatchBinariesNotFound
from .PatchInstallFailed import PatchInstallFailed as PatchInstallFailed
from .PatchIntegrityError import PatchIntegrityError as PatchIntegrityError
from .PatchMetadataCorrupted import PatchMetadataCorrupted as PatchMetadataCorrupted
from .PatchMetadataInvalid import PatchMetadataInvalid as PatchMetadataInvalid
from .PatchMetadataNotFound import PatchMetadataNotFound as PatchMetadataNotFound
from .PatchMissingDependencies import PatchMissingDependencies as PatchMissingDependencies
from .PatchNotApplicable import PatchNotApplicable as PatchNotApplicable
from .PatchSuperseded import PatchSuperseded as PatchSuperseded
from .PhysCompatRDMNotSupported import PhysCompatRDMNotSupported as PhysCompatRDMNotSupported
from .PlatformConfigFault import PlatformConfigFault as PlatformConfigFault
from .PowerOnFtSecondaryFailed import PowerOnFtSecondaryFailed as PowerOnFtSecondaryFailed
from .PowerOnFtSecondaryTimedout import PowerOnFtSecondaryTimedout as PowerOnFtSecondaryTimedout
from .ProfileUpdateFailed import ProfileUpdateFailed as ProfileUpdateFailed
from .QuarantineModeFault import QuarantineModeFault as QuarantineModeFault
from .QuestionPending import QuestionPending as QuestionPending
from .QuiesceDatastoreIOForHAFailed import QuiesceDatastoreIOForHAFailed as QuiesceDatastoreIOForHAFailed
from .RDMConversionNotSupported import RDMConversionNotSupported as RDMConversionNotSupported
from .RDMNotPreserved import RDMNotPreserved as RDMNotPreserved
from .RDMNotSupported import RDMNotSupported as RDMNotSupported
from .RDMNotSupportedOnDatastore import RDMNotSupportedOnDatastore as RDMNotSupportedOnDatastore
from .RDMPointsToInaccessibleDisk import RDMPointsToInaccessibleDisk as RDMPointsToInaccessibleDisk
from .RawDiskNotSupported import RawDiskNotSupported as RawDiskNotSupported
from .ReadHostResourcePoolTreeFailed import ReadHostResourcePoolTreeFailed as ReadHostResourcePoolTreeFailed
from .ReadOnlyDisksWithLegacyDestination import ReadOnlyDisksWithLegacyDestination as ReadOnlyDisksWithLegacyDestination
from .RebootRequired import RebootRequired as RebootRequired
from .RecordReplayDisabled import RecordReplayDisabled as RecordReplayDisabled
from .RemoteDeviceNotSupported import RemoteDeviceNotSupported as RemoteDeviceNotSupported
from .RemoveFailed import RemoveFailed as RemoveFailed
from .ReplicationConfigFault import ReplicationConfigFault as ReplicationConfigFault
from .ReplicationDiskConfigFault import ReplicationDiskConfigFault as ReplicationDiskConfigFault
from .ReplicationFault import ReplicationFault as ReplicationFault
from .ReplicationIncompatibleWithFT import ReplicationIncompatibleWithFT as ReplicationIncompatibleWithFT
from .ReplicationInvalidOptions import ReplicationInvalidOptions as ReplicationInvalidOptions
from .ReplicationNotSupportedOnHost import ReplicationNotSupportedOnHost as ReplicationNotSupportedOnHost
from .ReplicationVmConfigFault import ReplicationVmConfigFault as ReplicationVmConfigFault
from .ReplicationVmFault import ReplicationVmFault as ReplicationVmFault
from .ReplicationVmInProgressFault import ReplicationVmInProgressFault as ReplicationVmInProgressFault
from .ResourceInUse import ResourceInUse as ResourceInUse
from .ResourceNotAvailable import ResourceNotAvailable as ResourceNotAvailable
from .RestrictedByAdministrator import RestrictedByAdministrator as RestrictedByAdministrator
from .RestrictedVersion import RestrictedVersion as RestrictedVersion
from .RollbackFailure import RollbackFailure as RollbackFailure
from .RuleViolation import RuleViolation as RuleViolation
from .SSLDisabledFault import SSLDisabledFault as SSLDisabledFault
from .SSLVerifyFault import SSLVerifyFault as SSLVerifyFault
from .SSPIChallenge import SSPIChallenge as SSPIChallenge
from .SecondaryVmAlreadyDisabled import SecondaryVmAlreadyDisabled as SecondaryVmAlreadyDisabled
from .SecondaryVmAlreadyEnabled import SecondaryVmAlreadyEnabled as SecondaryVmAlreadyEnabled
from .SecondaryVmAlreadyRegistered import SecondaryVmAlreadyRegistered as SecondaryVmAlreadyRegistered
from .SecondaryVmNotRegistered import SecondaryVmNotRegistered as SecondaryVmNotRegistered
from .SharedBusControllerNotSupported import SharedBusControllerNotSupported as SharedBusControllerNotSupported
from .ShrinkDiskFault import ShrinkDiskFault as ShrinkDiskFault
from .SnapshotCloneNotSupported import SnapshotCloneNotSupported as SnapshotCloneNotSupported
from .SnapshotCopyNotSupported import SnapshotCopyNotSupported as SnapshotCopyNotSupported
from .SnapshotDisabled import SnapshotDisabled as SnapshotDisabled
from .SnapshotFault import SnapshotFault as SnapshotFault
from .SnapshotIncompatibleDeviceInVm import SnapshotIncompatibleDeviceInVm as SnapshotIncompatibleDeviceInVm
from .SnapshotLocked import SnapshotLocked as SnapshotLocked
from .SnapshotMoveFromNonHomeNotSupported import SnapshotMoveFromNonHomeNotSupported as SnapshotMoveFromNonHomeNotSupported
from .SnapshotMoveNotSupported import SnapshotMoveNotSupported as SnapshotMoveNotSupported
from .SnapshotMoveToNonHomeNotSupported import SnapshotMoveToNonHomeNotSupported as SnapshotMoveToNonHomeNotSupported
from .SnapshotNoChange import SnapshotNoChange as SnapshotNoChange
from .SnapshotRevertIssue import SnapshotRevertIssue as SnapshotRevertIssue
from .SoftRuleVioCorrectionDisallowed import SoftRuleVioCorrectionDisallowed as SoftRuleVioCorrectionDisallowed
from .SoftRuleVioCorrectionImpact import SoftRuleVioCorrectionImpact as SoftRuleVioCorrectionImpact
from .SolutionUserRequired import SolutionUserRequired as SolutionUserRequired
from .SsdDiskNotAvailable import SsdDiskNotAvailable as SsdDiskNotAvailable
from .StorageDrsCannotMoveDiskInMultiWriterMode import StorageDrsCannotMoveDiskInMultiWriterMode as StorageDrsCannotMoveDiskInMultiWriterMode
from .StorageDrsCannotMoveFTVm import StorageDrsCannotMoveFTVm as StorageDrsCannotMoveFTVm
from .StorageDrsCannotMoveIndependentDisk import StorageDrsCannotMoveIndependentDisk as StorageDrsCannotMoveIndependentDisk
from .StorageDrsCannotMoveManuallyPlacedSwapFile import StorageDrsCannotMoveManuallyPlacedSwapFile as StorageDrsCannotMoveManuallyPlacedSwapFile
from .StorageDrsCannotMoveManuallyPlacedVm import StorageDrsCannotMoveManuallyPlacedVm as StorageDrsCannotMoveManuallyPlacedVm
from .StorageDrsCannotMoveSharedDisk import StorageDrsCannotMoveSharedDisk as StorageDrsCannotMoveSharedDisk
from .StorageDrsCannotMoveTemplate import StorageDrsCannotMoveTemplate as StorageDrsCannotMoveTemplate
from .StorageDrsCannotMoveVmInUserFolder import StorageDrsCannotMoveVmInUserFolder as StorageDrsCannotMoveVmInUserFolder
from .StorageDrsCannotMoveVmWithMountedCDROM import StorageDrsCannotMoveVmWithMountedCDROM as StorageDrsCannotMoveVmWithMountedCDROM
from .StorageDrsCannotMoveVmWithNoFilesInLayout import StorageDrsCannotMoveVmWithNoFilesInLayout as StorageDrsCannotMoveVmWithNoFilesInLayout
from .StorageDrsDatacentersCannotShareDatastore import StorageDrsDatacentersCannotShareDatastore as StorageDrsDatacentersCannotShareDatastore
from .StorageDrsDisabledOnVm import StorageDrsDisabledOnVm as StorageDrsDisabledOnVm
from .StorageDrsHbrDiskNotMovable import StorageDrsHbrDiskNotMovable as StorageDrsHbrDiskNotMovable
from .StorageDrsHmsMoveInProgress import StorageDrsHmsMoveInProgress as StorageDrsHmsMoveInProgress
from .StorageDrsHmsUnreachable import StorageDrsHmsUnreachable as StorageDrsHmsUnreachable
from .StorageDrsIolbDisabledInternally import StorageDrsIolbDisabledInternally as StorageDrsIolbDisabledInternally
from .StorageDrsRelocateDisabled import StorageDrsRelocateDisabled as StorageDrsRelocateDisabled
from .StorageDrsStaleHmsCollection import StorageDrsStaleHmsCollection as StorageDrsStaleHmsCollection
from .StorageDrsUnableToMoveFiles import StorageDrsUnableToMoveFiles as StorageDrsUnableToMoveFiles
from .StorageVMotionNotSupported import StorageVMotionNotSupported as StorageVMotionNotSupported
from .StorageVmotionIncompatible import StorageVmotionIncompatible as StorageVmotionIncompatible
from .SuspendedRelocateNotSupported import SuspendedRelocateNotSupported as SuspendedRelocateNotSupported
from .SwapDatastoreNotWritableOnHost import SwapDatastoreNotWritableOnHost as SwapDatastoreNotWritableOnHost
from .SwapDatastoreUnset import SwapDatastoreUnset as SwapDatastoreUnset
from .SwapPlacementOverrideNotSupported import SwapPlacementOverrideNotSupported as SwapPlacementOverrideNotSupported
from .SwitchIpUnset import SwitchIpUnset as SwitchIpUnset
from .SwitchNotInUpgradeMode import SwitchNotInUpgradeMode as SwitchNotInUpgradeMode
from .TaskInProgress import TaskInProgress as TaskInProgress
from .ThirdPartyLicenseAssignmentFailed import ThirdPartyLicenseAssignmentFailed as ThirdPartyLicenseAssignmentFailed
from .Timedout import Timedout as Timedout
from .TooManyConcurrentNativeClones import TooManyConcurrentNativeClones as TooManyConcurrentNativeClones
from .TooManyConsecutiveOverrides import TooManyConsecutiveOverrides as TooManyConsecutiveOverrides
from .TooManyDevices import TooManyDevices as TooManyDevices
from .TooManyDisksOnLegacyHost import TooManyDisksOnLegacyHost as TooManyDisksOnLegacyHost
from .TooManyGuestLogons import TooManyGuestLogons as TooManyGuestLogons
from .TooManyHosts import TooManyHosts as TooManyHosts
from .TooManyNativeCloneLevels import TooManyNativeCloneLevels as TooManyNativeCloneLevels
from .TooManyNativeClonesOnFile import TooManyNativeClonesOnFile as TooManyNativeClonesOnFile
from .TooManySnapshotLevels import TooManySnapshotLevels as TooManySnapshotLevels
from .ToolsAlreadyUpgraded import ToolsAlreadyUpgraded as ToolsAlreadyUpgraded
from .ToolsAutoUpgradeNotSupported import ToolsAutoUpgradeNotSupported as ToolsAutoUpgradeNotSupported
from .ToolsImageCopyFailed import ToolsImageCopyFailed as ToolsImageCopyFailed
from .ToolsImageNotAvailable import ToolsImageNotAvailable as ToolsImageNotAvailable
from .ToolsImageSignatureCheckFailed import ToolsImageSignatureCheckFailed as ToolsImageSignatureCheckFailed
from .ToolsInstallationInProgress import ToolsInstallationInProgress as ToolsInstallationInProgress
from .ToolsUnavailable import ToolsUnavailable as ToolsUnavailable
from .ToolsUpgradeCancelled import ToolsUpgradeCancelled as ToolsUpgradeCancelled
from .UnSupportedDatastoreForVFlash import UnSupportedDatastoreForVFlash as UnSupportedDatastoreForVFlash
from .UncommittedUndoableDisk import UncommittedUndoableDisk as UncommittedUndoableDisk
from .UnconfiguredPropertyValue import UnconfiguredPropertyValue as UnconfiguredPropertyValue
from .UncustomizableGuest import UncustomizableGuest as UncustomizableGuest
from .UnexpectedCustomizationFault import UnexpectedCustomizationFault as UnexpectedCustomizationFault
from .UnrecognizedHost import UnrecognizedHost as UnrecognizedHost
from .UnsharedSwapVMotionNotSupported import UnsharedSwapVMotionNotSupported as UnsharedSwapVMotionNotSupported
from .UnsupportedDatastore import UnsupportedDatastore as UnsupportedDatastore
from .UnsupportedGuest import UnsupportedGuest as UnsupportedGuest
from .UnsupportedVimApiVersion import UnsupportedVimApiVersion as UnsupportedVimApiVersion
from .UnsupportedVmxLocation import UnsupportedVmxLocation as UnsupportedVmxLocation
from .UnusedVirtualDiskBlocksNotScrubbed import UnusedVirtualDiskBlocksNotScrubbed as UnusedVirtualDiskBlocksNotScrubbed
from .UserNotFound import UserNotFound as UserNotFound
from .VAppConfigFault import VAppConfigFault as VAppConfigFault
from .VAppNotRunning import VAppNotRunning as VAppNotRunning
from .VAppOperationInProgress import VAppOperationInProgress as VAppOperationInProgress
from .VAppPropertyFault import VAppPropertyFault as VAppPropertyFault
from .VAppTaskInProgress import VAppTaskInProgress as VAppTaskInProgress
from .VFlashCacheHotConfigNotSupported import VFlashCacheHotConfigNotSupported as VFlashCacheHotConfigNotSupported
from .VFlashModuleNotSupported import VFlashModuleNotSupported as VFlashModuleNotSupported
from .VFlashModuleVersionIncompatible import VFlashModuleVersionIncompatible as VFlashModuleVersionIncompatible
from .VMINotSupported import VMINotSupported as VMINotSupported
from .VMOnConflictDVPort import VMOnConflictDVPort as VMOnConflictDVPort
from .VMOnVirtualIntranet import VMOnVirtualIntranet as VMOnVirtualIntranet
from .VMotionAcrossNetworkNotSupported import VMotionAcrossNetworkNotSupported as VMotionAcrossNetworkNotSupported
from .VMotionInterfaceIssue import VMotionInterfaceIssue as VMotionInterfaceIssue
from .VMotionLinkCapacityLow import VMotionLinkCapacityLow as VMotionLinkCapacityLow
from .VMotionLinkDown import VMotionLinkDown as VMotionLinkDown
from .VMotionNotConfigured import VMotionNotConfigured as VMotionNotConfigured
from .VMotionNotLicensed import VMotionNotLicensed as VMotionNotLicensed
from .VMotionNotSupported import VMotionNotSupported as VMotionNotSupported
from .VMotionProtocolIncompatible import VMotionProtocolIncompatible as VMotionProtocolIncompatible
from .VimFault import VimFault as VimFault
from .VirtualDiskBlocksNotFullyProvisioned import VirtualDiskBlocksNotFullyProvisioned as VirtualDiskBlocksNotFullyProvisioned
from .VirtualDiskModeNotSupported import VirtualDiskModeNotSupported as VirtualDiskModeNotSupported
from .VirtualEthernetCardNotSupported import VirtualEthernetCardNotSupported as VirtualEthernetCardNotSupported
from .VirtualHardwareCompatibilityIssue import VirtualHardwareCompatibilityIssue as VirtualHardwareCompatibilityIssue
from .VirtualHardwareVersionNotSupported import VirtualHardwareVersionNotSupported as VirtualHardwareVersionNotSupported
from .VmAlreadyExistsInDatacenter import VmAlreadyExistsInDatacenter as VmAlreadyExistsInDatacenter
from .VmConfigFault import VmConfigFault as VmConfigFault
from .VmConfigIncompatibleForFaultTolerance import VmConfigIncompatibleForFaultTolerance as VmConfigIncompatibleForFaultTolerance
from .VmConfigIncompatibleForRecordReplay import VmConfigIncompatibleForRecordReplay as VmConfigIncompatibleForRecordReplay
from .VmFaultToleranceConfigIssue import VmFaultToleranceConfigIssue as VmFaultToleranceConfigIssue
from .VmFaultToleranceConfigIssueWrapper import VmFaultToleranceConfigIssueWrapper as VmFaultToleranceConfigIssueWrapper
from .VmFaultToleranceInvalidFileBacking import VmFaultToleranceInvalidFileBacking as VmFaultToleranceInvalidFileBacking
from .VmFaultToleranceIssue import VmFaultToleranceIssue as VmFaultToleranceIssue
from .VmFaultToleranceOpIssuesList import VmFaultToleranceOpIssuesList as VmFaultToleranceOpIssuesList
from .VmFaultToleranceTooManyFtVcpusOnHost import VmFaultToleranceTooManyFtVcpusOnHost as VmFaultToleranceTooManyFtVcpusOnHost
from .VmFaultToleranceTooManyVMsOnHost import VmFaultToleranceTooManyVMsOnHost as VmFaultToleranceTooManyVMsOnHost
from .VmHostAffinityRuleViolation import VmHostAffinityRuleViolation as VmHostAffinityRuleViolation
from .VmLimitLicense import VmLimitLicense as VmLimitLicense
from .VmMetadataManagerFault import VmMetadataManagerFault as VmMetadataManagerFault
from .VmMonitorIncompatibleForFaultTolerance import VmMonitorIncompatibleForFaultTolerance as VmMonitorIncompatibleForFaultTolerance
from .VmPowerOnDisabled import VmPowerOnDisabled as VmPowerOnDisabled
from .VmSmpFaultToleranceTooManyVMsOnHost import VmSmpFaultToleranceTooManyVMsOnHost as VmSmpFaultToleranceTooManyVMsOnHost
from .VmToolsUpgradeFault import VmToolsUpgradeFault as VmToolsUpgradeFault
from .VmValidateMaxDevice import VmValidateMaxDevice as VmValidateMaxDevice
from .VmWwnConflict import VmWwnConflict as VmWwnConflict
from .VmfsAlreadyMounted import VmfsAlreadyMounted as VmfsAlreadyMounted
from .VmfsAmbiguousMount import VmfsAmbiguousMount as VmfsAmbiguousMount
from .VmfsMountFault import VmfsMountFault as VmfsMountFault
from .VmotionInterfaceNotEnabled import VmotionInterfaceNotEnabled as VmotionInterfaceNotEnabled
from .VolumeEditorError import VolumeEditorError as VolumeEditorError
from .VramLimitLicense import VramLimitLicense as VramLimitLicense
from .VsanClusterUuidMismatch import VsanClusterUuidMismatch as VsanClusterUuidMismatch
from .VsanDiskFault import VsanDiskFault as VsanDiskFault
from .VsanFault import VsanFault as VsanFault
from .VsanIncompatibleDiskMapping import VsanIncompatibleDiskMapping as VsanIncompatibleDiskMapping
from .VsanNodeNotMaster import VsanNodeNotMaster as VsanNodeNotMaster
from .VsanSslVerifyCertFault import VsanSslVerifyCertFault as VsanSslVerifyCertFault
from .VspanDestPortConflict import VspanDestPortConflict as VspanDestPortConflict
from .VspanPortConflict import VspanPortConflict as VspanPortConflict
from .VspanPortMoveFault import VspanPortMoveFault as VspanPortMoveFault
from .VspanPortPromiscChangeFault import VspanPortPromiscChangeFault as VspanPortPromiscChangeFault
from .VspanPortgroupPromiscChangeFault import VspanPortgroupPromiscChangeFault as VspanPortgroupPromiscChangeFault
from .VspanPortgroupTypeChangeFault import VspanPortgroupTypeChangeFault as VspanPortgroupTypeChangeFault
from .VspanPromiscuousPortNotSupported import VspanPromiscuousPortNotSupported as VspanPromiscuousPortNotSupported
from .VspanSameSessionPortConflict import VspanSameSessionPortConflict as VspanSameSessionPortConflict
from .WakeOnLanNotSupported import WakeOnLanNotSupported as WakeOnLanNotSupported
from .WakeOnLanNotSupportedByVmotionNIC import WakeOnLanNotSupportedByVmotionNIC as WakeOnLanNotSupportedByVmotionNIC
from .WillLoseHAProtection import WillLoseHAProtection as WillLoseHAProtection
from .WillModifyConfigCpuRequirements import WillModifyConfigCpuRequirements as WillModifyConfigCpuRequirements
from .WillResetSnapshotDirectory import WillResetSnapshotDirectory as WillResetSnapshotDirectory
from .WipeDiskFault import WipeDiskFault as WipeDiskFault
