# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import check as check
from . import customization as customization
from . import device as device
from . import guest as guest
from . import replication as replication

from .AffinityInfo import AffinityInfo as AffinityInfo
from .BaseIndependentFilterSpec import BaseIndependentFilterSpec as BaseIndependentFilterSpec
from .BootOptions import BootOptions as BootOptions
from .Capability import Capability as Capability
from .CdromInfo import CdromInfo as CdromInfo
from .CertThumbprint import CertThumbprint as CertThumbprint
from .CloneSpec import CloneSpec as CloneSpec
from .ConfigInfo import ConfigInfo as ConfigInfo
from .ConfigOption import ConfigOption as ConfigOption
from .ConfigOptionDescriptor import ConfigOptionDescriptor as ConfigOptionDescriptor
from .ConfigSpec import ConfigSpec as ConfigSpec
from .ConfigTarget import ConfigTarget as ConfigTarget
from .ConsolePreferences import ConsolePreferences as ConsolePreferences
from .ContentLibraryItemInfo import ContentLibraryItemInfo as ContentLibraryItemInfo
from .DatastoreInfo import DatastoreInfo as DatastoreInfo
from .DatastoreOption import DatastoreOption as DatastoreOption
from .DefaultPowerOpInfo import DefaultPowerOpInfo as DefaultPowerOpInfo
from .DefaultProfileSpec import DefaultProfileSpec as DefaultProfileSpec
from .DefinedProfileSpec import DefinedProfileSpec as DefinedProfileSpec
from .DeviceRuntimeInfo import DeviceRuntimeInfo as DeviceRuntimeInfo
from .DiskDeviceInfo import DiskDeviceInfo as DiskDeviceInfo
from .DvxClassInfo import DvxClassInfo as DvxClassInfo
from .DynamicPassthroughInfo import DynamicPassthroughInfo as DynamicPassthroughInfo
from .EmptyIndependentFilterSpec import EmptyIndependentFilterSpec as EmptyIndependentFilterSpec
from .EmptyProfileSpec import EmptyProfileSpec as EmptyProfileSpec
from .FaultToleranceConfigInfo import FaultToleranceConfigInfo as FaultToleranceConfigInfo
from .FaultToleranceConfigSpec import FaultToleranceConfigSpec as FaultToleranceConfigSpec
from .FaultToleranceMetaSpec import FaultToleranceMetaSpec as FaultToleranceMetaSpec
from .FaultTolerancePrimaryConfigInfo import FaultTolerancePrimaryConfigInfo as FaultTolerancePrimaryConfigInfo
from .FaultToleranceSecondaryConfigInfo import FaultToleranceSecondaryConfigInfo as FaultToleranceSecondaryConfigInfo
from .FaultToleranceSecondaryOpResult import FaultToleranceSecondaryOpResult as FaultToleranceSecondaryOpResult
from .FaultToleranceVMConfigSpec import FaultToleranceVMConfigSpec as FaultToleranceVMConfigSpec
from .FeatureRequirement import FeatureRequirement as FeatureRequirement
from .FileInfo import FileInfo as FileInfo
from .FileLayout import FileLayout as FileLayout
from .FileLayoutEx import FileLayoutEx as FileLayoutEx
from .FlagInfo import FlagInfo as FlagInfo
from .FloppyInfo import FloppyInfo as FloppyInfo
from .ForkConfigInfo import ForkConfigInfo as ForkConfigInfo
from .GuestCustomizationManager import GuestCustomizationManager as GuestCustomizationManager
from .GuestInfo import GuestInfo as GuestInfo
from .GuestIntegrityInfo import GuestIntegrityInfo as GuestIntegrityInfo
from .GuestMonitoringModeInfo import GuestMonitoringModeInfo as GuestMonitoringModeInfo
from .GuestOsDescriptor import GuestOsDescriptor as GuestOsDescriptor
from .GuestQuiesceSpec import GuestQuiesceSpec as GuestQuiesceSpec
from .IdeDiskDeviceInfo import IdeDiskDeviceInfo as IdeDiskDeviceInfo
from .IndependentFilterSpec import IndependentFilterSpec as IndependentFilterSpec
from .InstantCloneSpec import InstantCloneSpec as InstantCloneSpec
from .LegacyNetworkSwitchInfo import LegacyNetworkSwitchInfo as LegacyNetworkSwitchInfo
from .Message import Message as Message
from .NetworkInfo import NetworkInfo as NetworkInfo
from .NetworkShaperInfo import NetworkShaperInfo as NetworkShaperInfo
from .OpaqueNetworkInfo import OpaqueNetworkInfo as OpaqueNetworkInfo
from .ParallelInfo import ParallelInfo as ParallelInfo
from .PciPassthroughInfo import PciPassthroughInfo as PciPassthroughInfo
from .PciSharedGpuPassthroughInfo import PciSharedGpuPassthroughInfo as PciSharedGpuPassthroughInfo
from .PrecisionClockInfo import PrecisionClockInfo as PrecisionClockInfo
from .ProfileDetails import ProfileDetails as ProfileDetails
from .ProfileRawData import ProfileRawData as ProfileRawData
from .ProfileSpec import ProfileSpec as ProfileSpec
from .PropertyRelation import PropertyRelation as PropertyRelation
from .QuestionInfo import QuestionInfo as QuestionInfo
from .RelocateSpec import RelocateSpec as RelocateSpec
from .ReplicationConfigSpec import ReplicationConfigSpec as ReplicationConfigSpec
from .RuntimeInfo import RuntimeInfo as RuntimeInfo
from .ScheduledHardwareUpgradeInfo import ScheduledHardwareUpgradeInfo as ScheduledHardwareUpgradeInfo
from .ScsiDiskDeviceInfo import ScsiDiskDeviceInfo as ScsiDiskDeviceInfo
from .ScsiPassthroughInfo import ScsiPassthroughInfo as ScsiPassthroughInfo
from .SerialInfo import SerialInfo as SerialInfo
from .SgxInfo import SgxInfo as SgxInfo
from .SgxTargetInfo import SgxTargetInfo as SgxTargetInfo
from .Snapshot import Snapshot as Snapshot
from .SnapshotInfo import SnapshotInfo as SnapshotInfo
from .SnapshotSelectionSpec import SnapshotSelectionSpec as SnapshotSelectionSpec
from .SnapshotTree import SnapshotTree as SnapshotTree
from .SoundInfo import SoundInfo as SoundInfo
from .SriovDevicePoolInfo import SriovDevicePoolInfo as SriovDevicePoolInfo
from .SriovInfo import SriovInfo as SriovInfo
from .SriovNetworkDevicePoolInfo import SriovNetworkDevicePoolInfo as SriovNetworkDevicePoolInfo
from .StorageInfo import StorageInfo as StorageInfo
from .SubnetInfo import SubnetInfo as SubnetInfo
from .Summary import Summary as Summary
from .TargetInfo import TargetInfo as TargetInfo
from .ToolsConfigInfo import ToolsConfigInfo as ToolsConfigInfo
from .UsbInfo import UsbInfo as UsbInfo
from .UsbScanCodeSpec import UsbScanCodeSpec as UsbScanCodeSpec
from .VFlashModuleInfo import VFlashModuleInfo as VFlashModuleInfo
from .VMotionStunTimeInfo import VMotionStunTimeInfo as VMotionStunTimeInfo
from .VcpuConfig import VcpuConfig as VcpuConfig
from .VendorDeviceGroupInfo import VendorDeviceGroupInfo as VendorDeviceGroupInfo
from .VgpuDeviceInfo import VgpuDeviceInfo as VgpuDeviceInfo
from .VgpuProfileInfo import VgpuProfileInfo as VgpuProfileInfo
from .VirtualDeviceGroups import VirtualDeviceGroups as VirtualDeviceGroups
from .VirtualDeviceSwap import VirtualDeviceSwap as VirtualDeviceSwap
from .VirtualHardware import VirtualHardware as VirtualHardware
from .VirtualHardwareOption import VirtualHardwareOption as VirtualHardwareOption
from .VirtualNuma import VirtualNuma as VirtualNuma
from .VirtualNumaInfo import VirtualNumaInfo as VirtualNumaInfo
from .VirtualPMem import VirtualPMem as VirtualPMem
from .VmImportSpec import VmImportSpec as VmImportSpec
from .WindowsQuiesceSpec import WindowsQuiesceSpec as WindowsQuiesceSpec
