# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AbortWipeDiskStatus import AbortWipeDiskStatus as AbortWipeDiskStatus
from .AboutInfoEx import AboutInfoEx as AboutInfoEx
from .AddStoragePoolDiskSpec import AddStoragePoolDiskSpec as AddStoragePoolDiskSpec
from .ClusterStatus import ClusterStatus as ClusterStatus
from .ComplianceDetail import ComplianceDetail as ComplianceDetail
from .ComplianceResult import ComplianceResult as ComplianceResult
from .ComplianceStatus import ComplianceStatus as ComplianceStatus
from .ConfigInfo import ConfigInfo as ConfigInfo
from .ConfigInfoEx import ConfigInfoEx as ConfigInfoEx
from .CreateNativeKeyProviderSpec import CreateNativeKeyProviderSpec as CreateNativeKeyProviderSpec
from .DataInTransitEncryptionInfo import DataInTransitEncryptionInfo as DataInTransitEncryptionInfo
from .DecommissionMode import DecommissionMode as DecommissionMode
from .DeleteStoragePoolDiskSpec import DeleteStoragePoolDiskSpec as DeleteStoragePoolDiskSpec
from .DiskMapInfo import DiskMapInfo as DiskMapInfo
from .DiskMapInfoEx import DiskMapInfoEx as DiskMapInfoEx
from .DiskMapResult import DiskMapResult as DiskMapResult
from .DiskMapping import DiskMapping as DiskMapping
from .DiskMappingCreationSpec import DiskMappingCreationSpec as DiskMappingCreationSpec
from .DiskResult import DiskResult as DiskResult
from .DiskResultEx import DiskResultEx as DiskResultEx
from .DrsStats import DrsStats as DrsStats
from .EncryptionInfo import EncryptionInfo as EncryptionInfo
from .EncryptionOperation import EncryptionOperation as EncryptionOperation
from .EncryptionTransitionState import EncryptionTransitionState as EncryptionTransitionState
from .HealthState import HealthState as HealthState
from .IpConfig import IpConfig as IpConfig
from .IpConfigEx import IpConfigEx as IpConfigEx
from .MembershipInfo import MembershipInfo as MembershipInfo
from .NodeState import NodeState as NodeState
from .PolicyStatus import PolicyStatus as PolicyStatus
from .PortConfigEx import PortConfigEx as PortConfigEx
from .QueryVsanDisksSpec import QueryVsanDisksSpec as QueryVsanDisksSpec
from .RemoteVsanServerClusterConfig import RemoteVsanServerClusterConfig as RemoteVsanServerClusterConfig
from .RuntimeStats import RuntimeStats as RuntimeStats
from .ServerClusterUnicastConfig import ServerClusterUnicastConfig as ServerClusterUnicastConfig
from .ServerClusterUnicastInfo import ServerClusterUnicastInfo as ServerClusterUnicastInfo
from .ServerNodeType import ServerNodeType as ServerNodeType
from .SiteAffinityInfo import SiteAffinityInfo as SiteAffinityInfo
from .StatsType import StatsType as StatsType
from .StoragePoolDisk import StoragePoolDisk as StoragePoolDisk
from .StoragePoolDiskInfo import StoragePoolDiskInfo as StoragePoolDiskInfo
from .StoragePoolDiskType import StoragePoolDiskType as StoragePoolDiskType
from .StoragePoolInfo import StoragePoolInfo as StoragePoolInfo
from .TrimDiskEntry import TrimDiskEntry as TrimDiskEntry
from .TrimDiskSpec import TrimDiskSpec as TrimDiskSpec
from .TrimDiskType import TrimDiskType as TrimDiskType
from .UpdateStoragePoolDiskSpec import UpdateStoragePoolDiskSpec as UpdateStoragePoolDiskSpec
from .VsanAssociatedObjects import VsanAssociatedObjects as VsanAssociatedObjects
from .VsanAssociatedObjectsResult import VsanAssociatedObjectsResult as VsanAssociatedObjectsResult
from .VsanComplianceQuerySpec import VsanComplianceQuerySpec as VsanComplianceQuerySpec
from .VsanComponentSyncState import VsanComponentSyncState as VsanComponentSyncState
from .VsanDirectStorage import VsanDirectStorage as VsanDirectStorage
from .VsanDiskEvacReason import VsanDiskEvacReason as VsanDiskEvacReason
from .VsanDiskInfo import VsanDiskInfo as VsanDiskInfo
from .VsanDiskManagementSystemCapability import VsanDiskManagementSystemCapability as VsanDiskManagementSystemCapability
from .VsanDiskTrimOption import VsanDiskTrimOption as VsanDiskTrimOption
from .VsanDiskType import VsanDiskType as VsanDiskType
from .VsanDiskgroupCapability import VsanDiskgroupCapability as VsanDiskgroupCapability
from .VsanHostCapability import VsanHostCapability as VsanHostCapability
from .VsanManagedDisksInfo import VsanManagedDisksInfo as VsanManagedDisksInfo
from .VsanManagedPMemInfo import VsanManagedPMemInfo as VsanManagedPMemInfo
from .VsanObjectProfileInfo import VsanObjectProfileInfo as VsanObjectProfileInfo
from .VsanObjectSyncState import VsanObjectSyncState as VsanObjectSyncState
from .VsanRuntimeInfo import VsanRuntimeInfo as VsanRuntimeInfo
from .VsanScsiDisk import VsanScsiDisk as VsanScsiDisk
from .VsanSyncingObjectQueryResult import VsanSyncingObjectQueryResult as VsanSyncingObjectQueryResult
from .VsanSyncingObjectRecoveryDetails import VsanSyncingObjectRecoveryDetails as VsanSyncingObjectRecoveryDetails
from .VsanWhatIfEvacDetail import VsanWhatIfEvacDetail as VsanWhatIfEvacDetail
from .VsanWhatIfEvacResult import VsanWhatIfEvacResult as VsanWhatIfEvacResult
from .WipeDiskEligible import WipeDiskEligible as WipeDiskEligible
from .WipeDiskState import WipeDiskState as WipeDiskState
from .WipeDiskStatus import WipeDiskStatus as WipeDiskStatus
