# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .BrokenDiskChainIssue import BrokenDiskChainIssue as BrokenDiskChainIssue
from .DisallowDataMovementIssue import DisallowDataMovementIssue as DisallowDataMovementIssue
from .DisallowEvacuateDataIssue import DisallowEvacuateDataIssue as DisallowEvacuateDataIssue
from .DiskUnhealthIssue import DiskUnhealthIssue as DiskUnhealthIssue
from .HigherObjectsPresentDuringDowngradeIssue import HigherObjectsPresentDuringDowngradeIssue as HigherObjectsPresentDuringDowngradeIssue
from .HostPropertyRetrieveIssue import HostPropertyRetrieveIssue as HostPropertyRetrieveIssue
from .HostWithHybridDiskgroupIssue import HostWithHybridDiskgroupIssue as HostWithHybridDiskgroupIssue
from .HostsCompressionOnlyNotSupported import HostsCompressionOnlyNotSupported as HostsCompressionOnlyNotSupported
from .MixedEsxVersionInClientIssue import MixedEsxVersionInClientIssue as MixedEsxVersionInClientIssue
from .MixedEsxVersionIssue import MixedEsxVersionIssue as MixedEsxVersionIssue
from .ObjectInaccessibleIssue import ObjectInaccessibleIssue as ObjectInaccessibleIssue
from .ObjectPolicyIssue import ObjectPolicyIssue as ObjectPolicyIssue
from .RemoteClusterNotCompatible import RemoteClusterNotCompatible as RemoteClusterNotCompatible
from .UnknownScanIssue import UnknownScanIssue as UnknownScanIssue
from .UnsupportedHighDiskVersionIssue import UnsupportedHighDiskVersionIssue as UnsupportedHighDiskVersionIssue
