# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.fault import OvfImport

class OvfCpuCompatibility(OvfImport):
   registerName: str
   level: int
   registerValue: str
   desiredRegisterValue: str
