# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AlreadyExists import AlreadyExists as AlreadyExists
from .CapabilityProfilePropertyMismatchFault import CapabilityProfilePropertyMismatchFault as CapabilityProfilePropertyMismatchFault
from .CompatibilityCheckFault import CompatibilityCheckFault as CompatibilityCheckFault
from .DefaultProfileAppliesFault import DefaultProfileAppliesFault as DefaultProfileAppliesFault
from .DuplicateName import DuplicateName as DuplicateName
from .IncompatibleVendorSpecificRuleSet import IncompatibleVendorSpecificRuleSet as IncompatibleVendorSpecificRuleSet
from .InvalidLogin import InvalidLogin as InvalidLogin
from .LegacyHubsNotSupported import LegacyHubsNotSupported as LegacyHubsNotSupported
from .NoPermission import NoPermission as NoPermission
from .NonExistentHubs import NonExistentHubs as NonExistentHubs
from .NotFound import NotFound as NotFound
from .PBMFault import PBMFault as PBMFault
from .ProfileStorageFault import ProfileStorageFault as ProfileStorageFault
from .PropertyMismatchFault import PropertyMismatchFault as PropertyMismatchFault
from .ResourceInUse import ResourceInUse as ResourceInUse
