# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .HostDiskMappingInfo import HostDiskMappingInfo as HostDiskMappingInfo
from .HostDiskMappingOption import HostDiskMappingOption as HostDiskMappingOption
from .ParaVirtualSCSIController import ParaVirtualSCSIController as ParaVirtualSCSIController
from .ParaVirtualSCSIControllerOption import ParaVirtualSCSIControllerOption as ParaVirtualSCSIControllerOption
from .VirtualAHCIController import VirtualAHCIController as VirtualAHCIController
from .VirtualAHCIControllerOption import VirtualAHCIControllerOption as VirtualAHCIControllerOption
from .VirtualBusLogicController import VirtualBusLogicController as VirtualBusLogicController
from .VirtualBusLogicControllerOption import VirtualBusLogicControllerOption as VirtualBusLogicControllerOption
from .VirtualCdrom import VirtualCdrom as VirtualCdrom
from .VirtualCdromOption import VirtualCdromOption as VirtualCdromOption
from .VirtualController import VirtualController as VirtualController
from .VirtualControllerOption import VirtualControllerOption as VirtualControllerOption
from .VirtualDevice import VirtualDevice as VirtualDevice
from .VirtualDeviceOption import VirtualDeviceOption as VirtualDeviceOption
from .VirtualDeviceSpec import VirtualDeviceSpec as VirtualDeviceSpec
from .VirtualDisk import VirtualDisk as VirtualDisk
from .VirtualDiskId import VirtualDiskId as VirtualDiskId
from .VirtualDiskOption import VirtualDiskOption as VirtualDiskOption
from .VirtualDiskSpec import VirtualDiskSpec as VirtualDiskSpec
from .VirtualE1000 import VirtualE1000 as VirtualE1000
from .VirtualE1000Option import VirtualE1000Option as VirtualE1000Option
from .VirtualE1000e import VirtualE1000e as VirtualE1000e
from .VirtualE1000eOption import VirtualE1000eOption as VirtualE1000eOption
from .VirtualEnsoniq1371 import VirtualEnsoniq1371 as VirtualEnsoniq1371
from .VirtualEnsoniq1371Option import VirtualEnsoniq1371Option as VirtualEnsoniq1371Option
from .VirtualEthernetCard import VirtualEthernetCard as VirtualEthernetCard
from .VirtualEthernetCardOption import VirtualEthernetCardOption as VirtualEthernetCardOption
from .VirtualFloppy import VirtualFloppy as VirtualFloppy
from .VirtualFloppyOption import VirtualFloppyOption as VirtualFloppyOption
from .VirtualHdAudioCard import VirtualHdAudioCard as VirtualHdAudioCard
from .VirtualHdAudioCardOption import VirtualHdAudioCardOption as VirtualHdAudioCardOption
from .VirtualIDEController import VirtualIDEController as VirtualIDEController
from .VirtualIDEControllerOption import VirtualIDEControllerOption as VirtualIDEControllerOption
from .VirtualKeyboard import VirtualKeyboard as VirtualKeyboard
from .VirtualKeyboardOption import VirtualKeyboardOption as VirtualKeyboardOption
from .VirtualLsiLogicController import VirtualLsiLogicController as VirtualLsiLogicController
from .VirtualLsiLogicControllerOption import VirtualLsiLogicControllerOption as VirtualLsiLogicControllerOption
from .VirtualLsiLogicSASController import VirtualLsiLogicSASController as VirtualLsiLogicSASController
from .VirtualLsiLogicSASControllerOption import VirtualLsiLogicSASControllerOption as VirtualLsiLogicSASControllerOption
from .VirtualNVDIMM import VirtualNVDIMM as VirtualNVDIMM
from .VirtualNVDIMMController import VirtualNVDIMMController as VirtualNVDIMMController
from .VirtualNVDIMMControllerOption import VirtualNVDIMMControllerOption as VirtualNVDIMMControllerOption
from .VirtualNVDIMMOption import VirtualNVDIMMOption as VirtualNVDIMMOption
from .VirtualNVMEController import VirtualNVMEController as VirtualNVMEController
from .VirtualNVMEControllerOption import VirtualNVMEControllerOption as VirtualNVMEControllerOption
from .VirtualPCIController import VirtualPCIController as VirtualPCIController
from .VirtualPCIControllerOption import VirtualPCIControllerOption as VirtualPCIControllerOption
from .VirtualPCIPassthrough import VirtualPCIPassthrough as VirtualPCIPassthrough
from .VirtualPCIPassthroughOption import VirtualPCIPassthroughOption as VirtualPCIPassthroughOption
from .VirtualPCNet32 import VirtualPCNet32 as VirtualPCNet32
from .VirtualPCNet32Option import VirtualPCNet32Option as VirtualPCNet32Option
from .VirtualPS2Controller import VirtualPS2Controller as VirtualPS2Controller
from .VirtualPS2ControllerOption import VirtualPS2ControllerOption as VirtualPS2ControllerOption
from .VirtualParallelPort import VirtualParallelPort as VirtualParallelPort
from .VirtualParallelPortOption import VirtualParallelPortOption as VirtualParallelPortOption
from .VirtualPointingDevice import VirtualPointingDevice as VirtualPointingDevice
from .VirtualPointingDeviceOption import VirtualPointingDeviceOption as VirtualPointingDeviceOption
from .VirtualPrecisionClock import VirtualPrecisionClock as VirtualPrecisionClock
from .VirtualPrecisionClockOption import VirtualPrecisionClockOption as VirtualPrecisionClockOption
from .VirtualSATAController import VirtualSATAController as VirtualSATAController
from .VirtualSATAControllerOption import VirtualSATAControllerOption as VirtualSATAControllerOption
from .VirtualSCSIController import VirtualSCSIController as VirtualSCSIController
from .VirtualSCSIControllerOption import VirtualSCSIControllerOption as VirtualSCSIControllerOption
from .VirtualSCSIPassthrough import VirtualSCSIPassthrough as VirtualSCSIPassthrough
from .VirtualSCSIPassthroughOption import VirtualSCSIPassthroughOption as VirtualSCSIPassthroughOption
from .VirtualSIOController import VirtualSIOController as VirtualSIOController
from .VirtualSIOControllerOption import VirtualSIOControllerOption as VirtualSIOControllerOption
from .VirtualSerialPort import VirtualSerialPort as VirtualSerialPort
from .VirtualSerialPortOption import VirtualSerialPortOption as VirtualSerialPortOption
from .VirtualSoundBlaster16 import VirtualSoundBlaster16 as VirtualSoundBlaster16
from .VirtualSoundBlaster16Option import VirtualSoundBlaster16Option as VirtualSoundBlaster16Option
from .VirtualSoundCard import VirtualSoundCard as VirtualSoundCard
from .VirtualSoundCardOption import VirtualSoundCardOption as VirtualSoundCardOption
from .VirtualSriovEthernetCard import VirtualSriovEthernetCard as VirtualSriovEthernetCard
from .VirtualSriovEthernetCardOption import VirtualSriovEthernetCardOption as VirtualSriovEthernetCardOption
from .VirtualTPM import VirtualTPM as VirtualTPM
from .VirtualTPMOption import VirtualTPMOption as VirtualTPMOption
from .VirtualUSB import VirtualUSB as VirtualUSB
from .VirtualUSBController import VirtualUSBController as VirtualUSBController
from .VirtualUSBControllerOption import VirtualUSBControllerOption as VirtualUSBControllerOption
from .VirtualUSBOption import VirtualUSBOption as VirtualUSBOption
from .VirtualUSBXHCIController import VirtualUSBXHCIController as VirtualUSBXHCIController
from .VirtualUSBXHCIControllerOption import VirtualUSBXHCIControllerOption as VirtualUSBXHCIControllerOption
from .VirtualVMCIDevice import VirtualVMCIDevice as VirtualVMCIDevice
from .VirtualVMCIDeviceOption import VirtualVMCIDeviceOption as VirtualVMCIDeviceOption
from .VirtualVMIROM import VirtualVMIROM as VirtualVMIROM
from .VirtualVMIROMOption import VirtualVMIROMOption as VirtualVMIROMOption
from .VirtualVideoCard import VirtualVideoCard as VirtualVideoCard
from .VirtualVideoCardOption import VirtualVideoCardOption as VirtualVideoCardOption
from .VirtualVmxnet import VirtualVmxnet as VirtualVmxnet
from .VirtualVmxnet2 import VirtualVmxnet2 as VirtualVmxnet2
from .VirtualVmxnet2Option import VirtualVmxnet2Option as VirtualVmxnet2Option
from .VirtualVmxnet3 import VirtualVmxnet3 as VirtualVmxnet3
from .VirtualVmxnet3Option import VirtualVmxnet3Option as VirtualVmxnet3Option
from .VirtualVmxnet3Vrdma import VirtualVmxnet3Vrdma as VirtualVmxnet3Vrdma
from .VirtualVmxnet3VrdmaOption import VirtualVmxnet3VrdmaOption as VirtualVmxnet3VrdmaOption
from .VirtualVmxnetOption import VirtualVmxnetOption as VirtualVmxnetOption
from .VirtualWDT import VirtualWDT as VirtualWDT
from .VirtualWDTOption import VirtualWDTOption as VirtualWDTOption
