# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import replication as replication

from .AlarmStatus import AlarmStatus as AlarmStatus
from .AlarmType import AlarmType as AlarmType
from .BackingConfig import BackingConfig as BackingConfig
from .BackingStoragePool import BackingStoragePool as BackingStoragePool
from .DatastoreBackingPoolMapping import DatastoreBackingPoolMapping as DatastoreBackingPoolMapping
from .DatastorePair import DatastorePair as DatastorePair
from .DrsMigrationCapabilityResult import DrsMigrationCapabilityResult as DrsMigrationCapabilityResult
from .EntityType import EntityType as EntityType
from .FaultDomainProviderMapping import FaultDomainProviderMapping as FaultDomainProviderMapping
from .FcStoragePort import FcStoragePort as FcStoragePort
from .FcoeStoragePort import FcoeStoragePort as FcoeStoragePort
from .FileSystemInfo import FileSystemInfo as FileSystemInfo
from .IscsiStoragePort import IscsiStoragePort as IscsiStoragePort
from .LunHbaAssociation import LunHbaAssociation as LunHbaAssociation
from .NameValuePair import NameValuePair as NameValuePair
from .StorageAlarm import StorageAlarm as StorageAlarm
from .StorageArray import StorageArray as StorageArray
from .StorageCapability import StorageCapability as StorageCapability
from .StorageContainer import StorageContainer as StorageContainer
from .StorageContainerResult import StorageContainerResult as StorageContainerResult
from .StorageContainerSpec import StorageContainerSpec as StorageContainerSpec
from .StorageFileSystem import StorageFileSystem as StorageFileSystem
from .StorageLun import StorageLun as StorageLun
from .StoragePort import StoragePort as StoragePort
from .StorageProcessor import StorageProcessor as StorageProcessor
from .ThinProvisioningStatus import ThinProvisioningStatus as ThinProvisioningStatus
