# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import KeyAnyValue
from pyVmomi.vmodl import LocalizableMessage

class EntityCompatibilityResult(DynamicData):
   entity: ManagedEntity
   compatible: bool
   incompatibleReasons: list[LocalizableMessage] = []
   extendedAttributes: list[KeyAnyValue] = []
