# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import host as host
from . import vcenter as vcenter

from .BaseConfigInfo import BaseConfigInfo as BaseConfigInfo
from .CloneSpec import CloneSpec as CloneSpec
from .CreateSpec import CreateSpec as CreateSpec
from .DiskCryptoSpec import DiskCryptoSpec as DiskCryptoSpec
from .DiskInfoFlag import DiskInfoFlag as DiskInfoFlag
from .ID import ID as ID
from .InfrastructureObjectPolicy import InfrastructureObjectPolicy as InfrastructureObjectPolicy
from .InfrastructureObjectPolicySpec import InfrastructureObjectPolicySpec as InfrastructureObjectPolicySpec
from .MigrateSpec import MigrateSpec as MigrateSpec
from .ReconcileResult import ReconcileResult as ReconcileResult
from .ReconcileSpec import ReconcileSpec as ReconcileSpec
from .RelocateSpec import RelocateSpec as RelocateSpec
from .StateInfo import StateInfo as StateInfo
from .TagEntry import TagEntry as TagEntry
from .VClockInfo import VClockInfo as VClockInfo
from .VStorageObject import VStorageObject as VStorageObject
from .VStorageObjectControlFlag import VStorageObjectControlFlag as VStorageObjectControlFlag
from .VStorageObjectManagerBase import VStorageObjectManagerBase as VStorageObjectManagerBase
from .VStorageObjectSnapshot import VStorageObjectSnapshot as VStorageObjectSnapshot
from .VStorageObjectSnapshotDetails import VStorageObjectSnapshotDetails as VStorageObjectSnapshotDetails
from .VStorageObjectSnapshotInfo import VStorageObjectSnapshotInfo as VStorageObjectSnapshotInfo
