# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .CannotConfigureSolutions import CannotConfigureSolutions as CannotConfigureSolutions
from .CannotUploadDepot import CannotUploadDepot as CannotUploadDepot
from .DepotIssue import DepotIssue as DepotIssue
from .InaccessibleDepot import InaccessibleDepot as InaccessibleDepot
from .InvalidDepot import InvalidDepot as InvalidDepot
from .PMIssue import PMIssue as PMIssue
from .PMUnavailable import PMUnavailable as PMUnavailable
