# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .DeviceId import DeviceId as DeviceId
from .FailoverParam import FailoverParam as FailoverParam
from .FailoverSuccessResult import FailoverSuccessResult as FailoverSuccessResult
from .FaultDomainInfo import FaultDomainInfo as FaultDomainInfo
from .GroupErrorResult import GroupErrorResult as GroupErrorResult
from .GroupInfo import GroupInfo as GroupInfo
from .GroupOperationResult import GroupOperationResult as GroupOperationResult
from .PointInTimeReplicaId import PointInTimeReplicaId as PointInTimeReplicaId
from .PromoteParam import PromoteParam as PromoteParam
from .QueryPointInTimeReplicaParam import QueryPointInTimeReplicaParam as QueryPointInTimeReplicaParam
from .QueryPointInTimeReplicaSuccessResult import QueryPointInTimeReplicaSuccessResult as QueryPointInTimeReplicaSuccessResult
from .QueryPointInTimeReplicaSummaryResult import QueryPointInTimeReplicaSummaryResult as QueryPointInTimeReplicaSummaryResult
from .QueryReplicationGroupSuccessResult import QueryReplicationGroupSuccessResult as QueryReplicationGroupSuccessResult
from .QueryReplicationPeerResult import QueryReplicationPeerResult as QueryReplicationPeerResult
from .RecoveredTargetGroupMemberInfo import RecoveredTargetGroupMemberInfo as RecoveredTargetGroupMemberInfo
from .ReplicaId import ReplicaId as ReplicaId
from .ReplicationState import ReplicationState as ReplicationState
from .ReverseReplicationSuccessResult import ReverseReplicationSuccessResult as ReverseReplicationSuccessResult
from .SourceGroupInfo import SourceGroupInfo as SourceGroupInfo
from .SourceGroupMemberInfo import SourceGroupMemberInfo as SourceGroupMemberInfo
from .SyncReplicationGroupSuccessResult import SyncReplicationGroupSuccessResult as SyncReplicationGroupSuccessResult
from .TargetGroupInfo import TargetGroupInfo as TargetGroupInfo
from .TargetGroupMemberInfo import TargetGroupMemberInfo as TargetGroupMemberInfo
from .TestFailoverParam import TestFailoverParam as TestFailoverParam
from .VVolId import VVolId as VVolId
from .VirtualDiskId import VirtualDiskId as VirtualDiskId
from .VirtualDiskKey import VirtualDiskKey as VirtualDiskKey
from .VirtualDiskMoId import VirtualDiskMoId as VirtualDiskMoId
from .VirtualMachineFilePath import VirtualMachineFilePath as VirtualMachineFilePath
from .VirtualMachineId import VirtualMachineId as VirtualMachineId
from .VirtualMachineMoId import VirtualMachineMoId as VirtualMachineMoId
from .VirtualMachineUUID import VirtualMachineUUID as VirtualMachineUUID
