# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

from pyVmomi.vim.fault import VimFault

from pyVmomi.vim.profile import ProfilePropertyPath

class ProfileUpdateFailed(VimFault):
   class UpdateFailure(DynamicData):
      profilePath: ProfilePropertyPath
      errMsg: LocalizableMessage

   failure: list[UpdateFailure] = []
   warnings: list[UpdateFailure] = []
