# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.sms.storage.replication import DeviceId
from pyVmomi.sms.storage.replication import TargetGroupMemberInfo

class RecoveredTargetGroupMemberInfo(TargetGroupMemberInfo):
   recoveredDeviceId: Optional[DeviceId] = None
