# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import TpmDigestInfo
from pyVmomi.vim.host import TpmEventLogEntry

class TpmAttestationReport(DynamicData):
   tpmPcrValues: list[TpmDigestInfo] = []
   tpmEvents: list[TpmEventLogEntry] = []
   tpmLogReliable: bool
