# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import Datastore

from pyVmomi.vmodl import DynamicData

class XvcClientInfoSpec(DynamicData):
   clientVc: str
   vcUuid: Optional[str] = None
   vcVersion: Optional[str] = None
   cluster: Optional[ClusterComputeResource] = None
   clusterName: Optional[str] = None
   clusterUuid: Optional[str] = None
   vsanFormatVersion: Optional[str] = None
   minVsanFormatVersion: Optional[str] = None
   datastore: list[Datastore] = []
