# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.fault import VmConfigFault

class VAppPropertyFault(VmConfigFault):
   id: str
   category: str
   label: str
   type: str
   value: str
