# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class AlarmFilter(DynamicData):
   alarmStatus: Optional[str] = None
   alarmType: Optional[str] = None
   entityType: Optional[str] = None
   entityId: list[object] = []
   pageMarker: Optional[str] = None
